<?php
// File: /404.php
// Purpose: Custom 404 error page

// Get application settings
require_once __DIR__ . '/includes/config.php';
require_once __DIR__ . '/includes/functions.php';

// Set HTTP status code
http_response_code(404);

// Get site info from settings
$siteName = getSetting('site_name', 'VTU Platform');
$siteUrl = getSetting('site_url', 'https://example.com');
$primaryColor = getSetting('primary_color', '#5D5CDE');

// Page title
$pageTitle = "Page Not Found";
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($pageTitle ?? ''); ?> - <?php echo htmlspecialchars($siteName ?? ''); ?></title>
    
    <!-- Favicon -->
    <link rel="icon" href="<?php echo htmlspecialchars(getSetting('favicon_url', '/assets/img/favicon.png') ?? ''); ?>" type="image/png">
    
    <!-- CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    
    <style>
        :root {
            --primary-color: <?php echo $primaryColor; ?>;
        }
        
        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, sans-serif;
            background-color: #111827;
            color: #f3f4f6;
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }
        
        .main-content {
            flex: 1;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 2rem 1rem;
        }
        
        .error-container {
            max-width: 800px;
            width: 100%;
            text-align: center;
            padding: 2rem;
        }
        
        .error-code {
            font-size: 10rem;
            font-weight: 800;
            line-height: 1;
            background: linear-gradient(135deg, var(--primary-color), #9f7aea);
            -webkit-background-clip: text;
            background-clip: text;
            color: transparent;
            margin-bottom: 1rem;
            position: relative;
            display: inline-block;
        }
        
        .error-code::after {
            content: '';
            position: absolute;
            width: 100%;
            height: 10px;
            background: linear-gradient(135deg, var(--primary-color), #9f7aea);
            bottom: 0;
            left: 0;
            border-radius: 5px;
            opacity: 0.5;
        }
        
        .error-text {
            font-size: 2rem;
            font-weight: 700;
            margin-bottom: 1.5rem;
            color: #ffffff;
        }
        
        .error-description {
            font-size: 1.125rem;
            margin-bottom: 2rem;
            color: #9ca3af;
            max-width: 600px;
            margin-left: auto;
            margin-right: auto;
        }
        
        .btn-primary {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
            font-weight: 600;
            padding: 0.75rem 1.5rem;
            border-radius: 0.5rem;
            transition: all 0.3s ease;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        
        .btn-primary:hover {
            transform: translateY(-2px);
            box-shadow: 0 6px 8px rgba(0, 0, 0, 0.15);
            background-color: var(--primary-color);
            filter: brightness(110%);
        }
        
        .search-box {
            max-width: 500px;
            margin: 0 auto 2rem;
        }
        
        .search-input {
            background-color: #1f2937;
            border: 1px solid #374151;
            color: #f3f4f6;
            padding: 0.75rem 1rem;
            border-radius: 0.5rem 0 0 0.5rem;
        }
        
        .search-input:focus {
            background-color: #1f2937;
            border-color: var(--primary-color);
            color: #f3f4f6;
            box-shadow: 0 0 0 0.25rem rgba(93, 92, 222, 0.25);
        }
        
        .search-button {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
            border-radius: 0 0.5rem 0.5rem 0;
        }
        
        .search-button:hover {
            background-color: var(--primary-color);
            filter: brightness(110%);
        }
        
        .suggested-links {
            display: flex;
            flex-wrap: wrap;
            justify-content: center;
            gap: 0.75rem;
            margin-top: 2rem;
        }
        
        .suggested-link {
            background-color: #1f2937;
            color: #e5e7eb;
            padding: 0.5rem 1rem;
            border-radius: 0.5rem;
            font-size: 0.875rem;
            text-decoration: none;
            transition: all 0.2s ease;
            border: 1px solid #374151;
        }
        
        .suggested-link:hover {
            background-color: #2d3748;
            color: #ffffff;
            border-color: var(--primary-color);
        }
        
        .illustration {
            margin-bottom: 2rem;
            max-width: 100%;
            height: auto;
        }
        
        /* Animation for the lost spaceship */
        @keyframes float {
            0%, 100% { transform: translateY(0px); }
            50% { transform: translateY(-20px); }
        }
        
        .floating {
            animation: float 6s ease-in-out infinite;
        }
        
        /* Responsive adjustments */
        @media (max-width: 768px) {
            .error-code {
                font-size: 6rem;
            }
            
            .error-text {
                font-size: 1.5rem;
            }
            
            .error-description {
                font-size: 1rem;
            }
        }
        
        @media (max-width: 480px) {
            .error-code {
                font-size: 4rem;
            }
            
            .error-text {
                font-size: 1.25rem;
            }
            
            .suggested-links {
                flex-direction: column;
                align-items: center;
            }
        }
    </style>
</head>
<body>
    <div class="main-content">
        <div class="error-container">
            <!-- SVG Illustration -->
            <div class="illustration floating">
                <svg width="200" height="200" viewBox="0 0 400 400" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <circle cx="200" cy="200" r="200" fill="#1F2937" fill-opacity="0.3"/>
                    <path d="M200 320C265.617 320 320 265.617 320 200C320 134.383 265.617 80 200 80C134.383 80 80 134.383 80 200C80 265.617 134.383 320 200 320Z" fill="#111827"/>
                    <path d="M200 280C243.078 280 278 245.078 278 202C278 158.922 243.078 124 200 124C156.922 124 122 158.922 122 202C122 245.078 156.922 280 200 280Z" fill="#1F2937"/>
                    <path d="M180 180C193.882 180 205 168.882 205 155C205 141.118 193.882 130 180 130C166.118 130 155 141.118 155 155C155 168.882 166.118 180 180 180Z" fill="#6B7280"/>
                    <path d="M220 155C233.882 155 245 143.882 245 130C245 116.118 233.882 105 220 105C206.118 105 195 116.118 195 130C195 143.882 206.118 155 220 155Z" fill="#4B5563"/>
                    <path d="M200 240C213.882 240 225 228.882 225 215C225 201.118 213.882 190 200 190C186.118 190 175 201.118 175 215C175 228.882 186.118 240 200 240Z" fill="#374151"/>
                    <path d="M160 210C173.882 210 185 198.882 185 185C185 171.118 173.882 160 160 160C146.118 160 135 171.118 135 185C135 198.882 146.118 210 160 210Z" fill="#4B5563"/>
                    <path d="M240 210C253.882 210 265 198.882 265 185C265 171.118 253.882 160 240 160C226.118 160 215 171.118 215 185C215 198.882 226.118 210 240 210Z" fill="#374151"/>
                    <path d="M173 100.5L150 50L200 70L250 50L227 100.5" stroke="url(#paint0_linear)" stroke-width="4" stroke-linecap="round" stroke-linejoin="round"/>
                    <path d="M200 70L200 40" stroke="url(#paint1_linear)" stroke-width="4" stroke-linecap="round"/>
                    <defs>
                        <linearGradient id="paint0_linear" x1="150" y1="50" x2="250" y2="50" gradientUnits="userSpaceOnUse">
                            <stop stop-color="#5D5CDE"/>
                            <stop offset="1" stop-color="#9F7AEA"/>
                        </linearGradient>
                        <linearGradient id="paint1_linear" x1="200" y1="40" x2="200" y2="70" gradientUnits="userSpaceOnUse">
                            <stop stop-color="#5D5CDE"/>
                            <stop offset="1" stop-color="#9F7AEA"/>
                        </linearGradient>
                    </defs>
                </svg>
            </div>
            
            <h1 class="error-code">404</h1>
            <h2 class="error-text">Page Not Found</h2>
            <p class="error-description">Oops! The page you're looking for doesn't exist or has been moved to another URL.</p>
            
            <!-- Search box -->
            <div class="search-box">
                <form action="/search" method="GET" class="input-group">
                    <input type="text" name="q" class="form-control search-input" placeholder="Try searching for something else..." aria-label="Search">
                    <button class="btn search-button" type="submit">
                        <i class="fas fa-search"></i>
                    </button>
                </form>
            </div>
            
            <div class="d-flex gap-3 justify-content-center">
                <a href="/" class="btn btn-primary">
                    <i class="fas fa-home me-2"></i> Go Home
                </a>
                <a href="javascript:history.back()" class="btn btn-outline-light">
                    <i class="fas fa-arrow-left me-2"></i> Go Back
                </a>
            </div>
            
            <!-- Suggested links -->
            <div class="suggested-links">
                <a href="/dashboard" class="suggested-link">
                    <i class="fas fa-tachometer-alt me-1"></i> Dashboard
                </a>
                <a href="/dashboard/buy_data.php" class="suggested-link">
                    <i class="fas fa-wifi me-1"></i> Buy Data
                </a>
                <a href="/dashboard/buy_airtime.php" class="suggested-link">
                    <i class="fas fa-phone me-1"></i> Buy Airtime
                </a>
                <a href="/dashboard/wallet.php" class="suggested-link">
                    <i class="fas fa-wallet me-1"></i> Wallet
                </a>
                <a href="/dashboard/service_ids.php" class="suggested-link">
                    <i class="fas fa-table me-1"></i> Service IDs
                </a>
                <a href="/help" class="suggested-link">
                    <i class="fas fa-question-circle me-1"></i> Help Center
                </a>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="py-4 text-center text-muted">
        <div class="container">
            <p class="mb-0">
                &copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($siteName ?? ''); ?>. All rights reserved.
                <a href="/" class="text-decoration-none text-muted">Home</a> | 
                <a href="/contact" class="text-decoration-none text-muted">Contact</a> | 
                <a href="/terms" class="text-decoration-none text-muted">Terms</a>
            </p>
        </div>
    </footer>
</body>
</html>