<?php
// File: /500.php
// Purpose: Custom 500 error page

// Get application settings
// Try-catch in case the error is in the config/functions files themselves
try {
    require_once __DIR__ . '/includes/config.php';
    require_once __DIR__ . '/includes/functions.php';
    
    // Get site info from settings
    $siteName = getSetting('site_name', 'VTU Platform');
    $siteUrl = getSetting('site_url', 'https://example.com');
    $primaryColor = getSetting('primary_color', '#5D5CDE');
} catch (Exception $e) {
    // Fallback values if settings can't be loaded
    $siteName = 'VTU Platform';
    $siteUrl = 'https://example.com';
    $primaryColor = '#5D5CDE';
}

// Set HTTP status code
http_response_code(500);

// Page title
$pageTitle = "Server Error";
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($pageTitle); ?> - <?php echo htmlspecialchars($siteName); ?></title>
    
    <!-- Favicon -->
    <link rel="icon" href="/assets/img/favicon.png" type="image/png">
    
    <!-- CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    
    <style>
        :root {
            --primary-color: <?php echo $primaryColor; ?>;
        }
        
        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, sans-serif;
            background-color: #111827;
            color: #f3f4f6;
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }
        
        .main-content {
            flex: 1;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 2rem 1rem;
        }
        
        .error-container {
            max-width: 800px;
            width: 100%;
            text-align: center;
            padding: 2rem;
        }
        
        .error-code {
            font-size: 8rem;
            font-weight: 800;
            line-height: 1;
            background: linear-gradient(135deg, #ef4444, #f97316);
            -webkit-background-clip: text;
            background-clip: text;
            color: transparent;
            margin-bottom: 1rem;
            position: relative;
            display: inline-block;
        }
        
        .error-code::after {
            content: '';
            position: absolute;
            width: 100%;
            height: 10px;
            background: linear-gradient(135deg, #ef4444, #f97316);
            bottom: 0;
            left: 0;
            border-radius: 5px;
            opacity: 0.5;
        }
        
        .error-text {
            font-size: 2rem;
            font-weight: 700;
            margin-bottom: 1.5rem;
            color: #ffffff;
        }
        
        .error-description {
            font-size: 1.125rem;
            margin-bottom: 2rem;
            color: #9ca3af;
            max-width: 600px;
            margin-left: auto;
            margin-right: auto;
        }
        
        .btn-primary {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
            font-weight: 600;
            padding: 0.75rem 1.5rem;
            border-radius: 0.5rem;
            transition: all 0.3s ease;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        
        .btn-primary:hover {
            transform: translateY(-2px);
            box-shadow: 0 6px 8px rgba(0, 0, 0, 0.15);
            background-color: var(--primary-color);
            filter: brightness(110%);
        }
        
        .suggested-links {
            display: flex;
            flex-wrap: wrap;
            justify-content: center;
            gap: 0.75rem;
            margin-top: 2rem;
        }
        
        .suggested-link {
            background-color: #1f2937;
            color: #e5e7eb;
            padding: 0.5rem 1rem;
            border-radius: 0.5rem;
            font-size: 0.875rem;
            text-decoration: none;
            transition: all 0.2s ease;
            border: 1px solid #374151;
        }
        
        .suggested-link:hover {
            background-color: #2d3748;
            color: #ffffff;
            border-color: var(--primary-color);
        }
        
        .illustration {
            margin-bottom: 2rem;
            max-width: 100%;
            height: auto;
        }
        
        /* Animation for the error illustration */
        @keyframes pulse {
            0% { transform: scale(1); }
            50% { transform: scale(1.05); }
            100% { transform: scale(1); }
        }
        
        .pulse {
            animation: pulse 3s ease-in-out infinite;
        }
        
        /* Responsive adjustments */
        @media (max-width: 768px) {
            .error-code {
                font-size: 6rem;
            }
            
            .error-text {
                font-size: 1.5rem;
            }
            
            .error-description {
                font-size: 1rem;
            }
        }
        
        @media (max-width: 480px) {
            .error-code {
                font-size: 4rem;
            }
            
            .error-text {
                font-size: 1.25rem;
            }
            
            .suggested-links {
                flex-direction: column;
                align-items: center;
            }
        }
    </style>
</head>
<body>
    <div class="main-content">
        <div class="error-container">
            <!-- SVG Illustration -->
            <div class="illustration pulse">
                <svg width="200" height="200" viewBox="0 0 200 200" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <circle cx="100" cy="100" r="100" fill="#1F2937" fill-opacity="0.3"/>
                    <rect x="40" y="90" width="120" height="60" rx="10" fill="#1F2937"/>
                    <rect x="50" y="50" width="100" height="30" rx="5" fill="#374151"/>
                    <circle cx="65" cy="120" r="10" fill="#EF4444"/>
                    <circle cx="100" cy="120" r="10" fill="#F97316"/>
                    <circle cx="135" cy="120" r="10" fill="#10B981"/>
                    <rect x="60" y="60" width="80" height="10" rx="2" fill="#6B7280"/>
                    <path d="M85 170L100 150L115 170" stroke="#F97316" stroke-width="4" stroke-linecap="round" stroke-linejoin="round"/>
                    <path d="M60 40L75 20L90 40" stroke="#EF4444" stroke-width="4" stroke-linecap="round" stroke-linejoin="round"/>
                    <path d="M110 40L125 20L140 40" stroke="#10B981" stroke-width="4" stroke-linecap="round" stroke-linejoin="round"/>
                    <rect x="70" y="155" width="60" height="15" rx="5" fill="#374151"/>
                </svg>
            </div>
            
            <h1 class="error-code">500</h1>
            <h2 class="error-text">Server Error</h2>
            <p class="error-description">Oops! Something went wrong on our servers. We're working to fix the issue and will be back shortly.</p>
            
            <div class="d-flex gap-3 justify-content-center">
                <a href="/" class="btn btn-primary">
                    <i class="fas fa-home me-2"></i> Go Home
                </a>
                <a href="javascript:location.reload()" class="btn btn-outline-light">
                    <i class="fas fa-redo me-2"></i> Try Again
                </a>
            </div>
            
            <!-- Additional info -->
            <div class="mt-5 p-4 text-start bg-gray-800 rounded-lg border border-gray-700">
                <h3 class="text-white mb-3 fs-5">What you can do:</h3>
                <ul class="text-gray-300 mb-0" style="color: #9ca3af;">
                    <li class="mb-2">Refresh the page to try again</li>
                    <li class="mb-2">Try again in a few minutes</li>
                    <li class="mb-2">Check if you're still connected to the internet</li>
                    <li class="mb-2">Clear your browser cache and cookies</li>
                    <li>If the problem persists, please contact our support team</li>
                </ul>
            </div>
            
            <!-- Support contact -->
            <div class="mt-4">
                <a href="/contact" class="btn btn-sm btn-outline-light">
                    <i class="fas fa-headset me-2"></i> Contact Support
                </a>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="py-4 text-center text-muted">
        <div class="container">
            <p class="mb-0">
                &copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($siteName); ?>. All rights reserved.
                <a href="/" class="text-decoration-none text-muted">Home</a> | 
                <a href="/contact" class="text-decoration-none text-muted">Contact</a> | 
                <a href="/terms" class="text-decoration-none text-muted">Terms</a>
            </p>
        </div>
    </footer>
</body>
</html>