<?php
// This file should be placed at /admin/ajax/get_order_details.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Unauthorized access']);
    exit;
}

// Set response header
header('Content-Type: application/json');

// Check for ID parameter
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid order ID']);
    exit;
}

$orderId = (int)$_GET['id'];
$db = getDB();
$conn = $db->getConnection();

// Get detailed order information
$stmt = $conn->prepare("
    SELECT ro.*, u.username, u.email, rp.name as panel_name, rp.price as panel_price 
    FROM reseller_orders ro
    JOIN users u ON ro.user_id = u.id
    JOIN reseller_panels rp ON ro.panel_id = rp.id
    WHERE ro.id = ?
");
$stmt->bind_param("i", $orderId);
$stmt->execute();
$result = $stmt->get_result();
$order = $result->fetch_assoc();

if (!$order) {
    echo json_encode(['success' => false, 'message' => 'Order not found']);
    exit;
}

// Decode addons if present
if (isset($order['addons']) && !empty($order['addons'])) {
    $decodedAddons = json_decode($order['addons'], true);
    
    // Fetch addon details for each addon ID
    if (!empty($decodedAddons)) {
        foreach ($decodedAddons as &$addon) {
            if (isset($addon['id'])) {
                $addonId = $addon['id'];
                $stmt = $conn->prepare("SELECT name FROM reseller_addons WHERE id = ?");
                $stmt->bind_param("i", $addonId);
                $stmt->execute();
                $addonResult = $stmt->get_result();
                $addonInfo = $addonResult->fetch_assoc();
                
                if ($addonInfo) {
                    $addon['name'] = $addonInfo['name'];
                } else {
                    $addon['name'] = 'Unknown Add-on';
                }
            }
        }
    }
    $order['addons_decoded'] = $decodedAddons;
} else {
    $order['addons_decoded'] = [];
}

// Add currency symbol
$order['currency'] = getSetting('currency', '₦');

// Return success response with order data
echo json_encode(['success' => true, 'order' => $order]);