<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized access'
    ]);
    exit;
}

// Get provider ID
$providerId = isset($_GET['provider_id']) ? (int)$_GET['provider_id'] : 0;

if (!$providerId) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Missing provider ID'
    ]);
    exit;
}

// Get DB connection
$db = getDB();
$conn = $db->getConnection();

// Get provider services
$services = [];
$stmt = $conn->prepare("
    SELECT * FROM api_provider_services 
    WHERE provider_id = ?
");
$stmt->bind_param("i", $providerId);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $serviceKey = $row['service_type'];
    if ($row['network_id']) {
        $serviceKey .= '_' . $row['network_id'];
    }
    $services[] = $serviceKey;
}

header('Content-Type: application/json');
echo json_encode([
    'success' => true,
    'services' => $services
]);
?>