<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/api/APIManager.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized access'
    ]);
    exit;
}

// Get provider ID
$providerId = isset($_GET['provider_id']) ? (int)$_GET['provider_id'] : 0;

if (!$providerId) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Missing provider ID'
    ]);
    exit;
}

// Get DB connection
$db = getDB();
$conn = $db->getConnection();

// Get API manager
$apiManager = new APIManager($db);

// Get the provider
$provider = $apiManager->getProvider($providerId);

if (!$provider) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Provider not found'
    ]);
    exit;
}

// Test the connection by checking balance
$result = $provider->checkBalance();

header('Content-Type: application/json');

if ($result['success']) {
    echo json_encode([
        'success' => true,
        'message' => 'Connection successful',
        'balance' => getSetting('currency') . number_format($result['data']['balance'], 2)
    ]);
} else {
    echo json_encode([
        'success' => false,
        'message' => $result['message']
    ]);
}
?>