<?php
// File: admin/scripts/populate_api_ids.php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    die("Admin authentication required");
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Populate network API IDs
$stmt = $conn->prepare("SELECT id FROM networks WHERE api_id IS NULL");
$stmt->execute();
$result = $stmt->get_result();

$counter = 1;
while ($row = $result->fetch_assoc()) {
    $networkId = $row['id'];
    
    // Find the next available API ID
    $stmt2 = $conn->prepare("SELECT MAX(api_id) as max_id FROM networks");
    $stmt2->execute();
    $maxResult = $stmt2->get_result()->fetch_assoc();
    $nextId = ($maxResult['max_id'] ?? 0) + 1;
    
    // Update network with new API ID
    $stmt3 = $conn->prepare("UPDATE networks SET api_id = ? WHERE id = ?");
    $stmt3->bind_param("ii", $nextId, $networkId);
    $stmt3->execute();
    
    echo "Updated network ID $networkId with API ID $nextId<br>";
    $counter++;
}

// Populate data plan API IDs
$stmt = $conn->prepare("SELECT id FROM data_plans WHERE api_plan_id IS NULL");
$stmt->execute();
$result = $stmt->get_result();

$counter = 1;
while ($row = $result->fetch_assoc()) {
    $planId = $row['id'];
    
    // Generate a unique plan ID
    $apiPlanId = 'DP' . str_pad($counter, 3, '0', STR_PAD_LEFT);
    
    // Verify uniqueness
    $stmt2 = $conn->prepare("SELECT id FROM data_plans WHERE api_plan_id = ?");
    $stmt2->bind_param("s", $apiPlanId);
    $stmt2->execute();
    
    while ($stmt2->get_result()->num_rows > 0) {
        $counter++;
        $apiPlanId = 'DP' . str_pad($counter, 3, '0', STR_PAD_LEFT);
        
        $stmt2->close();
        $stmt2 = $conn->prepare("SELECT id FROM data_plans WHERE api_plan_id = ?");
        $stmt2->bind_param("s", $apiPlanId);
        $stmt2->execute();
    }
    
    // Update plan with new API ID
    $stmt3 = $conn->prepare("UPDATE data_plans SET api_plan_id = ? WHERE id = ?");
    $stmt3->bind_param("si", $apiPlanId, $planId);
    $stmt3->execute();
    
    echo "Updated data plan ID $planId with API plan ID $apiPlanId<br>";
    $counter++;
}

echo "Population complete!";
?>