<?php
// File: /admin/includes/admin_header.php
// Ensure this is included after config.php and functions.php
if (!isset($admin) || !$admin) {
    // If admin not loaded yet, get admin info
    $adminId = $_SESSION['admin_id'] ?? 0;
    $db = getDB();
    $conn = $db->getConnection();

    $stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
    $stmt->bind_param("i", $adminId);
    $stmt->execute();
    $result = $stmt->get_result();
    $admin = $result->fetch_assoc();

    if (!$admin) {
        // If admin not found, log out
        session_destroy();
        redirect(ADMIN_URL . '/login.php');
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo isset($pageTitle) ? $pageTitle . ' - ' : ''; ?>Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active, .status-successful {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive, .status-canceled {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
        
        .status-pending {
            background-color: rgba(245, 158, 11, 0.3);
            color: #fcd34d;
        }
        
        .status-failed {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 44px;
            height: 24px;
        }

        .toggle-switch input { 
            opacity: 0;
            width: 0;
            height: 0;
        }

        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #555;
            transition: .4s;
            border-radius: 24px;
        }

        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 18px;
            width: 18px;
            left: 3px;
            bottom: 3px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }

        input:checked + .toggle-slider {
            background-color: var(--accent-color);
        }

        input:checked + .toggle-slider:before {
            transform: translateX(20px);
        }
        
        <?php if (isset($extraStyles)): ?>
        <?php echo $extraStyles; ?>
        <?php endif; ?>
    </style>
    <?php if (isset($headerScripts)): ?>
    <?php echo $headerScripts; ?>
    <?php endif; ?>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'index.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'users.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'transactions.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'data_plans.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_types.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'data_types.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-layer-group mr-3"></i>
                                <span>Data Types</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/airtime_networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'airtime_networks.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-phone mr-3"></i>
                                <span>Airtime Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'networks.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'api_settings.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'general.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'email.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'payment.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'providers.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-plug mr-3"></i>
                                <span>Providers</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo basename($_SERVER['SCRIPT_NAME']) == 'promo_codes.php' ? 'bg-gray-700' : ''; ?>">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <!-- Page title will be here -->
            <?php if (!empty($pageTitle)): ?>
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white"><?php echo htmlspecialchars($pageTitle); ?></h1>
                <?php if (isset($headerButton)): ?>
                <?php echo $headerButton; ?>
                <?php endif; ?>
            </div>
            <?php endif; ?>
            
            <!-- Flash messages -->
            <?php 
            $flashMessage = getFlashMessage();
            $error = isset($error) ? $error : '';
            $success = isset($success) ? $success : '';
            
            if ($flashMessage) {
                if ($flashMessage['type'] === 'success') {
                    $success = $flashMessage['message'];
                } else {
                    $error = $flashMessage['message'];
                }
            }
            ?>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>