<?php
/**
 * Admin Panel Sidebar Navigation
 * 
 * This file contains the sidebar navigation for the admin panel.
 * Include this file in all admin pages to maintain consistent navigation.
 * 
 * USAGE:
 * 1. First set the $currentPage variable before including this file
 *    e.g. $currentPage = 'dashboard'; // or 'users', 'transactions', etc.
 * 
 * 2. Then include this file:
 *    require_once '../includes/sidebar.php';
 * 
 * TO ADD NEW MENU ITEMS:
 * - Copy an existing <li> element and modify:
 *   - href: The URL to the page
 *   - $currentPage comparison: Add the page identifier to make highlighting work
 *   - icon: Change the Font Awesome icon class
 *   - text: The menu item text
 * 
 * Example of a menu item:
 * <li>
 *    <a href="<?php echo ADMIN_URL; ?>/your_page.php" 
 *       class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 
 *              <?php echo $currentPage === 'your_page' ? 'bg-gray-700' : ''; ?>">
 *       <i class="fas fa-icon-name mr-3"></i>
 *       <span>Menu Item Text</span>
 *    </a>
 * </li>
 */

// If $currentPage is not set, default to empty to avoid errors
if (!isset($currentPage)) {
    $currentPage = '';
}
?>

<aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
    <nav class="p-4">
        <div class="mb-4">
            <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
            <ul class="space-y-2">
                <li>
                    <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'dashboard' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-tachometer-alt mr-3"></i>
                        <span>Dashboard</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'users' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-users mr-3"></i>
                        <span>Users</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'transactions' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-exchange-alt mr-3"></i>
                        <span>Transactions</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/send_notification.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'send_notification' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-bell mr-3"></i>
                        <span>Notifications</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'support_tickets' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-ticket-alt mr-3"></i>
                        <span>Support Tickets</span>
                    </a>
                </li>
            </ul>
        </div>
        
        <div class="mb-4">
            <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
            <ul class="space-y-2">
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'data_plans' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-wifi mr-3"></i>
                        <span>Data Plans</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/services/data_types.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'data_types' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-layer-group mr-3"></i>
                        <span>Data Types</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/services/airtime_networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'airtime' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-phone mr-3"></i>
                        <span>Airtime Networks</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'networks' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-network-wired mr-3"></i>
                        <span>Networks</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'api_settings' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-cogs mr-3"></i>
                        <span>API Settings</span>
                    </a>
                </li>
            </ul>
        </div>
        
        <div class="mb-4">
            <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
            <ul class="space-y-2">
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'reseller_panels' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-store mr-3"></i>
                        <span>Panels</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'reseller_orders' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-shopping-cart mr-3"></i>
                        <span>Orders</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'form_fields' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-list-alt mr-3"></i>
                        <span>Form Fields</span>
                    </a>
                </li>
            </ul>
        </div>
        
        <div class="mb-4">
            <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
            <ul class="space-y-2">
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'settings_general' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-sliders-h mr-3"></i>
                        <span>General Settings</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'settings_email' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-envelope mr-3"></i>
                        <span>Email Settings</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'settings_payment' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-credit-card mr-3"></i>
                        <span>Payment Settings</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'providers' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-plug mr-3"></i>
                        <span>Providers</span>
                    </a>
                </li>
            </ul>
        </div>
        
        <div>
            <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
            <ul class="space-y-2">
                <li>
                    <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 <?php echo $currentPage === 'promo_codes' ? 'bg-gray-700' : ''; ?>">
                        <i class="fas fa-gift mr-3"></i>
                        <span>Promo Codes</span>
                    </a>
                </li>
                <li>
                    <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                        <i class="fas fa-external-link-alt mr-3"></i>
                        <span>View Site</span>
                    </a>
                </li>
            </ul>
        </div>
    </nav>
</aside>