<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get user ID from query parameters
$userId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($userId <= 0) {
    setFlashMessage('Invalid user ID', 'error');
    redirect(ADMIN_URL . '/users.php');
}

// Get admin data for logging
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT username FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Check if user exists and is active
$stmt = $conn->prepare("SELECT id, username, status FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    setFlashMessage('User not found', 'error');
    redirect(ADMIN_URL . '/users.php');
}

if ($user['status'] !== 'active') {
    setFlashMessage('Cannot login as an inactive user', 'error');
    redirect(ADMIN_URL . '/view_user.php?id=' . $userId);
}

// Log this action for security and auditing
$action = "Admin login as user";
$details = "Admin '{$admin['username']}' (ID: {$adminId}) logged in as user '{$user['username']}' (ID: {$userId})";
$ipAddress = $_SERVER['REMOTE_ADDR'];

$stmt = $conn->prepare("
    INSERT INTO admin_logs 
    (admin_id, action, details, ip_address, user_id)
    VALUES (?, ?, ?, ?, ?)
");
$stmt->bind_param("isssi", $adminId, $action, $details, $ipAddress, $userId);
$stmt->execute();

// Store the admin's session data temporarily
$_SESSION['admin_impersonating'] = true;
$_SESSION['admin_id_original'] = $adminId;
$_SESSION['admin_session_data'] = $_SESSION;

// Clear current session and set new session for user
session_regenerate_id(true);
$_SESSION = [];
$_SESSION['user_id'] = $userId;
$_SESSION['username'] = $user['username'];
$_SESSION['admin_impersonating'] = true;
$_SESSION['last_activity'] = time();

// Redirect to user dashboard
redirect(SITE_URL . '/dashboard/');
?>