<?php
// File: admin/reward/index.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get reward system stats
$stmt = $conn->prepare("
    SELECT 
        (SELECT COUNT(*) FROM referrals WHERE status = 'completed') as completed_referrals,
        (SELECT COUNT(*) FROM referrals WHERE status = 'qualified') as qualified_referrals,
        (SELECT COUNT(*) FROM referrals WHERE status = 'pending') as pending_referrals,
        (SELECT COUNT(*) FROM referral_contests WHERE is_active = 1 AND start_date <= NOW() AND end_date >= NOW()) as active_contests,
        (SELECT SUM(referral_earnings) FROM users) as total_referral_payouts
");
$stmt->execute();
$stats = $stmt->fetch_assoc();

// Set current page for nav highlighting
$currentPage = 'rewards';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Rewards Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .tab-button {
            padding: 0.5rem 1rem;
            font-weight: 500;
            border-bottom: 2px solid transparent;
        }
        
        .tab-button.active {
            color: var(--accent-color);
            border-bottom-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <!-- Tabs -->
            <div class="border-b border-gray-700 mb-4">
                <div class="flex space-x-4">
                    <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="tab-button">
                        <i class="fas fa-trophy mr-2"></i> Achievements
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/referral.php" class="tab-button">
                        <i class="fas fa-user-plus mr-2"></i> Referrals
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="tab-button">
                        <i class="fas fa-award mr-2"></i> Contests
                    </a>
                </div>
            </div>
            
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Rewards Management</h1>
            </div>
            
            <!-- Stats Cards -->
            <div class="grid grid-cols-1 md:grid-cols-5 gap-6 mb-8">
                <!-- Completed Referrals -->
                <div class="admin-card rounded-lg shadow p-4 bg-green-900 bg-opacity-20 border border-green-500">
                    <div class="flex items-center mb-2">
                        <div class="w-10 h-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-check-circle text-green-400"></i>
                        </div>
                        <h3 class="text-white font-medium">Completed Referrals</h3>
                    </div>
                    <div class="text-3xl font-bold text-white"><?php echo $stats['completed_referrals'] ?? 0; ?></div>
                </div>
                
                <!-- Qualified Referrals -->
                <div class="admin-card rounded-lg shadow p-4 bg-yellow-900 bg-opacity-20 border border-yellow-500">
                    <div class="flex items-center mb-2">
                        <div class="w-10 h-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-hourglass-half text-yellow-400"></i>
                        </div>
                        <h3 class="text-white font-medium">Ready to Claim</h3>
                    </div>
                    <div class="text-3xl font-bold text-white"><?php echo $stats['qualified_referrals'] ?? 0; ?></div>
                </div>
                
                <!-- Pending Referrals -->
                <div class="admin-card rounded-lg shadow p-4 bg-blue-900 bg-opacity-20 border border-blue-500">
                    <div class="flex items-center mb-2">
                        <div class="w-10 h-10 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-clock text-blue-400"></i>
                        </div>
                        <h3 class="text-white font-medium">Pending Referrals</h3>
                    </div>
                    <div class="text-3xl font-bold text-white"><?php echo $stats['pending_referrals'] ?? 0; ?></div>
                </div>
                
                <!-- Active Contests -->
                <div class="admin-card rounded-lg shadow p-4 bg-purple-900 bg-opacity-20 border border-purple-500">
                    <div class="flex items-center mb-2">
                        <div class="w-10 h-10 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-trophy text-purple-400"></i>
                        </div>
                        <h3 class="text-white font-medium">Active Contests</h3>
                    </div>
                    <div class="text-3xl font-bold text-white"><?php echo $stats['active_contests'] ?? 0; ?></div>
                </div>
                
                <!-- Total Payouts -->
                <div class="admin-card rounded-lg shadow p-4 bg-indigo-900 bg-opacity-20 border border-indigo-500">
                    <div class="flex items-center mb-2">
                        <div class="w-10 h-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-coins text-indigo-400"></i>
                        </div>
                        <h3 class="text-white font-medium">Total Payouts</h3>
                    </div>
                    <div class="text-3xl font-bold text-white"><?php echo formatAmount($stats['total_referral_payouts'] ?? 0); ?></div>
                </div>
            </div>
            
            <!-- Quick Links -->
            <div class="grid grid-cols-1 md:grid-cols-3 gap-6 mb-8">
                <!-- Manage Referrals -->
                <a href="<?php echo ADMIN_URL; ?>/reward/referral.php" class="admin-card rounded-lg shadow p-6 bg-indigo-900 bg-opacity-10 border border-indigo-500 hover:bg-indigo-900 hover:bg-opacity-20 transition-all">
                    <div class="w-16 h-16 mb-4 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center">
                        <i class="fas fa-user-plus text-2xl text-indigo-400"></i>
                    </div>
                    <h3 class="text-xl font-semibold text-white mb-2">Manage Referrals</h3>
                    <p class="text-gray-400 mb-4">View and manage all user referrals, approve or reject referrals, and adjust rewards.</p>
                    <div class="flex items-center text-indigo-400">
                        <span>Manage Referrals</span>
                        <i class="fas fa-arrow-right ml-2"></i>
                    </div>
                </a>
                
                <!-- Create Contest -->
                <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="admin-card rounded-lg shadow p-6 bg-purple-900 bg-opacity-10 border border-purple-500 hover:bg-purple-900 hover:bg-opacity-20 transition-all">
                    <div class="w-16 h-16 mb-4 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center">
                        <i class="fas fa-trophy text-2xl text-purple-400"></i>
                    </div>
                    <h3 class="text-xl font-semibold text-white mb-2">Create Contest</h3>
                    <p class="text-gray-400 mb-4">Create and manage referral contests, set entry fees, and configure elimination rules.</p>
                    <div class="flex items-center text-purple-400">
                        <span>Manage Contests</span>
                        <i class="fas fa-arrow-right ml-2"></i>
                    </div>
                </a>
                
                <!-- Manage Achievements -->
                <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="admin-card rounded-lg shadow p-6 bg-green-900 bg-opacity-10 border border-green-500 hover:bg-green-900 hover:bg-opacity-20 transition-all">
                    <div class="w-16 h-16 mb-4 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center">
                        <i class="fas fa-medal text-2xl text-green-400"></i>
                    </div>
                    <h3 class="text-xl font-semibold text-white mb-2">Manage Achievements</h3>
                    <p class="text-gray-400 mb-4">Create and manage user achievements, set requirements, and define rewards.</p>
                    <div class="flex items-center text-green-400">
                        <span>Manage Achievements</span>
                        <i class="fas fa-arrow-right ml-2"></i>
                    </div>
                </a>
            </div>
            
            <!-- Reward Settings -->
            <div class="admin-card rounded-lg shadow p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Quick Settings</h2>
                
                <?php
                // Get current referral reward setting
                $referralReward = getSetting('referral_reward', 100);
                ?>
                
                <form action="<?php echo ADMIN_URL; ?>/settings_update.php" method="POST" class="mb-4">
                    <input type="hidden" name="setting_type" value="reward">
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <div>
                            <label for="referral_reward" class="block text-sm font-medium text-gray-400 mb-1">Default Referral Reward (₦)</label>
                            <div class="flex">
                                <input type="number" id="referral_reward" name="referral_reward" class="form-input block w-full rounded-l-md bg-gray-700 border-gray-600 text-white" 
                                       value="<?php echo $referralReward; ?>" min="0" step="1">
                                <button type="submit" class="accent-button px-4 rounded-r-md text-white">
                                    Update
                                </button>
                            </div>
                            <p class="text-sm text-gray-500 mt-1">Default reward amount for each successful referral</p>
                        </div>
                    </div>
                </form>
                
                <div class="mt-4">
                    <a href="<?php echo ADMIN_URL; ?>/settings.php?tab=rewards" class="text-indigo-400 hover:text-indigo-300">
                        <i class="fas fa-cog mr-2"></i> View All Reward Settings
                    </a>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', function() {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', function(e) {
            if (!profileButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
    </script>
</body>
</html>