<?php
// File: /admin/services/get_data_types.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'Unauthorized']);
    exit;
}

// Get network ID from query params
$network_id = isset($_GET['network_id']) ? (int)$_GET['network_id'] : 0;

if ($network_id <= 0) {
    echo json_encode(['success' => false, 'message' => 'Invalid network ID']);
    exit;
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get all data types for the selected network
$data_types = [];
$stmt = $conn->prepare("SELECT id, name FROM data_types WHERE network_id = ? AND status = 'active' ORDER BY sort_order ASC, name ASC");
$stmt->bind_param("i", $network_id);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $data_types[] = $row;
}

// Return data types as JSON
echo json_encode([
    'success' => true,
    'data_types' => $data_types
]);
?>