<?php
// File: admin/services/service_ids.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../admin_auth.php';

$pageTitle = 'Service IDs Reference';
require_once '../includes/header.php';

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get all networks
$networks = [];
$stmt = $conn->prepare("SELECT id, name, api_id FROM networks WHERE status = 'active' ORDER BY name");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Get all data plans with detailed information
$dataPlans = [];
$stmt = $conn->prepare("
    SELECT dp.id, dp.name, dp.plan_id, dp.size, dp.validity, dp.api_plan_id,
           dp.price, dp.amount_api, dp.amount_smart, dp.amount_vendor,
           dt.name as data_type, n.name as network_name, n.id as network_id
    FROM data_plans dp
    JOIN data_types dt ON dp.data_type_id = dt.id
    JOIN networks n ON dt.network_id = n.id
    WHERE dp.status = 'active'
    ORDER BY n.name, dt.name, dp.price
");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $dataPlans[] = $row;
}

// Group data plans by network
$plansByNetwork = [];
foreach ($dataPlans as $plan) {
    if (!isset($plansByNetwork[$plan['network_name']])) {
        $plansByNetwork[$plan['network_name']] = [];
    }
    $plansByNetwork[$plan['network_name']][] = $plan;
}
?>

<div class="container px-6 mx-auto grid">
    <h2 class="my-6 text-2xl font-semibold text-gray-700 dark:text-gray-200">
        Service IDs Reference
    </h2>
    
    <div class="mb-8 bg-white rounded-lg shadow-md dark:bg-gray-800">
        <div class="p-4 border-b">
            <h2 class="text-lg font-semibold text-gray-600 dark:text-gray-300">
                Network IDs
            </h2>
            <p class="text-sm text-gray-500 dark:text-gray-400">
                These IDs are used in API requests for network identification
            </p>
        </div>
        <div class="p-4 overflow-x-auto">
            <table class="w-full whitespace-nowrap">
                <thead>
                    <tr class="text-xs font-semibold tracking-wide text-left text-gray-500 uppercase border-b dark:border-gray-700 bg-gray-50 dark:text-gray-400 dark:bg-gray-800">
                        <th class="px-4 py-3">ID</th>
                        <th class="px-4 py-3">API ID (v1/v2)</th>
                        <th class="px-4 py-3">Network Name</th>
                    </tr>
                </thead>
                <tbody class="bg-white divide-y dark:divide-gray-700 dark:bg-gray-800">
                    <?php foreach ($networks as $network): ?>
                    <tr class="text-gray-700 dark:text-gray-400">
                        <td class="px-4 py-3"><?php echo $network['id']; ?></td>
                        <td class="px-4 py-3 font-mono"><?php echo $network['api_id']; ?></td>
                        <td class="px-4 py-3"><?php echo htmlspecialchars($network['name']); ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <div class="mb-8">
        <h2 class="text-lg font-semibold text-gray-600 dark:text-gray-300 mb-4">
            Data Plan IDs by Network
        </h2>
        
        <div class="mb-4">
            <div class="border-b border-gray-200 dark:border-gray-700">
                <ul class="flex flex-wrap -mb-px" id="networkTabs" role="tablist">
                    <?php $firstNetwork = true; foreach (array_keys($plansByNetwork) as $networkName): ?>
                    <li class="mr-2" role="presentation">
                        <button class="inline-block p-4 border-b-2 rounded-t-lg <?php echo $firstNetwork ? 'text-blue-600 border-blue-600 dark:text-blue-500 dark:border-blue-500' : 'border-transparent hover:text-gray-600 hover:border-gray-300 dark:hover:text-gray-300'; ?>" 
                                id="<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>-tab" 
                                data-tabs-target="#<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>" 
                                type="button" 
                                role="tab" 
                                aria-controls="<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>" 
                                aria-selected="<?php echo $firstNetwork ? 'true' : 'false'; ?>">
                            <?php echo htmlspecialchars($networkName); ?>
                        </button>
                    </li>
                    <?php $firstNetwork = false; endforeach; ?>
                </ul>
            </div>
            
            <?php $firstNetwork = true; foreach ($plansByNetwork as $networkName => $plans): ?>
            <div class="<?php echo $firstNetwork ? 'block' : 'hidden'; ?> p-4 rounded-lg bg-white dark:bg-gray-800" 
                 id="<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>" 
                 role="tabpanel" 
                 aria-labelledby="<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>-tab">
                
                <div class="overflow-x-auto">
                    <table class="w-full whitespace-nowrap">
                        <thead>
                            <tr class="text-xs font-semibold tracking-wide text-left text-gray-500 uppercase border-b dark:border-gray-700 bg-gray-50 dark:text-gray-400 dark:bg-gray-800">
                                <th class="px-4 py-3">Internal ID</th>
                                <th class="px-4 py-3">Plan ID (API v1/v2)</th>
                                <th class="px-4 py-3">API Plan ID (Provider)</th>
                                <th class="px-4 py-3">Data Type</th>
                                <th class="px-4 py-3">Name</th>
                                <th class="px-4 py-3">Size</th>
                                <th class="px-4 py-3">Validity</th>
                                <th class="px-4 py-3">Base Price</th>
                                <th class="px-4 py-3">API Price</th>
                            </tr>
                        </thead>
                        <tbody class="bg-white divide-y dark:divide-gray-700 dark:bg-gray-800">
                            <?php foreach ($plans as $plan): ?>
                            <tr class="text-gray-700 dark:text-gray-400">
                                <td class="px-4 py-3"><?php echo $plan['id']; ?></td>
                                <td class="px-4 py-3 font-mono font-bold text-green-600 dark:text-green-400"><?php echo $plan['plan_id']; ?></td>
                                <td class="px-4 py-3 font-mono"><?php echo $plan['api_plan_id'] ?? 'N/A'; ?></td>
                                <td class="px-4 py-3"><?php echo htmlspecialchars($plan['data_type']); ?></td>
                                <td class="px-4 py-3"><?php echo htmlspecialchars($plan['name']); ?></td>
                                <td class="px-4 py-3"><?php echo htmlspecialchars($plan['size']); ?></td>
                                <td class="px-4 py-3"><?php echo htmlspecialchars($plan['validity']); ?></td>
                                <td class="px-4 py-3"><?php echo formatAmount($plan['price']); ?></td>
                                <td class="px-4 py-3"><?php echo formatAmount($plan['amount_api'] > 0 ? $plan['amount_api'] : $plan['price']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php $firstNetwork = false; endforeach; ?>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        // Tab switching functionality
        const tabs = document.querySelectorAll('[data-tabs-target]');
        const tabContents = document.querySelectorAll('[role="tabpanel"]');
        
        tabs.forEach(tab => {
            tab.addEventListener('click', () => {
                const target = document.querySelector(tab.dataset.tabsTarget);
                
                tabContents.forEach(tabContent => {
                    tabContent.classList.add('hidden');
                });
                
                tabs.forEach(t => {
                    t.classList.remove('text-blue-600', 'border-blue-600', 'dark:text-blue-500', 'dark:border-blue-500');
                    t.classList.add('border-transparent', 'hover:text-gray-600', 'hover:border-gray-300', 'dark:hover:text-gray-300');
                    t.setAttribute('aria-selected', false);
                });
                
                tab.classList.remove('border-transparent', 'hover:text-gray-600', 'hover:border-gray-300', 'dark:hover:text-gray-300');
                tab.classList.add('text-blue-600', 'border-blue-600', 'dark:text-blue-500', 'dark:border-blue-500');
                tab.setAttribute('aria-selected', true);
                
                target.classList.remove('hidden');
            });
        });
    });
</script>

<?php require_once '../includes/footer.php'; ?>