<?php
// File: admin/scripts/populate_plan_ids.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    die("Admin authentication required");
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Begin transaction
$conn->begin_transaction();

try {
    // Reset the sequence
    $stmt = $conn->prepare("UPDATE sequences SET value = 0 WHERE name = 'data_plan_seq'");
    $stmt->execute();
    
    // Get all data plans that need plan_id
    $stmt = $conn->prepare("SELECT id FROM data_plans WHERE plan_id IS NULL ORDER BY network_id, data_type_id, price");
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Assign sequential IDs
    $counter = 1;
    while ($row = $result->fetch_assoc()) {
        $planId = $row['id'];
        
        // Update plan with new plan_id
        $stmt2 = $conn->prepare("UPDATE data_plans SET plan_id = ? WHERE id = ?");
        $stmt2->bind_param("ii", $counter, $planId);
        $stmt2->execute();
        
        echo "Updated data plan ID $planId with plan_id $counter<br>";
        $counter++;
    }
    
    // Update the sequence to match the last used ID
    $stmt = $conn->prepare("UPDATE sequences SET value = ? WHERE name = 'data_plan_seq'");
    $stmt->bind_param("i", $counter);
    $stmt->execute();
    
    // Commit all changes
    $conn->commit();
    
    echo "<p>Successfully populated plan_ids for " . ($counter - 1) . " data plans.</p>";
    echo "<p>Current sequence value is now: " . ($counter) . "</p>";
} catch (Exception $e) {
    // Rollback on error
    $conn->rollback();
    echo "Error: " . $e->getMessage();
}
?>