<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $paystackPublicKey = sanitizeInput($_POST['paystack_public_key']);
    $paystackSecretKey = sanitizeInput($_POST['paystack_secret_key']);
    
    // Update settings
    updateSetting('paystack_public_key', $paystackPublicKey);
    updateSetting('paystack_secret_key', $paystackSecretKey);
    
    // Set flash message
    setFlashMessage('Paystack settings updated successfully', 'success');
    
    // Log the update
    error_log("Paystack settings updated. Public Key: " . substr($paystackPublicKey, 0, 10) . "..., Secret Key: " . substr($paystackSecretKey, 0, 5) . "...");
    
    // Redirect to prevent form resubmission
    header("Location: " . ADMIN_URL . "/settings/payment.php");
    exit;
}

// Current paystack settings
$paystackPublicKey = getSetting('paystack_public_key');
$paystackSecretKey = getSetting('paystack_secret_key');
?>

<div class="admin-card rounded-lg shadow-md p-6 mb-6">
    <h2 class="text-xl font-semibold text-white mb-4">Paystack Settings</h2>
    
    <form method="POST" action="">
        <div class="mb-4">
            <label for="paystack_public_key" class="block text-sm font-medium text-gray-400 mb-1">Paystack Public Key</label>
            <input type="text" id="paystack_public_key" name="paystack_public_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackPublicKey); ?>" required>
            <p class="mt-1 text-xs text-gray-500">Enter your Paystack public key. Get it from your Paystack dashboard.</p>
        </div>
        
        <div class="mb-6">
            <label for="paystack_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Paystack Secret Key</label>
            <input type="text" id="paystack_secret_key" name="paystack_secret_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackSecretKey); ?>" required>
            <p class="mt-1 text-xs text-gray-500">Enter your Paystack secret key. Keep this confidential.</p>
        </div>
        
        <div class="flex justify-end">
            <button type="submit" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                Save Paystack Settings
            </button>
        </div>
    </form>
</div>