<?php
// File: /api/v1/index.php (Main API Router)
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../api_functions.php';

// Enable error reporting for debugging (remove in production)
ini_set('display_errors', 0);
error_log('API Request: ' . $_SERVER['REQUEST_METHOD'] . ' ' . $_SERVER['REQUEST_URI']);

// Set headers for JSON API
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, X-API-KEY');

// Handle preflight requests
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Authenticate the request
$authResult = authenticateApiRequest();
if (!$authResult['success']) {
    http_response_code(401);
    echo json_encode([
        'status' => 'error',
        'error' => 'UNAUTHORIZED',
        'message' => $authResult['message']
    ]);
    exit;
}

// Get the authenticated user
$apiUser = $authResult['user'];

// Parse the request path
$requestUri = $_SERVER['REQUEST_URI'];
$basePath = parse_url(SITE_URL, PHP_URL_PATH) . '/api/v1/';
$path = str_replace($basePath, '', $requestUri);
$path = strtok($path, '?'); // Remove query string
$path = trim($path, '/');

// Route the request to the appropriate handler
$method = $_SERVER['REQUEST_METHOD'];

try {
    // Account endpoints
    if ($path === 'balance' && $method === 'GET') {
        getBalance($apiUser);
    } elseif ($path === 'profile' && $method === 'GET') {
        getProfile($apiUser);
    }
    // Data service endpoints
    elseif ($path === 'data/plans' && $method === 'GET') {
        getDataPlans($apiUser);
    } elseif ($path === 'data/buy' && $method === 'POST') {
        buyData($apiUser);
    }
    // Airtime service endpoints
    elseif ($path === 'airtime/buy' && $method === 'POST') {
        buyAirtime($apiUser);
    }
    // Transaction endpoints
    elseif ($path === 'transactions' && $method === 'GET') {
        getTransactions($apiUser);
    } elseif (preg_match('/^transactions\/(\d+)$/', $path, $matches) && $method === 'GET') {
        getTransaction($apiUser, $matches[1]);
    }
    // If no route matches
    else {
        http_response_code(404);
        echo json_encode([
            'status' => 'error',
            'error' => 'NOT_FOUND',
            'message' => 'The requested endpoint does not exist'
        ]);
    }
} catch (Exception $e) {
    http_response_code(500);
    error_log('API Error: ' . $e->getMessage());
    echo json_encode([
        'status' => 'error',
        'error' => 'INTERNAL_SERVER_ERROR',
        'message' => 'An unexpected error occurred'
    ]);
}
?>