<?php
// Include the configuration file
require_once $_SERVER['DOCUMENT_ROOT'] . '/includes/config.php';

// Connect to the database
try {
    $db = new PDO("mysql:host=" . DB_HOST . ";dbname=" . DB_NAME, DB_USER, DB_PASS);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Connection failed: " . $e->getMessage());
}

// Fetch all changelog entries, ordered by version (newest first)
try {
    $query = "SELECT * FROM changelog_entries ORDER BY STR_TO_DATE(CONCAT('01-', REPLACE(version, '.', '-')), '%d-%m-%Y') DESC, id DESC";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $changelog_entries = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Error fetching changelog entries: " . $e->getMessage());
}

// Function to determine the badge color based on entry type
function getBadgeClass($type) {
    switch (strtolower($type)) {
        case 'feature':
            return 'bg-success';
        case 'improvement':
            return 'bg-info';
        case 'bug fix':
            return 'bg-warning';
        case 'security':
            return 'bg-danger';
        default:
            return 'bg-secondary';
    }
}

// Group changelog entries by major version
$grouped_entries = [];
foreach ($changelog_entries as $entry) {
    // Extract major version (e.g., 1.0 from 1.0.1)
    $version_parts = explode('.', $entry['version']);
    $major_version = $version_parts[0] . '.' . $version_parts[1];
    
    if (!isset($grouped_entries[$major_version])) {
        $grouped_entries[$major_version] = [];
    }
    
    $grouped_entries[$major_version][] = $entry;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>VTU Platform - Changelog</title>
    
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    
    <style>
        :root {
            --primary-color: #5D5CDE;
            --secondary-color: #6c757d;
            --light-bg: #ffffff;
            --dark-bg: #181818;
            --light-text: #212529;
            --dark-text: #f8f9fa;
        }
        
        body {
            background-color: var(--light-bg);
            color: var(--light-text);
            transition: all 0.3s ease;
            padding-top: 80px;
        }
        
        body.dark-mode {
            background-color: var(--dark-bg);
            color: var(--dark-text);
        }
        
        .navbar {
            background-color: var(--primary-color);
        }
        
        .navbar-brand, .nav-link {
            color: white !important;
        }
        
        .changelog-container {
            max-width: 900px;
            margin: 0 auto;
        }
        
        .version-card {
            border-radius: 8px;
            margin-bottom: 30px;
            border: none;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: transform 0.3s ease, box-shadow 0.3s ease;
        }
        
        .dark-mode .version-card {
            background-color: #2c2c2c;
            color: var(--dark-text);
        }
        
        .version-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 15px rgba(0, 0, 0, 0.1);
        }
        
        .version-header {
            border-bottom: 1px solid #e9ecef;
            padding: 15px 20px;
        }
        
        .dark-mode .version-header {
            border-bottom: 1px solid #3a3a3a;
        }
        
        .version-title {
            margin: 0;
            font-weight: 700;
        }
        
        .version-date {
            font-size: 0.9rem;
            color: #6c757d;
        }
        
        .dark-mode .version-date {
            color: #adb5bd;
        }
        
        .version-badge {
            font-size: 0.8rem;
            padding: 5px 10px;
            border-radius: 50px;
            margin-right: 5px;
            margin-bottom: 5px;
            display: inline-block;
        }
        
        .version-content {
            padding: 20px;
        }
        
        .changelog-title {
            font-size: 1.75rem;
            margin-bottom: 30px;
            color: var(--primary-color);
            text-align: center;
        }
        
        .dark-mode .changelog-title {
            color: #7c7be1; /* Lighter version of primary color for dark mode */
        }
        
        .filter-container {
            margin-bottom: 30px;
            text-align: center;
        }
        
        .filter-btn {
            margin: 0 5px 10px;
            border-radius: 50px;
            font-size: 0.85rem;
            padding: 5px 15px;
            background-color: white;
            color: #333;
            border: 1px solid #ddd;
            transition: all 0.3s ease;
        }
        
        .dark-mode .filter-btn {
            background-color: #2c2c2c;
            color: #e9ecef;
            border: 1px solid #444;
        }
        
        .filter-btn:hover, .filter-btn.active {
            background-color: var(--primary-color);
            color: white;
            border-color: var(--primary-color);
        }
        
        .change-item {
            margin-bottom: 15px;
            position: relative;
            padding-left: 20px;
        }
        
        .change-item:before {
            content: "";
            position: absolute;
            left: 0;
            top: 10px;
            width: 8px;
            height: 8px;
            border-radius: 50%;
            background-color: var(--primary-color);
        }
        
        .change-type {
            margin-right: 8px;
        }
        
        .toggle-dark-mode {
            cursor: pointer;
            padding: 5px 10px;
            border-radius: 50px;
            background-color: transparent;
            border: 1px solid white;
            color: white;
            transition: all 0.3s ease;
        }
        
        .toggle-dark-mode:hover {
            background-color: rgba(255, 255, 255, 0.2);
        }
        
        @media (max-width: 768px) {
            body {
                padding-top: 70px;
            }
            
            .changelog-title {
                font-size: 1.5rem;
            }
            
            .version-card {
                margin-bottom: 20px;
            }
            
            .version-header {
                padding: 12px 15px;
            }
            
            .version-content {
                padding: 15px;
            }
        }
        
        footer {
            margin-top: 50px;
            background-color: var(--primary-color);
            color: white;
            padding: 20px 0;
            text-align: center;
        }
        
        .footer-links a {
            color: white;
            margin: 0 10px;
            text-decoration: none;
        }
        
        .footer-links a:hover {
            text-decoration: underline;
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg fixed-top">
        <div class="container">
            <a class="navbar-brand" href="<?php echo SITE_URL; ?>">
                <i class="fas fa-history"></i> VTU Platform Changelog
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="<?php echo SITE_URL; ?>">Home</a>
                    </li>
                    <li class="nav-item">
                        <button id="darkModeToggle" class="toggle-dark-mode">
                            <i class="fas fa-moon"></i>
                        </button>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Main content -->
    <div class="container changelog-container">
        <h1 class="changelog-title">Application Update History</h1>
        
        <!-- Filter buttons -->
        <div class="filter-container">
            <button class="filter-btn active" data-filter="all">All</button>
            <button class="filter-btn" data-filter="feature">Features</button>
            <button class="filter-btn" data-filter="improvement">Improvements</button>
            <button class="filter-btn" data-filter="bug fix">Bug Fixes</button>
            <button class="filter-btn" data-filter="security">Security</button>
        </div>
        
        <?php if (empty($changelog_entries)): ?>
            <div class="alert alert-info">No changelog entries available yet.</div>
        <?php else: ?>
            <!-- Grouped by major version -->
            <?php foreach ($grouped_entries as $major_version => $entries): ?>
                <div class="major-version-group mb-5">
                    <h2 class="mb-3">Version <?php echo htmlspecialchars($major_version); ?></h2>
                    
                    <?php foreach ($entries as $entry): ?>
                        <div class="card version-card changelog-item" data-type="<?php echo strtolower(htmlspecialchars($entry['type'])); ?>">
                            <div class="version-header">
                                <div class="d-flex justify-content-between align-items-center">
                                    <h3 class="version-title">Version <?php echo htmlspecialchars($entry['version']); ?></h3>
                                    <span class="version-date">
                                        <i class="far fa-calendar-alt"></i> 
                                        <?php echo date('F j, Y', strtotime($entry['release_date'])); ?>
                                    </span>
                                </div>
                                <div class="mt-2">
                                    <span class="badge version-badge <?php echo getBadgeClass($entry['type']); ?>">
                                        <?php echo htmlspecialchars($entry['type']); ?>
                                    </span>
                                </div>
                            </div>
                            <div class="version-content">
                                <h4><?php echo htmlspecialchars($entry['title']); ?></h4>
                                <div class="changelog-description">
                                    <?php echo $entry['description']; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>

    <!-- Footer -->
    <footer>
        <div class="container">
            <div class="footer-links">
                <a href="<?php echo SITE_URL; ?>">Home</a>
                <a href="<?php echo SITE_URL; ?>/features">Features</a>
                <a href="<?php echo SITE_URL; ?>/services">Services</a>
                <a href="<?php echo SITE_URL; ?>/contact">Contact</a>
            </div>
            <div class="mt-3">
                <p>&copy; <?php echo date('Y'); ?> VTU Platform. All rights reserved.</p>
            </div>
        </div>
    </footer>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Dark mode toggle
            const darkModeToggle = document.getElementById('darkModeToggle');
            const body = document.body;
            
            // Check user preference
            if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
                body.classList.add('dark-mode');
                darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
            }
            
            // Toggle dark mode
            darkModeToggle.addEventListener('click', function() {
                body.classList.toggle('dark-mode');
                if (body.classList.contains('dark-mode')) {
                    darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
                } else {
                    darkModeToggle.innerHTML = '<i class="fas fa-moon"></i>';
                }
            });
            
            // Listen for OS theme changes
            window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
                if (event.matches) {
                    body.classList.add('dark-mode');
                    darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
                } else {
                    body.classList.remove('dark-mode');
                    darkModeToggle.innerHTML = '<i class="fas fa-moon"></i>';
                }
            });
            
            // Filter functionality
            const filterButtons = document.querySelectorAll('.filter-btn');
            const changelogItems = document.querySelectorAll('.changelog-item');
            
            filterButtons.forEach(button => {
                button.addEventListener('click', function() {
                    // Remove active class from all buttons
                    filterButtons.forEach(btn => btn.classList.remove('active'));
                    
                    // Add active class to clicked button
                    this.classList.add('active');
                    
                    const filter = this.getAttribute('data-filter');
                    
                    // Show/hide changelog items based on filter
                    changelogItems.forEach(item => {
                        if (filter === 'all' || item.getAttribute('data-type') === filter) {
                            item.style.display = 'block';
                        } else {
                            item.style.display = 'none';
                        }
                    });
                });
            });
        });
    </script>
</body>
</html>