# SIMHOST-APP-PROJ-REQ-001
## Development Requirements Guide for SIMHOST Application

---

### **PROJECT OVERVIEW**
The SIMHOST app is a private-use mobile application designed for airtime-to-cash transactions and airtime vending operations. It will integrate with a backend hosted on `api.teleco.com.ng` and utilize SIM 1 for MTN and SIM 2 for Airtel. The app will:
1. Automate USSD operations for MTN and Airtel.
2. Read SMS messages for airtime-to-cash confirmations.
3. Provide API endpoints and manage API keys for secure communication between the app and the backend.

---

### **SYSTEM REQUIREMENTS**
#### **Mobile Application**
- **Development Framework:** Android Studio with Kotlin.
- **Target OS:** Android 6.0 (Marshmallow) and above.
- **Permissions Required:**
  - Read and send SMS.
  - Execute USSD requests.
  - Internet access for API communication.

#### **Backend**
- **Hosting:** Subdomain `api.teleco.com.ng` on a shared cPanel environment.
- **Backend Language:** PHP 7.4 or higher.
- **Database:** MySQL.

---

### **FUNCTIONAL REQUIREMENTS**

#### **1. SIM Slot Configuration**
- **Default Setup:**
  - SIM 1 must be MTN.
  - SIM 2 must be Airtel.
- **SIM Detection:**
  - Use Android’s `TelephonyManager` API to verify that:
    - SIM 1 is MTN (Network ID: 1).
    - SIM 2 is Airtel (Network ID: 2).
  - If the SIM slots are not configured correctly, the app will notify the user to correct the setup.

---

#### **2. Airtime to Cash**
- **SMS Reading:**
  - The app will read incoming SMS messages.
  - It will validate if:
    - The sender’s phone number matches the request.
    - The airtime amount matches the request.
  - If both match:
    - Mark the transaction as successful.
    - Send a confirmation to the backend via API.
  - If they do not match:
    - Flag the transaction as failed and log the error.

---

#### **3. Airtime Vending**
- **USSD Logic:**
- allow me to be able to set ussd logic
  - For MTN:
    - Use a single-step USSD format: `*321*recipientPhoneNumber*amount*pin#`.
    - Example: `*321*09166408768*100*0000#`.
  - For Airtel:
    - Use a multi-step USSD format:
      1. Dial `*312#`.
      2. Follow prompts:
         - Select option `2` (Airtime transfer).
         - Enter recipient phone number.
         - Enter amount.
         - Enter PIN.

---

#### **4. API Requirements**
- **Authentication:**
  - The app and backend will both require login functionality.
  - No registration is needed (admin use only).
- **Key Features:**
  - Generate and reset API keys.
  - Provide endpoints for:
    - Airtime-to-cash transactions.
    - Airtime vending transactions.
    - USSD execution.
  - Log all transactions and USSD sessions.

---

### **DATABASE REQUIREMENTS**
#### **Tables**
1. **Users Table (for login):**
   - `username`: Admin username.
   - `password_hash`: Hashed password.

2. **API Keys Table:**
   - `user_id`: Associated user.
   - `api_key`: Unique API key.
   - `is_active`: Boolean (active/inactive).

3. **USSD Logic Table:**
   - `network_provider`: MTN or Airtel.
   - `ussd_code`: USSD code (e.g., `*312#`).
   - `steps`: JSON array of prompts and responses.

4. **Transactions Table:**
   - `type`: Airtime-to-cash or airtime vending.
   - `phone_number`: Recipient phone number.
   - `amount`: Transaction amount.
   - `status`: Pending, completed, or failed.
   - `ussd_response`: Response from the USSD execution.

---

### **SECURITY REQUIREMENTS**
1. **Authentication:**
   - Use secure login for the app and backend.
   - Passwords must be hashed (e.g., using bcrypt).
2. **API Key Management:**
   - Each API request must include a valid API key.
   - API keys can be reset via the admin interface.
3. **SMS Data Privacy:**
   - SMS messages should only be read and processed for airtime-to-cash transactions.

---

### **IMPLEMENTATION NOTES**
1. **Mobile App:**
   - Use Android’s `TelephonyManager` API to enforce SIM configurations.
   - Use Accessibility Services to handle USSD prompts dynamically.
   - Ensure proper error handling for SMS reading and USSD execution.

2. **Backend:**
   - Provide a user-friendly admin interface to:
     - Configure USSD logic.
     - Manage API keys.
     - View transaction logs.
   - Use prepared statements to prevent SQL injection.
   - Ensure HTTPS is enabled for secure communication.

---

### **TESTING REQUIREMENTS**
1. **Mobile App:**
   - Test on a physical device with MTN in SIM 1 and Airtel in SIM 2.
   - Validate SMS reading for airtime-to-cash transactions.
   - Test USSD execution for both MTN and Airtel.
.

---

### **DELIVERABLES**
1. **Mobile App:**
   - Source code (Kotlin) with comments.

2. **Backend:**
   - Fully functional backend on `api.teleco.com.ng`.
   - Database schema and seed data.
   - Source code (PHP) with comments.

3. **Documentation:**
   - User guide for the app and backend.
   - API documentation (endpoints, request/response examples).

---

### **TIMELINE**
1. Backend Development: 2 weeks.
2. Mobile App Development: 3 weeks.
3. Testing and Deployment: 1 week.

---

### **NOTES**
- The app will not have a public-facing registration page; it is for private use only.
- Ensure MTN is always assigned to SIM 1 and Airtel to SIM 2 for proper functionality.
- Network IDs:
  - `1`: MTN.
  - `2`: Airtel.

---

### **APPROVAL**
Please review this document and provide approval to proceed with development.
**Extra Notes** 
please the api reduest format for airtime should always come with network_id as that is what the backend and endpoint Will use to identify which network as network _id 1 is for mtn and network_id2 is airtel