<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized access'
    ]);
    exit;
}

// Get network ID
$networkId = isset($_GET['network_id']) ? (int)$_GET['network_id'] : 0;

if (!$networkId) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Missing network ID',
        'plans' => []
    ]);
    exit;
}

// Get user ID and type
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT user_type FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'User not found',
        'plans' => []
    ]);
    exit;
}

// Get data plans for this network
$stmt = $conn->prepare("
    SELECT id, name, size, validity, amount_smart, amount_vendor, amount_api 
    FROM data_plans 
    WHERE network_id = ? AND status = 'active'
    ORDER BY amount_smart ASC
");
$stmt->bind_param("i", $networkId);
$stmt->execute();
$result = $stmt->get_result();

$plans = [];
while ($row = $result->fetch_assoc()) {
    // Determine price based on user type
    $price = $row['amount_smart']; // Default to smart user price
    if ($user['user_type'] === 'vendor') {
        $price = $row['amount_vendor'];
    } elseif ($user['user_type'] === 'api') {
        $price = $row['amount_api'];
    }
    
    $plans[] = [
        'id' => $row['id'],
        'name' => $row['name'],
        'size' => $row['size'],
        'validity' => $row['validity'],
        'price' => $price
    ];
}

header('Content-Type: application/json');
echo json_encode([
    'success' => true,
    'plans' => $plans
]);
?>