<?php
// File: /dashboard/ajax/verify_pin.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'You must be logged in to verify PIN']);
    exit;
}

// Validate request method
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Invalid request method']);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user record
$stmt = $conn->prepare("SELECT pin FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode(['success' => false, 'message' => 'User not found']);
    exit;
}

// Validate PIN
$pin = isset($_POST['pin']) ? trim($_POST['pin']) : '';

if (empty($pin)) {
    echo json_encode(['success' => false, 'message' => 'PIN is required']);
    exit;
}

if (!preg_match('/^[0-9]{4}$/', $pin)) {
    echo json_encode(['success' => false, 'message' => 'PIN must be exactly 4 digits']);
    exit;
}

// Check if user has a PIN set
if (empty($user['pin'])) {
    echo json_encode(['success' => false, 'message' => 'You have not set a transaction PIN. Please set one in your profile settings.']);
    exit;
}

// Verify PIN
if (password_verify($pin, $user['pin'])) {
    echo json_encode(['success' => true, 'message' => 'PIN verified successfully']);
} else {
    echo json_encode(['success' => false, 'message' => 'Invalid PIN. Please try again.']);
}
?>