<?php
$pageTitle = 'Buy Airtime';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get networks
$stmt = $conn->prepare("SELECT * FROM networks WHERE status = 'active' ORDER BY name");
$stmt->execute();
$result = $stmt->get_result();
$networks = [];

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Get airtime discounts based on user type
$discountKey = 'airtime_discount_' . $user['user_type'];
$discount = (float)getSetting($discountKey, 0);

// Get user's recent airtime purchases
$stmt = $conn->prepare("
    SELECT t.*, n.name as network_name
    FROM transactions t
    LEFT JOIN networks n ON JSON_EXTRACT(t.meta_data, '$.network_id') = n.id
    WHERE t.user_id = ? AND t.type = 'airtime'
    ORDER BY t.created_at DESC
    LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$recentPurchases = [];

while ($row = $result->fetch_assoc()) {
    $metaData = json_decode($row['meta_data'], true);
    $row['phone'] = $metaData['phone'] ?? '';
    $row['amount'] = $metaData['amount'] ?? $row['amount'];
    $recentPurchases[] = $row;
}

// Get saved beneficiaries
$stmt = $conn->prepare("
    SELECT * FROM beneficiaries 
    WHERE user_id = ? AND type = 'airtime'
    ORDER BY name ASC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$beneficiaries = [];

while ($row = $result->fetch_assoc()) {
    $beneficiaries[] = $row;
}

// Check if user has pin verification enabled (default is true if not set)
$pinVerificationEnabled = true;
if (isset($user['pin_verification_enabled'])) {
    $pinVerificationEnabled = (bool)$user['pin_verification_enabled'];
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Buy Airtime</h1>
    
    <div class="text-sm text-gray-400 mb-4">
        Purchase airtime for all networks at the best prices. <?php if ($discount > 0): ?>Enjoy <?php echo $discount; ?>% discount as a <?php echo ucfirst($user['user_type']); ?> user.<?php endif; ?>
    </div>
    
    <!-- Airtime Purchase Form -->
    <form id="airtimePurchaseForm" class="mt-6">
        <!-- Networks Selection -->
        <div class="mb-6">
            <label class="block text-sm font-medium text-gray-400 mb-2">Select Network</label>
            <div class="grid grid-cols-2 sm:grid-cols-4 gap-4">
                <?php foreach ($networks as $network): ?>
                    <div class="network-card cursor-pointer border border-gray-700 rounded-lg p-4 text-center" data-network-id="<?php echo $network['id']; ?>">
                        <div class="h-12 w-12 mx-auto mb-2 rounded-full bg-gray-700 flex items-center justify-center">
                            <i class="fas fa-broadcast-tower text-xl text-white"></i>
                        </div>
                        <div class="font-medium text-white"><?php echo htmlspecialchars($network['name']); ?></div>
                    </div>
                <?php endforeach; ?>
            </div>
            <input type="hidden" id="network_id" name="network_id" required>
        </div>
        
        <!-- Amount Selection -->
        <div class="mb-6">
            <label class="block text-sm font-medium text-gray-400 mb-2">Amount</label>
            <div class="grid grid-cols-2 sm:grid-cols-4 gap-4 mb-3">
                <div class="amount-preset cursor-pointer border border-gray-700 rounded-lg p-3 text-center" data-amount="100">
                    <div class="font-medium text-white"><?php echo $currency; ?>100</div>
                </div>
                <div class="amount-preset cursor-pointer border border-gray-700 rounded-lg p-3 text-center" data-amount="200">
                    <div class="font-medium text-white"><?php echo $currency; ?>200</div>
                </div>
                <div class="amount-preset cursor-pointer border border-gray-700 rounded-lg p-3 text-center" data-amount="500">
                    <div class="font-medium text-white"><?php echo $currency; ?>500</div>
                </div>
                <div class="amount-preset cursor-pointer border border-gray-700 rounded-lg p-3 text-center" data-amount="5000">
                    <div class="font-medium text-white"><?php echo $currency; ?>5,000</div>
                </div>
            </div>
            <div class="relative">
                <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                    <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                </div>
                <!-- Increased padding (py-3) and font size (text-base) -->
                <input type="number" id="amount" name="amount" class="form-input block w-full pl-7 pr-12 py-3 text-base rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter other amount" min="50" required>
            </div>
            <?php if ($discount > 0): ?>
                <p class="mt-2 text-xs text-green-400">
                    <i class="fas fa-tag mr-1"></i> You get <?php echo $discount; ?>% discount on all airtime purchases!
                </p>
            <?php endif; ?>
        </div>
        
        <!-- Phone Number -->
        <div class="mb-6">
            <label for="phone" class="block text-sm font-medium text-gray-400 mb-2">Phone Number</label>
            <div class="flex">
                <!-- Increased padding (py-3) and font size (text-base) -->
                <input type="tel" id="phone" name="phone" class="form-input block w-full py-3 text-base rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter recipient's phone number" required>
                <button type="button" id="showBeneficiariesBtn" class="bg-gray-700 text-white px-3 rounded-r-md hover:bg-gray-600">
                    <i class="fas fa-address-book"></i>
                </button>
            </div>
        </div>
        
        <!-- Save Beneficiary -->
        <div class="mb-6">
            <label class="inline-flex items-center cursor-pointer">
                <input type="checkbox" id="save_beneficiary" name="save_beneficiary" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                <span class="ml-2 text-gray-400">Save as beneficiary</span>
            </label>
            
            <div id="beneficiaryNameField" class="mt-3 hidden">
                <label for="beneficiary_name" class="block text-sm font-medium text-gray-400 mb-1">Beneficiary Name</label>
                <!-- Increased padding (py-3) and font size (text-base) -->
                <input type="text" id="beneficiary_name" name="beneficiary_name" class="form-input block w-full py-3 text-base rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter a name for this beneficiary">
            </div>
        </div>
        
        <!-- Promo Code -->
        <div class="mb-6">
            <label for="promo_code" class="block text-sm font-medium text-gray-400 mb-2">Promo Code (Optional)</label>
            <div class="flex">
                <!-- Increased padding (py-3) and font size (text-base) -->
                <input type="text" id="promo_code" name="promo_code" class="form-input block w-full py-3 text-base rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter promo code if available">
                <!-- Made button taller to match input -->
                <button type="button" id="applyPromoBtn" class="bg-indigo-600 text-white px-4 py-3 rounded-r-md hover:bg-indigo-700 flex items-center">
                    <i class="fas fa-check mr-1"></i> Apply
                </button>
            </div>
            <div id="promoMessage" class="mt-1 text-sm hidden"></div>
        </div>
        
        <!-- Price Info -->
        <div id="priceInfoCard" class="mb-6 p-4 rounded-md bg-gray-800 hidden">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Airtime Amount:</span>
                <span id="airtimeAmount" class="text-white font-medium"></span>
            </div>
            <div id="discountRow" class="flex justify-between mb-2 <?php echo ($discount > 0) ? '' : 'hidden'; ?>">
                <span class="text-gray-400">Discount (<?php echo $discount; ?>%):</span>
                <span id="discountAmount" class="text-green-400 font-medium"></span>
            </div>
            <div id="promoRow" class="flex justify-between mb-2 hidden">
                <span class="text-gray-400">Promo Discount:</span>
                <span id="promoAmount" class="text-green-400 font-medium"></span>
            </div>
            <div class="flex justify-between pt-2 border-t border-gray-700">
                <span class="text-gray-300 font-medium">Amount to Pay:</span>
                <span id="totalPrice" class="text-white font-bold"></span>
            </div>
        </div>
        
        <!-- Submit Button -->
        <div class="flex justify-end">
            <!-- Made button larger with py-3 -->
            <button type="submit" id="purchaseBtn" class="accent-button py-3 px-6 text-base rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50 disabled:cursor-not-allowed" disabled>
                Purchase Airtime
            </button>
        </div>
        
        <!-- Hidden field to track pin verification status -->
        <input type="hidden" id="pinVerificationEnabled" value="<?php echo $pinVerificationEnabled ? 'true' : 'false'; ?>">
    </form>
</div>

<!-- Recent Purchases -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Recent Airtime Purchases</h2>
    
    <?php if (empty($recentPurchases)): ?>
        <div class="text-center py-6 text-gray-400">
            <i class="fas fa-history text-3xl mb-2"></i>
            <p>No recent airtime purchases found</p>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Phone</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($recentPurchases as $purchase): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, H:i', strtotime($purchase['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($purchase['network_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($purchase['phone']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($purchase['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <span class="status-badge status-<?php echo $purchase['status']; ?>">
                                    <?php echo ucfirst($purchase['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4">
                                <button type="button" class="text-indigo-400 hover:text-indigo-300 buy-again" 
                                        data-network="<?php echo $purchase['network_name']; ?>"
                                        data-network-id="<?php echo json_decode($purchase['meta_data'], true)['network_id']; ?>"
                                        data-phone="<?php echo $purchase['phone']; ?>"
                                        data-amount="<?php echo $purchase['amount']; ?>">
                                    <i class="fas fa-redo-alt mr-1"></i> Buy Again
                                </button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Beneficiaries Modal -->
<div id="beneficiariesModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg w-full max-w-md max-h-full overflow-y-auto">
        <div class="p-4 border-b border-gray-700">
            <h3 class="text-xl font-semibold text-white">Saved Beneficiaries</h3>
        </div>
        <div class="p-4">
            <?php if (empty($beneficiaries)): ?>
                <div class="text-center py-6 text-gray-400">
                    <i class="fas fa-address-book text-3xl mb-2"></i>
                    <p>No saved beneficiaries found</p>
                </div>
            <?php else: ?>
                <div class="space-y-3">
                    <?php foreach ($beneficiaries as $beneficiary): ?>
                        <div class="beneficiary-item p-3 bg-gray-700 rounded-md cursor-pointer hover:bg-gray-600" data-phone="<?php echo htmlspecialchars($beneficiary['identifier']); ?>">
                            <div class="flex items-center">
                                <div class="w-10 h-10 rounded-full bg-gray-600 flex items-center justify-center mr-3">
                                    <i class="fas fa-user text-gray-300"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                    <div class="text-sm text-gray-300"><?php echo htmlspecialchars($beneficiary['identifier']); ?></div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        <div class="p-4 border-t border-gray-700 flex justify-end">
            <button type="button" id="closeBeneficiariesModal" class="bg-gray-700 text-white py-3 px-4 text-base rounded-md hover:bg-gray-600">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2">Processing Your Request</p>
        <p class="text-gray-400">Please wait while we process your airtime purchase...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Airtime Purchase Successful!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your airtime has been purchased successfully and will be delivered shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Network:</span>
                <span id="successNetwork" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Phone Number:</span>
                <span id="successPhone" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Airtime Amount:</span>
                <span id="successAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount Paid:</span>
                <span id="successPaid" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Transaction Ref:</span>
                <span id="successRef" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="successDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeSuccessModal" class="accent-button py-3 px-4 text-base rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Airtime Purchase Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your airtime purchase at this time.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-3 px-4 text-base rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- PIN Verification Modal -->
<div id="pinVerificationModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-lock text-3xl text-indigo-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Transaction PIN Required</h3>
            <p class="text-gray-400 mt-2">Please enter your 4-digit transaction PIN to complete this purchase.</p>
        </div>
        <div class="mb-6">
            <label for="transaction_pin" class="sr-only">Transaction PIN</label>
            <div class="pin-input-container flex justify-center gap-2">
                <input type="password" inputmode="numeric" maxlength="1" class="pin-digit w-12 h-14 text-center text-2xl bg-gray-700 border border-gray-600 rounded-md text-white">
                <input type="password" inputmode="numeric" maxlength="1" class="pin-digit w-12 h-14 text-center text-2xl bg-gray-700 border border-gray-600 rounded-md text-white">
                <input type="password" inputmode="numeric" maxlength="1" class="pin-digit w-12 h-14 text-center text-2xl bg-gray-700 border border-gray-600 rounded-md text-white">
                <input type="password" inputmode="numeric" maxlength="1" class="pin-digit w-12 h-14 text-center text-2xl bg-gray-700 border border-gray-600 rounded-md text-white">
            </div>
            <input type="hidden" id="transaction_pin" value="">
            <p id="pinErrorMessage" class="text-red-500 mt-2 text-center text-sm hidden"></p>
        </div>
        <div class="flex justify-between">
            <button type="button" id="cancelPinVerification" class="bg-gray-700 hover:bg-gray-600 py-3 px-4 text-base rounded-md text-white">
                Cancel
            </button>
            <button type="button" id="confirmPinVerification" class="accent-button py-3 px-4 text-base rounded-md text-white">
                Confirm Purchase
            </button>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // DOM Elements
        const networkCards = document.querySelectorAll('.network-card');
        const networkIdInput = document.getElementById('network_id');
        const amountPresets = document.querySelectorAll('.amount-preset');
        const amountInput = document.getElementById('amount');
        const phoneInput = document.getElementById('phone');
        const saveBeneficiaryCheckbox = document.getElementById('save_beneficiary');
        const beneficiaryNameField = document.getElementById('beneficiaryNameField');
        const promoCodeInput = document.getElementById('promo_code');
        const applyPromoBtn = document.getElementById('applyPromoBtn');
        const promoMessage = document.getElementById('promoMessage');
        const purchaseBtn = document.getElementById('purchaseBtn');
        const airtimePurchaseForm = document.getElementById('airtimePurchaseForm');
        const priceInfoCard = document.getElementById('priceInfoCard');
        const airtimeAmountElement = document.getElementById('airtimeAmount');
        const discountRowElement = document.getElementById('discountRow');
        const discountAmountElement = document.getElementById('discountAmount');
        const promoRowElement = document.getElementById('promoRow');
        const promoAmountElement = document.getElementById('promoAmount');
        const totalPriceElement = document.getElementById('totalPrice');
        
        // Modal Elements
        const beneficiariesModal = document.getElementById('beneficiariesModal');
        const showBeneficiariesBtn = document.getElementById('showBeneficiariesBtn');
        const closeBeneficiariesModal = document.getElementById('closeBeneficiariesModal');
        const beneficiaryItems = document.querySelectorAll('.beneficiary-item');
        const loadingModal = document.getElementById('loadingModal');
        const successModal = document.getElementById('successModal');
        const closeSuccessModal = document.getElementById('closeSuccessModal');
        const errorModal = document.getElementById('errorModal');
        const closeErrorModal = document.getElementById('closeErrorModal');
        
        // PIN Verification Elements
        const pinVerificationModal = document.getElementById('pinVerificationModal');
        const pinDigits = document.querySelectorAll('.pin-digit');
        const transactionPinInput = document.getElementById('transaction_pin');
        const pinErrorMessage = document.getElementById('pinErrorMessage');
        const cancelPinVerification = document.getElementById('cancelPinVerification');
        const confirmPinVerification = document.getElementById('confirmPinVerification');
        const pinVerificationEnabled = document.getElementById('pinVerificationEnabled').value === 'true';
        
        // Success modal elements
        const successNetwork = document.getElementById('successNetwork');
        const successPhone = document.getElementById('successPhone');
        const successAmount = document.getElementById('successAmount');
        const successPaid = document.getElementById('successPaid');
        const successRef = document.getElementById('successRef');
        const successDate = document.getElementById('successDate');
        const successMessage = document.getElementById('successMessage');
        
        // Error modal element
        const errorMessage = document.getElementById('errorMessage');
        
        // Buy again buttons
        const buyAgainButtons = document.querySelectorAll('.buy-again');
        
        // Current state
        let selectedNetworkId = null;
        let selectedAmount = 0;
        let discount = <?php echo $discount; ?>;
        let promoDiscount = 0;
        let promoCodeValidated = false;
        let formData = null;
        
        // Functions
        
        // Update price information
        function updatePriceInfo() {
            if (selectedAmount > 0) {
                airtimeAmountElement.textContent = formatCurrency(selectedAmount);
                
                let totalDiscount = 0;
                
                // Apply regular discount
                if (discount > 0) {
                    const regularDiscountAmount = (selectedAmount * discount) / 100;
                    discountAmountElement.textContent = `- ${formatCurrency(regularDiscountAmount)}`;
                    discountRowElement.classList.remove('hidden');
                    totalDiscount += regularDiscountAmount;
                }
                
                // Apply promo discount
                if (promoDiscount > 0) {
                    promoAmountElement.textContent = `- ${formatCurrency(promoDiscount)}`;
                    promoRowElement.classList.remove('hidden');
                    totalDiscount += promoDiscount;
                } else {
                    promoRowElement.classList.add('hidden');
                }
                
                // Calculate final price
                const finalPrice = Math.max(selectedAmount - totalDiscount, 0);
                totalPriceElement.textContent = formatCurrency(finalPrice);
                
                priceInfoCard.classList.remove('hidden');
            } else {
                priceInfoCard.classList.add('hidden');
            }
        }
        
        // Format currency
        function formatCurrency(amount) {
            return '<?php echo $currency; ?>' + parseFloat(amount).toFixed(2);
        }
        
        // Validate promo code
        function validatePromoCode() {
            const promoCode = promoCodeInput.value.trim();
            
            if (!promoCode || !selectedAmount) {
                // Reset promo discount
                promoDiscount = 0;
                promoCodeValidated = false;
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                updatePriceInfo();
                return;
            }
            
            // Show loading state for Apply button
            applyPromoBtn.innerHTML = '<i class="fas fa-spinner fa-spin mr-1"></i> Checking...';
            applyPromoBtn.disabled = true;
            
            // Show message that we're validating
            promoMessage.textContent = 'Validating promo code...';
            promoMessage.className = 'mt-1 text-sm text-blue-400';
            promoMessage.classList.remove('hidden');
            
            // Fetch promo code validation
            fetch(`${window.location.origin}/dashboard/ajax/validate_promo.php`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `promo_code=${promoCode}&amount=${selectedAmount}&service_type=airtime`
            })
            .then(response => response.json())
            .then(data => {
                // Re-enable apply button
                applyPromoBtn.innerHTML = '<i class="fas fa-check mr-1"></i> Apply';
                applyPromoBtn.disabled = false;
                
                if (data.success) {
                    promoDiscount = data.discount;
                    promoCodeValidated = true;
                    
                    // Show success message
                    promoMessage.textContent = data.message;
                    promoMessage.className = 'mt-1 text-sm text-green-400';
                    
                    // Update the price display
                    if (promoDiscount > 0) {
                        promoAmountElement.innerHTML = `- ${formatCurrency(promoDiscount)} <span class="text-xs">(${promoCode})</span>`;
                        promoRowElement.classList.remove('hidden');
                    }
                } else {
                    promoDiscount = 0;
                    promoCodeValidated = false;
                    
                    // Show error message
                    promoMessage.textContent = data.message;
                    promoMessage.className = 'mt-1 text-sm text-red-400';
                    promoRowElement.classList.add('hidden');
                }
                
                updatePriceInfo();
            })
            .catch(error => {
                console.error('Error validating promo code:', error);
                
                // Re-enable apply button
                applyPromoBtn.innerHTML = '<i class="fas fa-check mr-1"></i> Apply';
                applyPromoBtn.disabled = false;
                
                // Reset promo discount
                promoDiscount = 0;
                promoCodeValidated = false;
                
                // Show error message
                promoMessage.textContent = 'Error validating promo code. Please try again.';
                promoMessage.className = 'mt-1 text-sm text-red-400';
                promoRowElement.classList.add('hidden');
                
                updatePriceInfo();
            });
        }
        
        // Check if all required fields are filled
        function checkFormValidity() {
            const networkSelected = !!selectedNetworkId;
            const amountValid = !!amountInput.value && parseFloat(amountInput.value) >= 50;
            const phoneValid = !!phoneInput.value && phoneInput.value.match(/^(0|\+?234)[789][01]\d{8}$/);
            
            if (networkSelected && amountValid && phoneValid) {
                purchaseBtn.disabled = false;
            } else {
                purchaseBtn.disabled = true;
            }
        }
        
        // Show success modal with transaction details
        function showSuccessModal(data) {
            successNetwork.textContent = data.network || '';
            successPhone.textContent = data.phone || '';
            successAmount.textContent = formatCurrency(data.amount) || '';
            successPaid.textContent = formatCurrency(data.paid) || '';
            successRef.textContent = data.reference || '';
            successDate.textContent = data.date || new Date().toLocaleString();
            successMessage.textContent = data.message || 'Your airtime has been purchased successfully and has been delivered.';
            
            loadingModal.classList.add('hidden');
            successModal.classList.remove('hidden');
        }
        
        // Show error modal with error message
        function showErrorModal(message) {
            errorMessage.textContent = message || 'Sorry, we couldn\'t process your airtime purchase at this time.';
            
            loadingModal.classList.add('hidden');
            errorModal.classList.remove('hidden');
        }
        
        // Process the purchase with server
        function processPurchase() {
            // Show loading modal
            loadingModal.classList.remove('hidden');
            
            // Calculate final amount after discounts
            let totalDiscount = 0;
            if (discount > 0) {
                totalDiscount += (selectedAmount * discount) / 100;
            }
            if (promoDiscount > 0) {
                totalDiscount += promoDiscount;
            }
            const finalPrice = Math.max(selectedAmount - totalDiscount, 0);
            
            // Send request
            fetch(`${window.location.origin}/dashboard/process/buy_airtime.php`, {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // Show success modal
                    showSuccessModal({
                        network: document.querySelector('.network-card.selected').querySelector('.font-medium').textContent,
                        phone: phoneInput.value,
                        amount: selectedAmount,
                        paid: finalPrice,
                        reference: data.data.reference,
                        message: data.message
                    });
                } else {
                    // Show error modal
                    showErrorModal(data.message);
                }
            })
            .catch(error => {
                console.error('Error processing airtime purchase:', error);
                showErrorModal('An unexpected error occurred. Please try again later.');
            });
        }
        
        // Verify PIN with server
        function verifyPin(pin) {
            return new Promise((resolve, reject) => {
                fetch(`${window.location.origin}/dashboard/ajax/verify_pin.php`, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `pin=${pin}`
                })
                .then(response => response.json())
                .then(data => {
                    resolve(data);
                })
                .catch(error => {
                    console.error('Error verifying PIN:', error);
                    reject({success: false, message: 'Error verifying PIN. Please try again.'});
                });
            });
        }
        
        // Event Listeners
        
        // PIN input handling
        pinDigits.forEach((digit, index) => {
            // Focus on first digit on modal open
            if (index === 0) {
                digit.addEventListener('focus', function() {
                    this.select();
                });
            }
            
            // Handle input in each digit field
            digit.addEventListener('input', function(e) {
                this.value = this.value.replace(/[^0-9]/g, '');
                
                if (this.value) {
                    // Auto-focus next input
                    if (index < pinDigits.length - 1) {
                        pinDigits[index + 1].focus();
                    }
                }
                
                // Combine all digits to form the PIN
                let pin = '';
                pinDigits.forEach(input => {
                    pin += input.value;
                });
                transactionPinInput.value = pin;
                
                // Enable confirm button if all digits filled
                confirmPinVerification.disabled = pin.length !== 4;
            });
            
            // Handle backspace to go to previous input
            digit.addEventListener('keydown', function(e) {
                if (e.key === 'Backspace' && !this.value && index > 0) {
                    pinDigits[index - 1].focus();
                }
            });
        });
        
        // Network selection
        networkCards.forEach(card => {
            card.addEventListener('click', function() {
                // Remove selected class from all cards
                networkCards.forEach(c => c.classList.remove('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20'));
                
                // Add selected class to this card
                this.classList.add('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20');
                
                // Update selected network id
                selectedNetworkId = this.dataset.networkId;
                networkIdInput.value = selectedNetworkId;
                
                // Check form validity
                checkFormValidity();
            });
        });
        
        // Amount preset selection
        amountPresets.forEach(preset => {
            preset.addEventListener('click', function() {
                // Remove selected class from all presets
                amountPresets.forEach(p => p.classList.remove('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20'));
                
                // Add selected class to this preset
                this.classList.add('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20');
                
                // Update amount input
                const presetAmount = this.dataset.amount;
                amountInput.value = presetAmount;
                
                // Update selected amount
                selectedAmount = parseFloat(presetAmount);
                
                // Reset promo code validation
                if (promoCodeInput.value && promoCodeValidated) {
                    validatePromoCode();
                } else {
                    updatePriceInfo();
                }
                
                // Check form validity
                checkFormValidity();
            });
        });
        
        // Amount input
        amountInput.addEventListener('input', function() {
            // Remove selected class from all presets
            amountPresets.forEach(p => p.classList.remove('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20'));
            
            // Update selected amount
            selectedAmount = parseFloat(this.value) || 0;
            
            // Reset promo code validation if value has changed
            if (promoCodeInput.value && promoCodeValidated) {
                validatePromoCode();
            } else {
                updatePriceInfo();
            }
            
            // Check form validity
            checkFormValidity();
        });
        
        // Phone input
        phoneInput.addEventListener('input', checkFormValidity);
        
        // Save beneficiary checkbox
        saveBeneficiaryCheckbox.addEventListener('change', function() {
            if (this.checked) {
                beneficiaryNameField.classList.remove('hidden');
            } else {
                beneficiaryNameField.classList.add('hidden');
            }
        });
        
        // Apply Promo Code button
        applyPromoBtn.addEventListener('click', validatePromoCode);
        
        // Enter key on promo code input
        promoCodeInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                e.preventDefault();
                validatePromoCode();
            }
        });
        
        // Show beneficiaries modal
        showBeneficiariesBtn.addEventListener('click', function() {
            beneficiariesModal.classList.remove('hidden');
        });
        
        // Close beneficiaries modal
        closeBeneficiariesModal.addEventListener('click', function() {
            beneficiariesModal.classList.add('hidden');
        });
        
        // Select beneficiary
        beneficiaryItems.forEach(item => {
            item.addEventListener('click', function() {
                phoneInput.value = this.dataset.phone;
                beneficiariesModal.classList.add('hidden');
                checkFormValidity();
            });
        });
        
        // Close success modal
        closeSuccessModal.addEventListener('click', function() {
            successModal.classList.add('hidden');
            window.location.reload(); // Reload page to show updated recent purchases
        });
        
        // Close error modal
        closeErrorModal.addEventListener('click', function() {
            errorModal.classList.add('hidden');
        });
        
        // PIN Verification Modal Handlers
        confirmPinVerification.addEventListener('click', async function() {
            const pin = transactionPinInput.value;
            
            if (pin.length !== 4) {
                pinErrorMessage.textContent = 'Please enter a valid 4-digit PIN';
                pinErrorMessage.classList.remove('hidden');
                return;
            }
            
            // Show loading state
            confirmPinVerification.disabled = true;
            confirmPinVerification.innerHTML = '<i class="fas fa-spinner fa-spin mr-1"></i> Verifying...';
            
            try {
                const result = await verifyPin(pin);
                
                if (result.success) {
                    // Hide PIN modal
                    pinVerificationModal.classList.add('hidden');
                    
                    // Reset PIN inputs
                    pinDigits.forEach(input => {
                        input.value = '';
                    });
                    transactionPinInput.value = '';
                    pinErrorMessage.classList.add('hidden');
                    
                    // Process the purchase
                    processPurchase();
                } else {
                    // Show error message
                    pinErrorMessage.textContent = result.message || 'Invalid PIN. Please try again.';
                    pinErrorMessage.classList.remove('hidden');
                    
                    // Clear PIN fields
                    pinDigits.forEach(input => {
                        input.value = '';
                    });
                    transactionPinInput.value = '';
                    pinDigits[0].focus();
                }
            } catch (error) {
                // Show error message
                pinErrorMessage.textContent = 'Error verifying PIN. Please try again.';
                pinErrorMessage.classList.remove('hidden');
            } finally {
                // Reset button state
                confirmPinVerification.disabled = false;
                confirmPinVerification.innerHTML = 'Confirm Purchase';
            }
        });
        
        // Cancel PIN verification
        cancelPinVerification.addEventListener('click', function() {
            pinVerificationModal.classList.add('hidden');
            
            // Reset PIN inputs
            pinDigits.forEach(input => {
                input.value = '';
            });
            transactionPinInput.value = '';
            pinErrorMessage.classList.add('hidden');
        });
        
        // Form submission
        airtimePurchaseForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Prepare form data
            formData = new FormData();
            formData.append('network_id', selectedNetworkId);
            formData.append('amount', selectedAmount);
            formData.append('phone', phoneInput.value);
            
            if (saveBeneficiaryCheckbox.checked && document.getElementById('beneficiary_name').value) {
                formData.append('beneficiary', document.getElementById('beneficiary_name').value);
            }
            
            if (promoCodeInput.value && promoCodeValidated) {
                formData.append('promo_code', promoCodeInput.value);
            }
            
            // Check if PIN verification is enabled for this user
            if (pinVerificationEnabled) {
                // Show PIN verification modal
                pinVerificationModal.classList.remove('hidden');
                pinDigits[0].focus();
            } else {
                // Process purchase directly
                processPurchase();
            }
        });
        
        // Buy again buttons
        buyAgainButtons.forEach(button => {
            button.addEventListener('click', function() {
                const networkId = this.dataset.networkId;
                const networkName = this.dataset.network;
                const phone = this.dataset.phone;
                const amount = this.dataset.amount;
                
                // Reset promo fields
                promoCodeInput.value = '';
                promoDiscount = 0;
                promoCodeValidated = false;
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                promoRowElement.classList.add('hidden');
                
                // Set selected network
                networkCards.forEach(card => {
                    if (card.dataset.networkId === networkId) {
                        card.click();
                    }
                });
                
                // Set phone number
                phoneInput.value = phone;
                
                // Set amount and update price info
                amountInput.value = amount;
                selectedAmount = parseFloat(amount);
                updatePriceInfo();
                
                // Reset amount preset selection UI
                amountPresets.forEach(preset => {
                    if (preset.dataset.amount === amount) {
                        preset.click();
                    }
                });
                
                // Scroll to form
                document.getElementById('airtimePurchaseForm').scrollIntoView({ behavior: 'smooth' });
                
                // Check form validity
                checkFormValidity();
            });
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', function(e) {
            if (e.target === beneficiariesModal) {
                beneficiariesModal.classList.add('hidden');
            }
            if (e.target === successModal) {
                successModal.classList.add('hidden');
            }
            if (e.target === errorModal) {
                errorModal.classList.add('hidden');
            }
            if (e.target === pinVerificationModal) {
                pinVerificationModal.classList.add('hidden');
                
                // Reset PIN inputs
                pinDigits.forEach(input => {
                    input.value = '';
                });
                transactionPinInput.value = '';
                pinErrorMessage.classList.add('hidden');
            }
        });
    });
</script>

<?php require_once './includes/footer.php'; ?>