<?php
$pageTitle = 'Buy Data';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get networks
$stmt = $conn->prepare("SELECT * FROM networks WHERE status = 'active' ORDER BY name");
$stmt->execute();
$result = $stmt->get_result();
$networks = [];

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Get user's recent data purchases
$stmt = $conn->prepare("
    SELECT t.*, n.name as network_name
    FROM transactions t
    LEFT JOIN networks n ON JSON_EXTRACT(t.meta_data, '$.network_id') = n.id
    WHERE t.user_id = ? AND t.type = 'data'
    ORDER BY t.created_at DESC
    LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$recentPurchases = [];

while ($row = $result->fetch_assoc()) {
    $metaData = json_decode($row['meta_data'], true);
    $row['phone'] = $metaData['phone'] ?? '';
    $row['plan_size'] = $metaData['plan_size'] ?? '';
    $recentPurchases[] = $row;
}

// Get saved beneficiaries
$stmt = $conn->prepare("
    SELECT * FROM beneficiaries 
    WHERE user_id = ? AND type = 'data'
    ORDER BY name ASC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$beneficiaries = [];

while ($row = $result->fetch_assoc()) {
    $beneficiaries[] = $row;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Buy Data Bundle</h1>
    
    <div class="text-sm text-gray-400 mb-4">
        Purchase data bundles for all networks at the best prices. Instant delivery guaranteed.
    </div>
    
    <!-- Data Purchase Form -->
    <form id="dataPurchaseForm" class="mt-6">
        <!-- Networks Selection -->
        <div class="mb-6">
            <label class="block text-sm font-medium text-gray-400 mb-2">Select Network</label>
            <div class="grid grid-cols-2 sm:grid-cols-4 gap-4">
                <?php foreach ($networks as $network): ?>
                    <div class="network-card cursor-pointer border border-gray-700 rounded-lg p-4 text-center" data-network-id="<?php echo $network['id']; ?>">
                        <div class="h-12 w-12 mx-auto mb-2 rounded-full bg-gray-700 flex items-center justify-center">
                            <i class="fas fa-broadcast-tower text-xl text-white"></i>
                        </div>
                        <div class="font-medium text-white"><?php echo htmlspecialchars($network['name']); ?></div>
                    </div>
                <?php endforeach; ?>
            </div>
            <input type="hidden" id="network_id" name="network_id" required>
        </div>
        
        <!-- Data Type Selection -->
        <div class="mb-4" id="dataTypeContainer" style="display: none;">
            <label for="data_type_id" class="block text-sm font-medium text-gray-400 mb-2">Select Data Type</label>
            <!-- Added py-3 and text-base for larger, more touch-friendly dropdown -->
            <select id="data_type_id" name="data_type_id" class="form-select block w-full py-3 text-base rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required disabled>
                <option value="">-- Select a network first --</option>
            </select>
        </div>
        
        <!-- Data Plan Selection -->
        <div class="mb-6" id="planContainer" style="display: none;">
            <label for="plan_id" class="block text-sm font-medium text-gray-400 mb-2">Select Data Plan</label>
            <!-- Added py-3 and text-base for larger, more touch-friendly dropdown -->
            <select id="plan_id" name="plan_id" class="form-select block w-full py-3 text-base rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required disabled>
                <option value="">-- Select a data type first --</option>
            </select>
        </div>
        
        <!-- Phone Number -->
        <div class="mb-6">
            <label for="phone" class="block text-sm font-medium text-gray-400 mb-2">Phone Number</label>
            <div class="flex">
                <!-- Added py-3 and text-base for larger input -->
                <input type="tel" id="phone" name="phone" class="form-input block w-full py-3 text-base rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter recipient's phone number" required>
                <!-- Added py-3 to match input height -->
                <button type="button" id="showBeneficiariesBtn" class="bg-gray-700 text-white px-3 py-3 rounded-r-md hover:bg-gray-600">
                    <i class="fas fa-address-book"></i>
                </button>
            </div>
        </div>
        
        <!-- Save Beneficiary -->
        <div class="mb-6">
            <label class="inline-flex items-center cursor-pointer">
                <input type="checkbox" id="save_beneficiary" name="save_beneficiary" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                <span class="ml-2 text-gray-400">Save as beneficiary</span>
            </label>
            
            <div id="beneficiaryNameField" class="mt-3 hidden">
                <label for="beneficiary_name" class="block text-sm font-medium text-gray-400 mb-1">Beneficiary Name</label>
                <!-- Added py-3 and text-base for larger input -->
                <input type="text" id="beneficiary_name" name="beneficiary_name" class="form-input block w-full py-3 text-base rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter a name for this beneficiary">
            </div>
        </div>
        
        <!-- Promo Code -->
        <div class="mb-6">
            <label for="promo_code" class="block text-sm font-medium text-gray-400 mb-2">Promo Code (Optional)</label>
            <div class="flex">
                <!-- Added py-3 and text-base for larger input -->
                <input type="text" id="promo_code" name="promo_code" class="form-input block w-full py-3 text-base rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter promo code if available">
                <!-- Added py-3 to match input height -->
                <button type="button" id="applyPromoBtn" class="bg-indigo-600 text-white px-4 py-3 rounded-r-md hover:bg-indigo-700 flex items-center">
                    <i class="fas fa-check mr-1"></i> Apply
                </button>
            </div>
            <div id="promoMessage" class="mt-1 text-sm hidden"></div>
        </div>
        
        <!-- Price Info -->
        <div id="priceInfoCard" class="mb-6 p-4 rounded-md bg-gray-800 hidden">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Plan Price:</span>
                <span id="planPrice" class="text-white font-medium"></span>
            </div>
            <div id="discountRow" class="flex justify-between mb-2 hidden">
                <span class="text-gray-400">Discount:</span>
                <span id="discountAmount" class="text-green-400 font-medium"></span>
            </div>
            <div class="flex justify-between pt-2 border-t border-gray-700">
                <span class="text-gray-300 font-medium">Total Price:</span>
                <span id="totalPrice" class="text-white font-bold"></span>
            </div>
        </div>
        
        <!-- Submit Button -->
        <div class="flex justify-end">
            <!-- Added py-3 and text-base for larger button -->
            <button type="submit" id="purchaseBtn" class="accent-button py-3 px-6 text-base rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50 disabled:cursor-not-allowed" disabled>
                Purchase Data
            </button>
        </div>
    </form>
</div>

<!-- Recent Purchases -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Recent Data Purchases</h2>
    
    <?php if (empty($recentPurchases)): ?>
        <div class="text-center py-6 text-gray-400">
            <i class="fas fa-history text-3xl mb-2"></i>
            <p>No recent data purchases found</p>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Phone</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($recentPurchases as $purchase): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, H:i', strtotime($purchase['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($purchase['network_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($purchase['plan_size']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($purchase['phone']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($purchase['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <span class="status-badge status-<?php echo $purchase['status']; ?>">
                                    <?php echo ucfirst($purchase['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4">
                                <button type="button" class="text-indigo-400 hover:text-indigo-300 buy-again" 
                                        data-network="<?php echo $purchase['network_name']; ?>"
                                        data-network-id="<?php echo json_decode($purchase['meta_data'], true)['network_id']; ?>"
                                        data-phone="<?php echo $purchase['phone']; ?>"
                                        data-plan-id="<?php echo json_decode($purchase['meta_data'], true)['plan_id']; ?>">
                                    <i class="fas fa-redo-alt mr-1"></i> Buy Again
                                </button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Beneficiaries Modal -->
<div id="beneficiariesModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg w-full max-w-md max-h-full overflow-y-auto">
        <div class="p-4 border-b border-gray-700">
            <h3 class="text-xl font-semibold text-white">Saved Beneficiaries</h3>
        </div>
        <div class="p-4">
            <?php if (empty($beneficiaries)): ?>
                <div class="text-center py-6 text-gray-400">
                    <i class="fas fa-address-book text-3xl mb-2"></i>
                    <p>No saved beneficiaries found</p>
                </div>
            <?php else: ?>
                <div class="space-y-3">
                    <?php foreach ($beneficiaries as $beneficiary): ?>
                        <div class="beneficiary-item p-3 bg-gray-700 rounded-md cursor-pointer hover:bg-gray-600" data-phone="<?php echo htmlspecialchars($beneficiary['identifier']); ?>">
                            <div class="flex items-center">
                                <div class="w-10 h-10 rounded-full bg-gray-600 flex items-center justify-center mr-3">
                                    <i class="fas fa-user text-gray-300"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                    <div class="text-sm text-gray-300"><?php echo htmlspecialchars($beneficiary['identifier']); ?></div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        <div class="p-4 border-t border-gray-700 flex justify-end">
            <!-- Added py-3 and text-base for larger button -->
            <button type="button" id="closeBeneficiariesModal" class="bg-gray-700 text-white py-3 px-4 text-base rounded-md hover:bg-gray-600">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2">Processing Your Request</p>
        <p class="text-gray-400">Please wait while we process your data purchase...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Data Purchase Successful!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your data has been purchased successfully and will be delivered shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Network:</span>
                <span id="successNetwork" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Phone Number:</span>
                <span id="successPhone" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Data Plan:</span>
                <span id="successPlan" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="successAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Transaction Ref:</span>
                <span id="successRef" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="successDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <!-- Added py-3 and text-base for larger button -->
            <button type="button" id="closeSuccessModal" class="accent-button py-3 px-4 text-base rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Data Purchase Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your data purchase at this time.</p>
        </div>
        <div class="flex justify-end">
            <!-- Added py-3 and text-base for larger button -->
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-3 px-4 text-base rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // DOM Elements
        const networkCards = document.querySelectorAll('.network-card');
        const networkIdInput = document.getElementById('network_id');
        const dataTypeContainer = document.getElementById('dataTypeContainer');
        const dataTypeSelect = document.getElementById('data_type_id');
        const planContainer = document.getElementById('planContainer');
        const planSelect = document.getElementById('plan_id');
        const phoneInput = document.getElementById('phone');
        const saveBeneficiaryCheckbox = document.getElementById('save_beneficiary');
        const beneficiaryNameField = document.getElementById('beneficiaryNameField');
        const promoCodeInput = document.getElementById('promo_code');
        const applyPromoBtn = document.getElementById('applyPromoBtn');
        const promoMessage = document.getElementById('promoMessage');
        const purchaseBtn = document.getElementById('purchaseBtn');
        const dataPurchaseForm = document.getElementById('dataPurchaseForm');
        const priceInfoCard = document.getElementById('priceInfoCard');
        const planPriceElement = document.getElementById('planPrice');
        const discountRowElement = document.getElementById('discountRow');
        const discountAmountElement = document.getElementById('discountAmount');
        const totalPriceElement = document.getElementById('totalPrice');
        
        // Modal Elements
        const beneficiariesModal = document.getElementById('beneficiariesModal');
        const showBeneficiariesBtn = document.getElementById('showBeneficiariesBtn');
        const closeBeneficiariesModal = document.getElementById('closeBeneficiariesModal');
        const beneficiaryItems = document.querySelectorAll('.beneficiary-item');
        const loadingModal = document.getElementById('loadingModal');
        const successModal = document.getElementById('successModal');
        const closeSuccessModal = document.getElementById('closeSuccessModal');
        const errorModal = document.getElementById('errorModal');
        const closeErrorModal = document.getElementById('closeErrorModal');
        
        // Success modal elements
        const successNetwork = document.getElementById('successNetwork');
        const successPhone = document.getElementById('successPhone');
        const successPlan = document.getElementById('successPlan');
        const successAmount = document.getElementById('successAmount');
        const successRef = document.getElementById('successRef');
        const successDate = document.getElementById('successDate');
        const successMessage = document.getElementById('successMessage');
        
        // Error modal element
        const errorMessage = document.getElementById('errorMessage');
        
        // Buy again buttons
        const buyAgainButtons = document.querySelectorAll('.buy-again');
        
        // Current state
        let selectedNetworkId = null;
        let selectedDataTypeId = null;
        let selectedPlanPrice = 0;
        let selectedPlanName = '';
        let selectedPlanSize = '';
        let promoDiscount = 0;
        let promoCodeValidated = false;
        
        // Functions
        
        // Load data types for a network
        function loadDataTypes(networkId) {
            dataTypeSelect.innerHTML = '<option value="">-- Loading data types... --</option>';
            dataTypeContainer.style.display = 'block';
            dataTypeSelect.disabled = true;
            
            // Reset plan selection
            planSelect.innerHTML = '<option value="">-- Select a data type first --</option>';
            planContainer.style.display = 'none';
            planSelect.disabled = true;
            
            // Fetch data types
            fetch(`get_data_types_user.php?network_id=${networkId}`)
                .then(response => response.json())
                .then(data => {
                    dataTypeSelect.innerHTML = '<option value="">-- Select Data Type --</option>';
                    
                    if (data.success && data.data_types.length > 0) {
                        data.data_types.forEach(type => {
                            const option = document.createElement('option');
                            option.value = type.id;
                            option.textContent = type.name;
                            dataTypeSelect.appendChild(option);
                        });
                        
                        dataTypeSelect.disabled = false;
                    } else {
                        dataTypeSelect.innerHTML = '<option value="">No data types available</option>';
                    }
                })
                .catch(error => {
                    console.error('Error loading data types:', error);
                    dataTypeSelect.innerHTML = '<option value="">Error loading data types</option>';
                });
        }
        
        // Load data plans for a data type
        function loadDataPlans(dataTypeId) {
            planSelect.innerHTML = '<option value="">-- Loading plans... --</option>';
            planContainer.style.display = 'block';
            planSelect.disabled = true;
            
            // Fetch data plans
            fetch(`get_plans_by_data_type.php?data_type_id=${dataTypeId}`)
                .then(response => response.json())
                .then(data => {
                    planSelect.innerHTML = '<option value="">-- Select Data Plan --</option>';
                    
                    if (data.success && data.plans.length > 0) {
                        data.plans.forEach(plan => {
                            const option = document.createElement('option');
                            option.value = plan.id;
                            option.dataset.price = plan.price;
                            option.dataset.name = plan.name;
                            option.dataset.size = plan.value;
                            option.textContent = `${plan.name} - ${plan.value} - ${formatCurrency(plan.price)}`;
                            planSelect.appendChild(option);
                        });
                        
                        planSelect.disabled = false;
                    } else {
                        planSelect.innerHTML = '<option value="">No plans available</option>';
                    }
                })
                .catch(error => {
                    console.error('Error loading data plans:', error);
                    planSelect.innerHTML = '<option value="">Error loading plans</option>';
                });
        }
        
        // Update price information
        function updatePriceInfo() {
            if (selectedPlanPrice > 0) {
                planPriceElement.textContent = formatCurrency(selectedPlanPrice);
                
                if (promoDiscount > 0) {
                    discountRowElement.classList.remove('hidden');
                    discountAmountElement.textContent = `- ${formatCurrency(promoDiscount)}`;
                    totalPriceElement.textContent = formatCurrency(selectedPlanPrice - promoDiscount);
                } else {
                    discountRowElement.classList.add('hidden');
                    totalPriceElement.textContent = formatCurrency(selectedPlanPrice);
                }
                
                priceInfoCard.classList.remove('hidden');
            } else {
                priceInfoCard.classList.add('hidden');
            }
        }
        
        // Format currency
        function formatCurrency(amount) {
            return '<?php echo $currency; ?>' + parseFloat(amount).toFixed(2);
        }
        
        // Validate promo code
        function validatePromoCode() {
            const promoCode = promoCodeInput.value.trim();
            
            if (!promoCode || !selectedPlanPrice) {
                // Reset promo discount
                promoDiscount = 0;
                promoCodeValidated = false;
                updatePriceInfo();
                
                // Update promo message
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                return;
            }
            
            // Show loading state for Apply button
            applyPromoBtn.innerHTML = '<i class="fas fa-spinner fa-spin mr-1"></i> Checking...';
            applyPromoBtn.disabled = true;
            
            // Show message that we're validating
            promoMessage.textContent = 'Validating promo code...';
            promoMessage.className = 'mt-1 text-sm text-blue-400';
            promoMessage.classList.remove('hidden');
            
            // Fetch promo code validation
            fetch(`${window.location.origin}/dashboard/ajax/validate_promo.php`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `promo_code=${promoCode}&amount=${selectedPlanPrice}&service_type=data`
            })
            .then(response => response.json())
            .then(data => {
                // Re-enable apply button
                applyPromoBtn.innerHTML = '<i class="fas fa-check mr-1"></i> Apply';
                applyPromoBtn.disabled = false;
                
                if (data.success) {
                    promoDiscount = data.discount;
                    promoCodeValidated = true;
                    
                    // Show success message
                    promoMessage.textContent = data.message;
                    promoMessage.className = 'mt-1 text-sm text-green-400';
                    
                    // Update the price display with strikethrough for original price
                    if (promoDiscount > 0) {
                        discountRowElement.classList.remove('hidden');
                        discountAmountElement.innerHTML = `- ${formatCurrency(promoDiscount)} <span class="text-xs">(${promoCode})</span>`;
                    }
                } else {
                    promoDiscount = 0;
                    promoCodeValidated = false;
                    
                    // Show error message
                    promoMessage.textContent = data.message;
                    promoMessage.className = 'mt-1 text-sm text-red-400';
                }
                
                updatePriceInfo();
            })
            .catch(error => {
                console.error('Error validating promo code:', error);
                
                // Re-enable apply button
                applyPromoBtn.innerHTML = '<i class="fas fa-check mr-1"></i> Apply';
                applyPromoBtn.disabled = false;
                
                // Reset promo discount
                promoDiscount = 0;
                promoCodeValidated = false;
                
                // Show error message
                promoMessage.textContent = 'Error validating promo code. Please try again.';
                promoMessage.className = 'mt-1 text-sm text-red-400';
                
                updatePriceInfo();
            });
        }
        
        // Check if all required fields are filled
        function checkFormValidity() {
            const networkSelected = !!selectedNetworkId;
            const dataTypeSelected = !!selectedDataTypeId;
            const planSelected = !!planSelect.value;
            const phoneValid = !!phoneInput.value && phoneInput.value.match(/^(0|\+?234)[789][01]\d{8}$/);
            
            if (networkSelected && dataTypeSelected && planSelected && phoneValid) {
                purchaseBtn.disabled = false;
            } else {
                purchaseBtn.disabled = true;
            }
        }
        
        // Show success modal with transaction details
        function showSuccessModal(data) {
            successNetwork.textContent = data.network || '';
            successPhone.textContent = data.phone || '';
            successPlan.textContent = data.plan || '';
            
            // Check if there was a discount
            if (data.discount && data.discount > 0) {
                successAmount.innerHTML = `
                    <span class="line-through text-gray-400">${formatCurrency(data.original_amount)}</span> 
                    ${formatCurrency(data.final_amount)}`;
            } else {
                successAmount.textContent = formatCurrency(data.amount || data.final_amount || 0);
            }
            
            successRef.textContent = data.reference || '';
            successDate.textContent = data.date || new Date().toLocaleString();
            successMessage.textContent = data.message || 'Your data has been purchased successfully and will be delivered shortly.';
            
            loadingModal.classList.add('hidden');
            successModal.classList.remove('hidden');
        }
        
        // Show error modal with error message
        function showErrorModal(message) {
            errorMessage.textContent = message || 'Sorry, we couldn\'t process your data purchase at this time.';
            
            loadingModal.classList.add('hidden');
            errorModal.classList.remove('hidden');
        }
        
        // Event Listeners
        
        // Network selection
        networkCards.forEach(card => {
            card.addEventListener('click', function() {
                // Remove selected class from all cards
                networkCards.forEach(c => c.classList.remove('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20'));
                
                // Add selected class to this card
                this.classList.add('selected', 'border-indigo-500', 'bg-indigo-900', 'bg-opacity-20');
                
                // Update selected network id
                selectedNetworkId = this.dataset.networkId;
                networkIdInput.value = selectedNetworkId;
                
                // Load data types for this network
                loadDataTypes(selectedNetworkId);
                
                // Reset price info and promo
                selectedPlanPrice = 0;
                promoDiscount = 0;
                promoCodeValidated = false;
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                updatePriceInfo();
                
                // Check form validity
                checkFormValidity();
            });
        });
        
        // Data Type selection
        dataTypeSelect.addEventListener('change', function() {
            selectedDataTypeId = this.value;
            
            if (selectedDataTypeId) {
                // Load data plans for this data type
                loadDataPlans(selectedDataTypeId);
            } else {
                // Reset plan selection
                planSelect.innerHTML = '<option value="">-- Select a data type first --</option>';
                planContainer.style.display = 'none';
                planSelect.disabled = true;
                
                // Reset price info and promo
                selectedPlanPrice = 0;
                promoDiscount = 0;
                promoCodeValidated = false;
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                updatePriceInfo();
            }
            
            checkFormValidity();
        });
        
        // Plan selection
        planSelect.addEventListener('change', function() {
            const selectedOption = this.options[this.selectedIndex];
            
            if (this.value) {
                selectedPlanPrice = parseFloat(selectedOption.dataset.price);
                selectedPlanName = selectedOption.dataset.name;
                selectedPlanSize = selectedOption.dataset.size;
                
                // Reset promo discount when plan changes
                promoDiscount = 0;
                promoCodeValidated = false;
                
                // Clear any promo messages
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                
                // Update price info
                updatePriceInfo();
            } else {
                selectedPlanPrice = 0;
                selectedPlanName = '';
                selectedPlanSize = '';
                promoDiscount = 0;
                promoCodeValidated = false;
                
                updatePriceInfo();
            }
            
            checkFormValidity();
        });
        
        // Phone input
        phoneInput.addEventListener('input', checkFormValidity);
        
        // Save beneficiary checkbox
        saveBeneficiaryCheckbox.addEventListener('change', function() {
            if (this.checked) {
                beneficiaryNameField.classList.remove('hidden');
            } else {
                beneficiaryNameField.classList.add('hidden');
            }
        });
        
        // Apply Promo Code button
        applyPromoBtn.addEventListener('click', validatePromoCode);
        
        // Enter key on promo code input
        promoCodeInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                e.preventDefault();
                validatePromoCode();
            }
        });
        
        // Show beneficiaries modal
        showBeneficiariesBtn.addEventListener('click', function() {
            beneficiariesModal.classList.remove('hidden');
        });
        
        // Close beneficiaries modal
        closeBeneficiariesModal.addEventListener('click', function() {
            beneficiariesModal.classList.add('hidden');
        });
        
        // Select beneficiary
        beneficiaryItems.forEach(item => {
            item.addEventListener('click', function() {
                phoneInput.value = this.dataset.phone;
                beneficiariesModal.classList.add('hidden');
                checkFormValidity();
            });
        });
        
        // Close success modal
        closeSuccessModal.addEventListener('click', function() {
            successModal.classList.add('hidden');
            window.location.reload(); // Reload page to show updated recent purchases
        });
        
        // Close error modal
        closeErrorModal.addEventListener('click', function() {
            errorModal.classList.add('hidden');
        });
        
        // Form submission
        dataPurchaseForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Show loading modal
            loadingModal.classList.remove('hidden');
            
            // Prepare form data
            const formData = new FormData();
            formData.append('network_id', selectedNetworkId);
            formData.append('data_type_id', selectedDataTypeId);
            formData.append('plan_id', planSelect.value);
            formData.append('phone', phoneInput.value);
            
            if (saveBeneficiaryCheckbox.checked && document.getElementById('beneficiary_name').value) {
                formData.append('beneficiary', document.getElementById('beneficiary_name').value);
            }
            
            if (promoCodeInput.value && promoCodeValidated) {
                formData.append('promo_code', promoCodeInput.value);
            }
            
            // Send request
            fetch(`${window.location.origin}/dashboard/process/buy_data.php`, {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // Show success modal
                    showSuccessModal({
                        network: document.querySelector('.network-card.selected').querySelector('.font-medium').textContent,
                        phone: phoneInput.value,
                        plan: selectedPlanSize,
                        original_amount: selectedPlanPrice,
                        discount: promoDiscount,
                        final_amount: selectedPlanPrice - promoDiscount,
                        reference: data.data.reference,
                        message: data.message
                    });
                } else {
                    // Show error modal
                    showErrorModal(data.message);
                }
            })
            .catch(error => {
                console.error('Error processing data purchase:', error);
                showErrorModal('An unexpected error occurred. Please try again later.');
            });
        });
        
        // Buy again buttons
        buyAgainButtons.forEach(button => {
            button.addEventListener('click', function() {
                const networkId = this.dataset.networkId;
                const networkName = this.dataset.network;
                const phone = this.dataset.phone;
                const planId = this.dataset.planId;
                
                // Reset promo fields
                promoCodeInput.value = '';
                promoDiscount = 0;
                promoCodeValidated = false;
                promoMessage.textContent = '';
                promoMessage.classList.add('hidden');
                
                // Set selected network
                networkCards.forEach(card => {
                    if (card.dataset.networkId === networkId) {
                        card.click();
                    }
                });
                
                // Set phone number
                phoneInput.value = phone;
                
                // Wait for data types to load, then select the right data type, then plan
                const waitForDataTypes = setInterval(() => {
                    if (!dataTypeSelect.disabled && dataTypeSelect.options.length > 1) {
                        // Data types loaded, find the right one for this plan
                        fetch(`get_data_type_for_plan.php?plan_id=${planId}`)
                            .then(response => response.json())
                            .then(data => {
                                if (data.success) {
                                    dataTypeSelect.value = data.data_type_id;
                                    dataTypeSelect.dispatchEvent(new Event('change'));
                                    
                                    // Now wait for plans to load
                                    const waitForPlans = setInterval(() => {
                                        if (!planSelect.disabled && planSelect.options.length > 1) {
                                            planSelect.value = planId;
                                            planSelect.dispatchEvent(new Event('change'));
                                            clearInterval(waitForPlans);
                                            
                                            // Scroll to form
                                            document.getElementById('dataPurchaseForm').scrollIntoView({ behavior: 'smooth' });
                                        }
                                    }, 100);
                                }
                            })
                            .catch(error => console.error('Error fetching data type for plan:', error));
                        
                        clearInterval(waitForDataTypes);
                    }
                }, 100);
            });
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', function(e) {
            if (e.target === beneficiariesModal) {
                beneficiariesModal.classList.add('hidden');
            }
            if (e.target === successModal) {
                successModal.classList.add('hidden');
            }
            if (e.target === errorModal) {
                errorModal.classList.add('hidden');
            }
        });
    });
</script>

<?php require_once './includes/footer.php'; ?>