<?php
$pageTitle = 'Cable TV Subscription';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get cable TV providers
$stmt = $conn->prepare("SELECT * FROM cable_providers WHERE status = 'active' ORDER BY name");
$stmt->execute();
$result = $stmt->get_result();
$providers = [];

while ($row = $result->fetch_assoc()) {
    $providers[] = $row;
}

// Get user's recent cable TV purchases
$stmt = $conn->prepare("
    SELECT t.*, cp.name as provider_name
    FROM transactions t
    LEFT JOIN cable_providers cp ON JSON_EXTRACT(t.meta_data, '$.provider_id') = cp.id
    WHERE t.user_id = ? AND t.type = 'cable'
    ORDER BY t.created_at DESC
    LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$recentPurchases = [];

while ($row = $result->fetch_assoc()) {
    $metaData = json_decode($row['meta_data'], true);
    $row['smart_card'] = $metaData['smart_card'] ?? '';
    $row['plan_name'] = $metaData['plan_name'] ?? '';
    $recentPurchases[] = $row;
}

// Get saved beneficiaries
$stmt = $conn->prepare("
    SELECT * FROM beneficiaries 
    WHERE user_id = ? AND type = 'cable'
    ORDER BY name ASC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$beneficiaries = [];

while ($row = $result->fetch_assoc()) {
    $beneficiaries[] = $row;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Cable TV Subscription</h1>
    
    <div class="text-sm text-gray-400 mb-4">
        Pay for cable TV subscriptions for all providers. Instant activation guaranteed.
    </div>
    
    <!-- Cable TV Purchase Form -->
    <form id="cableTvPurchaseForm" class="mt-6">
        <!-- Provider Selection -->
        <div class="mb-6">
            <label class="block text-sm font-medium text-gray-400 mb-2">Select Provider</label>
            <div class="grid grid-cols-2 sm:grid-cols-4 gap-4">
                <?php foreach ($providers as $provider): ?>
                    <div class="provider-card cursor-pointer border border-gray-700 rounded-lg p-4 text-center" data-provider-id="<?php echo $provider['id']; ?>">
                        <div class="h-12 w-12 mx-auto mb-2 rounded-full bg-gray-700 flex items-center justify-center">
                            <i class="fas fa-tv text-xl text-white"></i>
                        </div>
                        <div class="font-medium text-white"><?php echo htmlspecialchars($provider['name']); ?></div>
                    </div>
                <?php endforeach; ?>
            </div>
            <input type="hidden" id="provider_id" name="provider_id" required>
        </div>
        
        <!-- Smart Card Number -->
        <div class="mb-6">
            <label for="smart_card" class="block text-sm font-medium text-gray-400 mb-2">Smart Card/IUC Number</label>
            <div class="flex">
                <input type="text" id="smart_card" name="smart_card" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter your Smart Card/IUC Number" required>
                <button type="button" id="showBeneficiariesBtn" class="bg-gray-700 text-white px-3 rounded-r-md hover:bg-gray-600">
                    <i class="fas fa-address-book"></i>
                </button>
            </div>
            <p class="mt-1 text-sm text-gray-500">
                <span id="customerName" class="hidden"><i class="fas fa-user mr-1"></i> <span id="customerNameValue"></span></span>
            </p>
        </div>
        
        <!-- Verify Button -->
        <div class="mb-6">
            <button type="button" id="verifyBtn" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-500 disabled:opacity-50 disabled:cursor-not-allowed" disabled>
                <i class="fas fa-search mr-1"></i> Verify Smart Card
            </button>
            <div id="verificationMessage" class="mt-2 text-sm hidden"></div>
        </div>
        
        <!-- Plan Selection -->
        <div class="mb-6">
            <label for="plan_id" class="block text-sm font-medium text-gray-400 mb-2">Select Subscription Plan</label>
            <select id="plan_id" name="plan_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required disabled>
                <option value="">-- Verify smart card first --</option>
            </select>
        </div>
        
        <!-- Phone Number -->
        <div class="mb-6">
            <label for="phone" class="block text-sm font-medium text-gray-400 mb-2">Phone Number (Optional)</label>
            <input type="tel" id="phone" name="phone" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter phone number to receive receipt">
        </div>
        
        <!-- Save Beneficiary -->
        <div class="mb-6">
            <label class="inline-flex items-center cursor-pointer">
                <input type="checkbox" id="save_beneficiary" name="save_beneficiary" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                <span class="ml-2 text-gray-400">Save as beneficiary</span>
            </label>
            
            <div id="beneficiaryNameField" class="mt-3 hidden">
                <label for="beneficiary_name" class="block text-sm font-medium text-gray-400 mb-1">Beneficiary Name</label>
                <input type="text" id="beneficiary_name" name="beneficiary_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter a name for this beneficiary">
            </div>
        </div>
        
        <!-- Promo Code -->
        <div class="mb-6">
            <label for="promo_code" class="block text-sm font-medium text-gray-400 mb-2">Promo Code (Optional)</label>
            <input type="text" id="promo_code" name="promo_code" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter promo code if available">
        </div>
        
        <!-- Price Info -->
        <div id="priceInfoCard" class="mb-6 p-4 rounded-md bg-gray-800 hidden">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Plan Price:</span>
                <span id="planPrice" class="text-white font-medium"></span>
            </div>
            <div id="discountRow" class="flex justify-between mb-2 hidden">
                <span class="text-gray-400">Discount:</span>
                <span id="discountAmount" class="text-green-400 font-medium"></span>
            </div>
            <div class="flex justify-between pt-2 border-t border-gray-700">
                <span class="text-gray-300 font-medium">Total Price:</span>
                <span id="totalPrice" class="text-white font-bold"></span>
            </div>
        </div>
        
        <!-- Submit Button -->
        <div class="flex justify-end">
            <button type="submit" id="purchaseBtn" class="accent-button py-2 px-6 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50 disabled:cursor-not-allowed" disabled>
                Pay Subscription
            </button>
        </div>
    </form>
</div>

<!-- Recent Purchases -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Recent Cable TV Subscriptions</h2>
    
    <?php if (empty($recentPurchases)): ?>
        <div class="text-center py-6 text-gray-400">
            <i class="fas fa-history text-3xl mb-2"></i>
            <p>No recent Cable TV subscriptions found</p>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Provider</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Smart Card</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($recentPurchases as $purchase): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, H:i', strtotime($purchase['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($purchase['provider_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($purchase['smart_card']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($purchase['plan_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($purchase['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <span class="status-badge status-<?php echo $purchase['status']; ?>">
                                    <?php echo ucfirst($purchase['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4">
                                <button type="button" class="text-indigo-400 hover:text-indigo-300 buy-again" 
                                        data-provider="<?php echo $purchase['provider_name']; ?>"
                                        data-provider-id="<?php echo json_decode($purchase['meta_data'], true)['provider_id']; ?>"
                                        data-smartcard="<?php echo $purchase['smart_card']; ?>">
                                    <i class="fas fa-redo-alt mr-1"></i> Buy Again
                                </button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Beneficiaries Modal -->
<div id="beneficiariesModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg w-full max-w-md max-h-full overflow-y-auto">
        <div class="p-4 border-b border-gray-700">
            <h3 class="text-xl font-semibold text-white">Saved Beneficiaries</h3>
        </div>
        <div class="p-4">
            <?php if (empty($beneficiaries)): ?>
                <div class="text-center py-6 text-gray-400">
                    <i class="fas fa-address-book text-3xl mb-2"></i>
                    <p>No saved beneficiaries found</p>
                </div>
            <?php else: ?>
                <div class="space-y-3">
                    <?php foreach ($beneficiaries as $beneficiary): ?>
                        <div class="beneficiary-item p-3 bg-gray-700 rounded-md cursor-pointer hover:bg-gray-600" data-smartcard="<?php echo htmlspecialchars($beneficiary['identifier']); ?>">
                            <div class="flex items-center">
                                <div class="w-10 h-10 rounded-full bg-gray-600 flex items-center justify-center mr-3">
                                    <i class="fas fa-tv text-gray-300"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                    <div class="text-sm text-gray-300"><?php echo htmlspecialchars($beneficiary['identifier']); ?></div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        <div class="p-4 border-t border-gray-700 flex justify-end">
            <button type="button" id="closeBeneficiariesModal" class="bg-gray-700 text-white py-2 px-4 rounded-md hover:bg-gray-600">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2" id="loadingText">Processing Your Request</p>
        <p class="text-gray-400" id="loadingSubtext">Please wait while we verify your smart card...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Payment Successful!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your Cable TV subscription has been paid successfully and will be activated shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Provider:</span>
                <span id="successProvider" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Customer Name:</span>
                <span id="successCustomer" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Smart Card/IUC:</span>
                <span id="successSmartCard" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Plan:</span>
                <span id="successPlan" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="successAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Transaction Ref:</span>
                <span id="successRef" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="successDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeSuccessModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Payment Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your cable TV subscription payment at this time.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<'EOT'
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // DOM Elements
        const providerCards = document.querySelectorAll('.provider-card');
        const providerIdInput = document.getElementById('provider_id');
        const smartCardInput = document.getElementById('smart_card');
        const phoneInput = document.getElementById('phone');
        const verifyBtn = document.getElementById('verifyBtn');
        const verificationMessage = document.getElementById('verificationMessage');
        const customerNameElement = document.getElementById('customerName');
        const customerNameValue = document.getElementById('customerNameValue');
        const planSelect = document.getElementById('plan_id');
        const saveBeneficiaryCheckbox = document.getElementById('save_beneficiary');
        const beneficiaryNameField = document.getElementById('beneficiaryNameField');
        const promoCodeInput = document.getElementById('promo_code');
        const purchaseBtn = document.getElementById('purchaseBtn');
        const cableTvPurchaseForm = document.getElementById('cableTvPurchaseForm');
        const priceInfoCard = document.getElementById('priceInfoCard');
        const planPriceElement = document.getElementById('planPrice');
        const discountRowElement = document.getElementById('discountRow');
        const discountAmountElement = document.getElementById('discountAmount');
        const totalPriceElement = document.getElementById('totalPrice');
        
        // Modal Elements
        const beneficiariesModal = document.getElementById('beneficiariesModal');
        const showBeneficiariesBtn = document.getElementById('showBeneficiariesBtn');
        const closeBeneficiariesModal = document.getElementById('closeBeneficiariesModal');
        const beneficiaryItems = document.querySelectorAll('.beneficiary-item');
        const loadingModal = document.getElementById('loadingModal');
        const loadingText = document.getElementById('loadingText');
        const loadingSubtext = document.getElementById('loadingSubtext');
        const successModal = document.getElementById('successModal');
        const closeSuccessModal = document.getElementById('closeSuccessModal');
        const errorModal = document.getElementById('errorModal');
        const closeErrorModal = document.getElementById('closeErrorModal');
        
        // Success modal elements
        const successProvider = document.getElementById('successProvider');
        const successCustomer = document.getElementById('successCustomer');
        const successSmartCard = document.getElementById('successSmartCard');
        const successPlan = document.getElementById('successPlan');
        const successAmount = document.getElementById('successAmount');
        const successRef = document.getElementById('successRef');
        const successDate = document.getElementById('successDate');
        const successMessage = document.getElementById('successMessage');
        
        // Error modal element
        const errorMessage = document.getElementById('errorMessage');
        
        // Buy again buttons
        const buyAgainButtons = document.querySelectorAll('.buy-again');
        
        // Current state
        let selectedProviderId = null;
        let selectedPlanPrice = 0;
        let selectedPlanName = '';
        let customerName = '';
        let promoDiscount = 0;
        let verificationPending = false;
        
        // Functions
        
        // Load cable plans for selected provider
        function loadCablePlans(providerId, smartCard) {
            // Clear current options
            planSelect.innerHTML = '<option value="">Loading plans...</option>';
            planSelect.disabled = true;
            
            // Show verification message
            verificationMessage.classList.remove('text-green-400', 'text-red-400');
            verificationMessage.classList.add('text-gray-400');
            verificationMessage.textContent = 'Fetching available plans...';
            verificationMessage.classList.remove('hidden');
            
            // Fetch cable plans
            fetch(`${window.location.origin}/dashboard/ajax/verify_cable.php`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                },
                body: `provider_id=${providerId}&smart_card=${smartCard}`
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // Show customer name
                    customerName = data.customer_name;
                    customerNameValue.textContent = customerName;
                    customerNameElement.classList.remove('hidden');
                    
                    // Update verification message
                    verificationMessage.classList.remove('text-gray-400', 'text-red-400');
                    verificationMessage.classList.add('text-green-400');
                    verificationMessage.innerHTML = '<i class="fas fa-check-circle mr-1"></i> Smart card verified successfully!';
                    
                    // Populate plans dropdown
                    planSelect.innerHTML = '<option value="">-- Select Subscription Plan --</option>';
                    
                    if (data.plans && data.plans.length > 0) {
                        data.plans.forEach(plan => {
                            const option = document.createElement('option');
                            option.value = plan.id;
                            option.textContent = `${plan.name} - ${formatCurrency(plan.price)} - ${plan.duration}`;
                            option.dataset.price = plan.price;
                            option.dataset.name = plan.name;
                            planSelect.appendChild(option);
                        });
                        
                        planSelect.disabled = false;
                    } else {
                        planSelect.innerHTML = '<option value="">No plans available for this provider</option>';
                    }
                    
                    // If auto-fill beneficiary name checkbox is checked
                    if (saveBeneficiaryCheckbox.checked && document.getElementById('beneficiary_name').value === '') {
                        document.getElementById('beneficiary_name').value = customerName;
                    }
                    
                    verificationPending = false;
                } else {
                    // Show error message
                    verificationMessage.classList.remove('text-gray-400', 'text-green-400');
                    verificationMessage.classList.add('text-red-400');
                    verificationMessage.innerHTML = `<i class="fas fa-exclamation-circle mr-1"></i> ${data.message}`;
                    
                    // Reset plans dropdown
                    planSelect.innerHTML = '<option value="">-- Verify smart card first --</option>';
                    planSelect.disabled = true;
                    
                    // Hide customer name
                    customerNameElement.classList.add('hidden');
                    
                    verificationPending = false;
                }
            })
            .catch(error => {
                console.error('Error verifying smart card:', error);
                
                // Show error message
                verificationMessage.classList.remove('text-gray-400', 'text-green-400');
                verificationMessage.classList.add('text-red-400');
                verificationMessage.innerHTML = '<i class="fas fa-exclamation-circle mr-1"></i> An error occurred while verifying the smart card.';
                
                // Reset plans dropdown
                planSelect.innerHTML = '<option value="">-- Verify smart card first --</option>';
                planSelect.disabled = true;
                
                verificationPending = false;
            });
        }
        
        // Update price information
        function updatePriceInfo() {
            if (selectedPlanPrice > 0) {
                planPriceElement.textContent = formatCurrency(selectedPlanPrice);
                
                if (promoDiscount > 0) {
                    discountRowElement.classList.remove('hidden');
                    discountAmountElement.textContent = `- ${formatCurrency(promoDiscount)}`;
                    totalPriceElement.textContent = formatCurrency(selectedPlanPrice - promoDiscount);
                } else {
                    discountRowElement.classList.add('hidden');
                    totalPriceElement.textContent = formatCurrency(selectedPlanPrice);
                }
                
                priceInfoCard.classList.remove('hidden');
            } else {
                priceInfoCard.classList.add('hidden');
            }
        }
        
        // Format currency
        function formatCurrency(amount) {
            return '${currency}' + parseFloat(amount).toFixed(2);
        }
        
        // Validate promo code
        function validatePromoCode() {
            const promoCode = promoCodeInput.value.trim();
            
            if (!promoCode || !selectedPlanPrice) {
                promoDiscount = 0;
                updatePriceInfo();
                return;
            }
            
            // Fetch promo code validation
            fetch(`${window.location.origin}/dashboard/ajax/validate_promo.php`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `promo_code=${promoCode}&amount=${selectedPlanPrice}&service_type=cable`
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    promoDiscount = data.discount;
                } else {
                    promoDiscount = 0;
                }
                updatePriceInfo();
            })
            .catch(error => {
                console.error('Error validating promo code:', error);
                promoDiscount = 0;
                updatePriceInfo();
            });
        }
        
        // Check if smart card can be verified
        function checkVerifyButton() {
            const providerSelected = !!selectedProviderId;
            const smartCardValid = !!smartCardInput.value.trim();
            
            if (providerSelected && smartCardValid && !verificationPending) {
                verifyBtn.disabled = false;
            } else {
                verifyBtn.disabled = true;
            }
        }
        
        // Check if all required fields are filled
        function checkFormValidity() {
            const providerSelected = !!selectedProviderId;
            const smartCardValid = !!smartCardInput.value.trim();
            const planSelected = !!planSelect.value;
            const customerVerified = !customerNameElement.classList.contains('hidden');
            
            if (providerSelected && smartCardValid && planSelected && customerVerified) {
                purchaseBtn.disabled = false;
            } else {
                purchaseBtn.disabled = true;
            }
        }
        
        // Show success modal with transaction details
        function showSuccessModal(data) {
            successProvider.textContent = data.provider || '';
            successCustomer.textContent = data.customer || '';
            successSmartCard.textContent = data.smart_card || '';
            successPlan.textContent = data.plan || '';
            successAmount.textContent = formatCurrency(data.amount) || '';
            successRef.textContent = data.reference || '';
            successDate.textContent = data.date || new Date().toLocaleString();
            successMessage.textContent = data.message || 'Your Cable TV subscription has been paid successfully and will be activated shortly.';
            
            loadingModal.classList.add('hidden');
            successModal.classList.remove('hidden');
        }
        
        // Show error modal with error message
        function showErrorModal(message) {
            errorMessage.textContent = message || 'Sorry, we couldn\\'t process your Cable TV subscription payment at this time.';
            
            loadingModal.classList.add('hidden');
            errorModal.classList.remove('hidden');
        }
        
        // Event Listeners
        
        // Provider selection
        providerCards.forEach(card => {
            card.addEventListener('click', function() {
                // Remove selected class from all cards
                providerCards.forEach(c => c.classList.remove('selected'));
                
                // Add selected class to this card
                this.classList.add('selected');
                
                // Update selected provider id
                selectedProviderId = this.dataset.providerId;
                providerIdInput.value = selectedProviderId;
                
                // Reset verification
                verificationMessage.classList.add('hidden');
                customerNameElement.classList.add('hidden');
                planSelect.innerHTML = '<option value="">-- Verify smart card first --</option>';
                planSelect.disabled = true;
                
                // Reset price info
                selectedPlanPrice = 0;
                promoDiscount = 0;
                updatePriceInfo();
                
                // Check if verify button can be enabled
                checkVerifyButton();
                
                // Check form validity
                checkFormValidity();
            });
        });
        
        // Smart card input
        smartCardInput.addEventListener('input', function() {
            // Reset verification
            verificationMessage.classList.add('hidden');
            customerNameElement.classList.add('hidden');
            planSelect.innerHTML = '<option value="">-- Verify smart card first --</option>';
            planSelect.disabled = true;
            
            // Check if verify button can be enabled
            checkVerifyButton();
            
            // Check form validity
            checkFormValidity();
        });
        
        // Verify button
        verifyBtn.addEventListener('click', function() {
            // Show loading modal
            loadingText.textContent = 'Verifying Smart Card';
            loadingSubtext.textContent = 'Please wait while we verify your smart card...';
            loadingModal.classList.remove('hidden');
            
            // Set verification pending flag
            verificationPending = true;
            
            // Verify smart card and load plans
            loadCablePlans(selectedProviderId, smartCardInput.value);
            
            // Hide loading modal after verification
            setTimeout(() => {
                loadingModal.classList.add('hidden');
            }, 1000);
        });
        
        // Plan selection
        planSelect.addEventListener('change', function() {
            const selectedOption = this.options[this.selectedIndex];
            
            if (this.value) {
                selectedPlanPrice = parseFloat(selectedOption.dataset.price);
                selectedPlanName = selectedOption.dataset.name;
                validatePromoCode();
            } else {
                selectedPlanPrice = 0;
                selectedPlanName = '';
                updatePriceInfo();
            }
            
            checkFormValidity();
        });
        
        // Phone input
        phoneInput.addEventListener('input', checkFormValidity);
        
        // Save beneficiary checkbox
        saveBeneficiaryCheckbox.addEventListener('change', function() {
            if (this.checked) {
                beneficiaryNameField.classList.remove('hidden');
                
                // Auto-fill with customer name if available
                if (customerName && document.getElementById('beneficiary_name').value === '') {
                    document.getElementById('beneficiary_name').value = customerName;
                }
            } else {
                beneficiaryNameField.classList.add('hidden');
            }
        });
        
        // Promo code input
        promoCodeInput.addEventListener('blur', validatePromoCode);
        
        // Show beneficiaries modal
        showBeneficiariesBtn.addEventListener('click', function() {
            beneficiariesModal.classList.remove('hidden');
        });
        
        // Close beneficiaries modal
        closeBeneficiariesModal.addEventListener('click', function() {
            beneficiariesModal.classList.add('hidden');
        });
        
        // Select beneficiary
        beneficiaryItems.forEach(item => {
            item.addEventListener('click', function() {
                smartCardInput.value = this.dataset.smartcard;
                beneficiariesModal.classList.add('hidden');
                checkVerifyButton();
            });
        });
        
        // Close success modal
        closeSuccessModal.addEventListener('click', function() {
            successModal.classList.add('hidden');
            window.location.reload(); // Reload page to show updated recent purchases
        });
        
        // Close error modal
        closeErrorModal.addEventListener('click', function() {
            errorModal.classList.add('hidden');
        });
        
        // Form submission
        cableTvPurchaseForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Show loading modal
            loadingText.textContent = 'Processing Your Request';
            loadingSubtext.textContent = 'Please wait while we process your subscription payment...';
            loadingModal.classList.remove('hidden');
            
            // Get the selected plan name
            const selectedPlan = planSelect.options[planSelect.selectedIndex].textContent;
            
            // Prepare form data
            const formData = new FormData();
            formData.append('provider_id', selectedProviderId);
            formData.append('plan_id', planSelect.value);
            formData.append('smart_card', smartCardInput.value);
            formData.append('customer_name', customerName);
            
            if (phoneInput.value) {
                formData.append('phone', phoneInput.value);
            }
            
            if (saveBeneficiaryCheckbox.checked && document.getElementById('beneficiary_name').value) {
                formData.append('beneficiary', document.getElementById('beneficiary_name').value);
            }
            
            if (promoCodeInput.value) {
                formData.append('promo_code', promoCodeInput.value);
            }
            
            // Send request
            fetch(`${window.location.origin}/dashboard/process/pay_cable.php`, {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // Show success modal
                    showSuccessModal({
                        provider: document.querySelector('.provider-card.selected').querySelector('.font-medium').textContent,
                        customer: customerName,
                        smart_card: smartCardInput.value,
                        plan: selectedPlan,
                        amount: selectedPlanPrice - promoDiscount,
                        reference: data.data.reference,
                        message: data.message
                    });
                } else {
                    // Show error modal
                    showErrorModal(data.message);
                }
            })
            .catch(error => {
                console.error('Error processing cable TV payment:', error);
                showErrorModal('An unexpected error occurred. Please try again later.');
            });
        });
        
        // Buy again buttons
        buyAgainButtons.forEach(button => {
            button.addEventListener('click', function() {
                const providerId = this.dataset.providerId;
                const providerName = this.dataset.provider;
                const smartCard = this.dataset.smartcard;
                
                // Set selected provider
                providerCards.forEach(card => {
                    if (card.dataset.providerId === providerId) {
                        card.click();
                    }
                });
                
                // Set smart card
                smartCardInput.value = smartCard;
                
                // Check verify button
                checkVerifyButton();
                
                // Scroll to form
                document.getElementById('cableTvPurchaseForm').scrollIntoView({ behavior: 'smooth' });
            });
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', function(e) {
            if (e.target === beneficiariesModal) {
                beneficiariesModal.classList.add('hidden');
            }
            if (e.target === successModal) {
                successModal.classList.add('hidden');
            }
            if (e.target === errorModal) {
                errorModal.classList.add('hidden');
            }
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>