<?php
$pageTitle = 'FAQs';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Define FAQs by category
$faqCategories = [
    'general' => [
        'name' => 'General',
        'icon' => 'info-circle',
        'color' => 'blue',
        'questions' => [
            [
                'question' => 'What is Teleco VTU?',
                'answer' => 'Teleco VTU is a virtual top-up platform that enables you to buy airtime, data bundles, pay cable TV subscriptions, and electricity bills conveniently online.'
            ],
            [
                'question' => 'How do I get started?',
                'answer' => 'To get started, create an account, fund your wallet using any of our payment methods, and you\'re ready to make purchases.'
            ],
            [
                'question' => 'How safe is my information?',
                'answer' => 'We take security seriously. All transactions and personal data are encrypted and secured using industry-standard security protocols.'
            ],
            [
                'question' => 'What are the operational hours?',
                'answer' => 'Our platform is available 24/7 for automated services. Customer support is available Monday to Friday, 8:00 AM - 6:00 PM WAT.'
            ],
            [
                'question' => 'How do I fund my wallet?',
                'answer' => 'You can fund your wallet through various channels including card payment, bank transfer, and USSD. Visit the "Fund Wallet" page for details.'
            ]
        ]
    ],
    'account' => [
        'name' => 'Account & Wallet',
        'icon' => 'user-circle',
        'color' => 'purple',
        'questions' => [
            [
                'question' => 'How do I change my password?',
                'answer' => 'To change your password, go to your profile settings, click on "Change Password", enter your current password and then set your new password.'
            ],
            [
                'question' => 'What is the minimum amount I can fund?',
                'answer' => 'The minimum amount you can fund your wallet with is ₦100.'
            ],
            [
                'question' => 'How do I check my transaction history?',
                'answer' => 'Your transaction history can be viewed in the "Transactions" section of your dashboard.'
            ],
            [
                'question' => 'What should I do if I forget my password?',
                'answer' => 'Click on the "Forgot Password" link on the login page and follow the instructions to reset your password.'
            ],
            [
                'question' => 'What are the different user account types?',
                'answer' => 'We offer three account types: Standard (for regular users), Vendor (for resellers), and API (for developers who want to integrate our services).'
            ]
        ]
    ],
    'data' => [
        'name' => 'Data Services',
        'icon' => 'wifi',
        'color' => 'indigo',
        'questions' => [
            [
                'question' => 'Which networks do you support for data purchases?',
                'answer' => 'We support all major networks in Nigeria including MTN, Airtel, Glo, and 9mobile.'
            ],
            [
                'question' => 'How long does it take for data to be delivered?',
                'answer' => 'Data purchases are processed instantly. You should receive the data within seconds to minutes after purchase.'
            ],
            [
                'question' => 'What happens if my data isn\'t delivered?',
                'answer' => 'If your data isn\'t delivered within 5 minutes, please contact our support team with your transaction reference.'
            ],
            [
                'question' => 'Can I buy data for someone else?',
                'answer' => 'Yes, you can purchase data for anyone. Just enter their phone number during the purchase process.'
            ],
            [
                'question' => 'Do data plans auto-renew?',
                'answer' => 'No, data plans do not auto-renew. You need to make a new purchase when your data expires.'
            ]
        ]
    ],
    'airtime' => [
        'name' => 'Airtime Services',
        'icon' => 'phone',
        'color' => 'green',
        'questions' => [
            [
                'question' => 'Is there a discount on airtime purchases?',
                'answer' => 'Yes, we offer discounts on airtime purchases. The exact discount depends on your account type and the network.'
            ],
            [
                'question' => 'Can I buy airtime for any network?',
                'answer' => 'Yes, you can purchase airtime for all major networks in Nigeria.'
            ],
            [
                'question' => 'What is the minimum and maximum airtime I can buy?',
                'answer' => 'The minimum amount is ₦50 and the maximum is ₦50,000 per transaction.'
            ],
            [
                'question' => 'How do I buy airtime for multiple numbers at once?',
                'answer' => 'You can save frequent numbers as beneficiaries and select them during purchase, or use our bulk airtime feature for corporate purchases.'
            ],
            [
                'question' => 'What if my airtime purchase fails?',
                'answer' => 'If your airtime purchase fails, the amount will be refunded to your wallet automatically. If not, please contact support.'
            ]
        ]
    ],
    'cable' => [
        'name' => 'Cable TV',
        'icon' => 'tv',
        'color' => 'red',
        'questions' => [
            [
                'question' => 'Which Cable TV providers do you support?',
                'answer' => 'We support major providers including DSTV, GOTV, and Startimes.'
            ],
            [
                'question' => 'How do I verify my smart card number?',
                'answer' => 'When you enter your smart card number during the purchase process, the system automatically verifies it and displays the customer name.'
            ],
            [
                'question' => 'How long does it take for my subscription to be activated?',
                'answer' => 'Cable TV subscriptions are usually activated within minutes after payment confirmation.'
            ],
            [
                'question' => 'Can I upgrade my current subscription?',
                'answer' => 'Yes, you can upgrade your subscription by purchasing a higher package. The new package will take effect immediately.'
            ],
            [
                'question' => 'What if my Cable TV subscription fails?',
                'answer' => 'If your subscription fails, your wallet will be refunded. Contact support if you encounter any issues.'
            ]
        ]
    ],
    'electricity' => [
        'name' => 'Electricity',
        'icon' => 'bolt',
        'color' => 'yellow',
        'questions' => [
            [
                'question' => 'Which electricity providers do you support?',
                'answer' => 'We support all major electricity distribution companies in Nigeria including EKEDC, IKEDC, AEDC, PHEDC, and others.'
            ],
            [
                'question' => 'How do I verify my meter number?',
                'answer' => 'Enter your meter number during the purchase process, and the system will automatically verify it and display the customer details.'
            ],
            [
                'question' => 'Where will I find my token after payment?',
                'answer' => 'Your token will be displayed on the success page, sent to your email, and also available in your transaction history.'
            ],
            [
                'question' => 'What\'s the minimum amount for electricity purchase?',
                'answer' => 'The minimum amount for electricity purchase is ₦1,000.'
            ],
            [
                'question' => 'What if I enter the wrong meter number?',
                'answer' => 'The system verifies your meter before processing the payment. If you enter an incorrect meter number, the transaction won\'t proceed.'
            ]
        ]
    ],
    'reseller' => [
        'name' => 'Reseller Panel',
        'icon' => 'store',
        'color' => 'pink',
        'questions' => [
            [
                'question' => 'What is a Reseller Panel?',
                'answer' => 'A Reseller Panel is a white-label VTU platform that allows you to start your own VTU business under your brand name.'
            ],
            [
                'question' => 'How do I get a Reseller Panel?',
                'answer' => 'You can purchase a reseller panel from the Reseller Panel page in your dashboard.'
            ],
            [
                'question' => 'What features come with the Reseller Panel?',
                'answer' => 'The Reseller Panel includes all our services (data, airtime, cable TV, electricity), customizable branding, sub-reseller management, comprehensive reporting, and more.'
            ],
            [
                'question' => 'How long is the Reseller Panel valid?',
                'answer' => 'The Reseller Panel is valid for one year from the activation date and can be renewed annually.'
            ],
            [
                'question' => 'Can I use my own domain name?',
                'answer' => 'Yes, you can use your own domain name with the Reseller Panel. Alternatively, we can provide you with a subdomain.'
            ]
        ]
    ]
];

// Get search query if any
$searchQuery = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Filter FAQs based on search query
if (!empty($searchQuery)) {
    $searchResults = [];
    
    foreach ($faqCategories as $categoryKey => $category) {
        $matchingQuestions = [];
        
        foreach ($category['questions'] as $question) {
            if (stripos($question['question'], $searchQuery) !== false || 
                stripos($question['answer'], $searchQuery) !== false) {
                $matchingQuestions[] = $question;
            }
        }
        
        if (!empty($matchingQuestions)) {
            $searchResults[$categoryKey] = [
                'name' => $category['name'],
                'icon' => $category['icon'],
                'color' => $category['color'],
                'questions' => $matchingQuestions
            ];
        }
    }
    
    $displayCategories = $searchResults;
} else {
    $displayCategories = $faqCategories;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex flex-col md:flex-row justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white mb-4 md:mb-0">Frequently Asked Questions</h1>
        
        <form action="" method="GET" class="w-full md:w-auto">
            <div class="relative">
                <input type="text" name="search" placeholder="Search FAQs..." class="form-input pl-10 pr-4 py-2 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 w-full md:w-64" value="<?php echo htmlspecialchars($searchQuery); ?>">
                <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                    <i class="fas fa-search text-gray-400"></i>
                </div>
                <?php if (!empty($searchQuery)): ?>
                    <a href="<?php echo SITE_URL; ?>/dashboard/faqs.php" class="absolute inset-y-0 right-0 pr-3 flex items-center">
                        <i class="fas fa-times text-gray-400 hover:text-gray-600"></i>
                    </a>
                <?php endif; ?>
            </div>
        </form>
    </div>
    
    <?php if (!empty($searchQuery)): ?>
        <div class="bg-gray-800 p-4 rounded-md mb-6">
            <p class="text-gray-300">
                <?php 
                $totalResults = 0;
                foreach ($displayCategories as $category) {
                    $totalResults += count($category['questions']);
                }
                
                if ($totalResults > 0) {
                    echo "Showing {$totalResults} results for \"" . htmlspecialchars($searchQuery) . "\"";
                } else {
                    echo "No results found for \"" . htmlspecialchars($searchQuery) . "\"";
                }
                ?>
            </p>
        </div>
    <?php endif; ?>
    
    <?php if (empty($displayCategories)): ?>
        <div class="text-center py-10">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-search text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-gray-400 mb-1">No Results Found</h3>
            <p class="text-gray-500 text-sm mb-4">We couldn't find any FAQs matching your search.</p>
            <a href="<?php echo SITE_URL; ?>/dashboard/faqs.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm inline-block">
                Clear Search
            </a>
        </div>
    <?php else: ?>
        <div class="space-y-6">
            <?php foreach ($displayCategories as $categoryKey => $category): ?>
                <div class="bg-gray-800 rounded-lg overflow-hidden">
                    <div class="bg-gray-700 p-4 flex items-center">
                        <div class="h-10 w-10 rounded-full bg-<?php echo $category['color']; ?>-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-<?php echo $category['icon']; ?> text-<?php echo $category['color']; ?>-400"></i>
                        </div>
                        <h2 class="text-lg font-semibold text-white"><?php echo htmlspecialchars($category['name']); ?> FAQs</h2>
                    </div>
                    
                    <div class="divide-y divide-gray-700">
                        <?php foreach ($category['questions'] as $index => $faq): ?>
                            <div class="faq-item">
                                <button class="faq-question w-full text-left py-4 px-6 focus:outline-none flex justify-between items-center">
                                    <span class="text-white font-medium"><?php echo htmlspecialchars($faq['question']); ?></span>
                                    <i class="fas fa-chevron-down text-gray-400 transition-transform"></i>
                                </button>
                                <div class="faq-answer px-6 pb-4 hidden">
                                    <p class="text-gray-300"><?php echo htmlspecialchars($faq['answer']); ?></p>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>
</div>

<!-- Still Need Help Card -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">
        <i class="fas fa-headset mr-2 text-indigo-400"></i> Still Need Help?
    </h2>
    <div class="bg-gray-800 rounded-lg p-6">
        <p class="text-gray-400 mb-6">
            Can't find the answer you're looking for? Our support team is here to help you with any questions or issues you may have.
        </p>
        
        <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
            <a href="<?php echo SITE_URL; ?>/dashboard/support.php" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 text-center transition-colors">
                <div class="h-12 w-12 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fas fa-ticket-alt text-indigo-400"></i>
                </div>
                <div class="font-medium text-white mb-1">Submit a Ticket</div>
                <div class="text-xs text-gray-400">Get personalized support</div>
            </a>
            
            <a href="mailto:<?php echo getSetting('support_email') ?: 'support@teleco.com.ng'; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 text-center transition-colors">
                <div class="h-12 w-12 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fas fa-envelope text-blue-400"></i>
                </div>
                <div class="font-medium text-white mb-1">Email Us</div>
                <div class="text-xs text-gray-400"><?php echo getSetting('support_email') ?: 'support@teleco.com.ng'; ?></div>
            </a>
            
            <a href="https://wa.me/<?php echo str_replace(['+', ' ', '-'], '', getSetting('whatsapp_number') ?: '+234800123456'); ?>" target="_blank" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 text-center transition-colors">
                <div class="h-12 w-12 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fab fa-whatsapp text-green-400"></i>
                </div>
                <div class="font-medium text-white mb-1">WhatsApp</div>
                <div class="text-xs text-gray-400">Chat with us on WhatsApp</div>
            </a>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // FAQ accordion functionality
        const faqQuestions = document.querySelectorAll('.faq-question');
        
        faqQuestions.forEach(question => {
            question.addEventListener('click', function() {
                const answer = this.nextElementSibling;
                const icon = this.querySelector('i');
                
                // Toggle this FAQ
                answer.classList.toggle('hidden');
                icon.classList.toggle('transform');
                icon.classList.toggle('rotate-180');
                
                // Optional: Close other open FAQs in same category
                // const parentFaqItem = this.closest('.faq-item');
                // const siblingFaqItems = parentFaqItem.parentElement.children;
                
                // Array.from(siblingFaqItems).forEach(item => {
                //     if (item !== parentFaqItem) {
                //         const siblingAnswer = item.querySelector('.faq-answer');
                //         const siblingIcon = item.querySelector('.faq-question i');
                //         
                //         siblingAnswer.classList.add('hidden');
                //         siblingIcon.classList.remove('transform', 'rotate-180');
                //     }
                // });
            });
        });
        
        // If there's a search query, open all FAQ items to show matches
        <?php if (!empty($searchQuery)): ?>
        faqQuestions.forEach(question => {
            const answer = question.nextElementSibling;
            const icon = question.querySelector('i');
            
            answer.classList.remove('hidden');
            icon.classList.add('transform', 'rotate-180');
        });
        <?php endif; ?>
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>