<?php
$pageTitle = 'Fund Wallet';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get selected payment method from URL
$paymentMethod = isset($_GET['method']) ? sanitizeInput($_GET['method']) : '';

// Get bank details
$bankName = getSetting('bank_name');
$accountName = getSetting('account_name');
$accountNumber = getSetting('account_number');

// Get USSD code
$ussdCode = getSetting('ussd_code');

// Get Paystack public key
$paystackPublicKey = getSetting('paystack_public_key');
// Log the available Paystack key
error_log("Available Paystack public key: " . $paystackPublicKey);

// Get recent funding
$stmt = $conn->prepare("
    SELECT * FROM transactions 
    WHERE user_id = ? AND type = 'fund'
    ORDER BY created_at DESC
    LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$recentFunding = [];

while ($row = $result->fetch_assoc()) {
    $recentFunding[] = $row;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Fund Wallet</h1>
    
    <div class="text-sm text-gray-400 mb-6">
        Current Balance: <span class="font-semibold text-white"><?php echo $currency . number_format($user['balance'], 2); ?></span>
    </div>
    
    <!-- Payment Methods -->
    <div class="grid grid-cols-1 md:grid-cols-3 gap-4 mb-6">
        <a href="?method=paystack" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 flex items-center <?php echo $paymentMethod === 'paystack' ? 'border-2 border-indigo-500' : ''; ?>">
            <div class="h-10 w-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                <i class="fas fa-credit-card text-green-400"></i>
            </div>
            <div>
                <div class="font-medium text-white">Card Payment</div>
                <div class="text-xs text-gray-400">Pay with Paystack</div>
            </div>
        </a>
        
        <a href="?method=bank_transfer" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 flex items-center <?php echo $paymentMethod === 'bank_transfer' ? 'border-2 border-indigo-500' : ''; ?>">
            <div class="h-10 w-10 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mr-3">
                <i class="fas fa-university text-blue-400"></i>
            </div>
            <div>
                <div class="font-medium text-white">Bank Transfer</div>
                <div class="text-xs text-gray-400">Manual bank transfer</div>
            </div>
        </a>
        
        <a href="?method=ussd" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 flex items-center <?php echo $paymentMethod === 'ussd' ? 'border-2 border-indigo-500' : ''; ?>">
            <div class="h-10 w-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                <i class="fas fa-mobile-alt text-yellow-400"></i>
            </div>
            <div>
                <div class="font-medium text-white">USSD</div>
                <div class="text-xs text-gray-400">Pay with USSD code</div>
            </div>
        </a>
    </div>
    
    <?php if ($paymentMethod === 'paystack'): ?>
        <!-- Paystack Payment Form -->
        <div class="bg-gray-800 rounded-lg p-6">
            <h2 class="text-lg font-semibold text-white mb-4">Fund with Card Payment</h2>
            
            <form id="paystackForm" class="space-y-4">
                <div>
                    <label for="amount" class="block text-sm font-medium text-gray-400 mb-2">Amount (<?php echo $currency; ?>)</label>
                    <div class="relative">
                        <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                            <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                        </div>
                        <input type="number" id="amount" name="amount" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="100" step="0.01" required>
                    </div>
                </div>
                
                <input type="hidden" name="payment_method" value="paystack">
                
                <div class="pt-4">
                    <button type="submit" id="paystackPayBtn" class="accent-button w-full py-2 px-4 rounded-md text-white flex items-center justify-center">
                        <span id="paystackBtnText">Pay Now</span>
                        <span id="paystackBtnLoader" class="hidden">
                            <svg class="animate-spin ml-2 h-4 w-4 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                                <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
                                <path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                            </svg>
                        </span>
                    </button>
                </div>
            </form>
        </div>
    <?php elseif ($paymentMethod === 'bank_transfer'): ?>
        <!-- Bank Transfer Instructions -->
        <div class="bg-gray-800 rounded-lg p-6">
            <h2 class="text-lg font-semibold text-white mb-4">Fund with Bank Transfer</h2>
            
            <?php if (empty($bankName) || empty($accountName) || empty($accountNumber)): ?>
                <div class="bg-red-500 bg-opacity-20 text-red-400 p-4 rounded-md mb-4">
                    <p>Bank transfer details are not available at the moment. Please try another payment method or contact support.</p>
                </div>
            <?php else: ?>
                <form id="bankTransferForm" class="space-y-4">
                    <div>
                        <label for="amount_bank" class="block text-sm font-medium text-gray-400 mb-2">Amount (<?php echo $currency; ?>)</label>
                        <div class="relative">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                            </div>
                            <input type="number" id="amount_bank" name="amount" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="100" step="0.01" required>
                        </div>
                    </div>
                    
                    <input type="hidden" name="payment_method" value="bank_transfer">
                    
                    <div class="pt-4">
                        <button type="submit" id="bankTransferBtn" class="accent-button w-full py-2 px-4 rounded-md text-white flex items-center justify-center">
                            <span id="bankTransferBtnText">Get Bank Details</span>
                            <span id="bankTransferBtnLoader" class="hidden">
                                <svg class="animate-spin ml-2 h-4 w-4 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                                    <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
                                    <path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                                </svg>
                            </span>
                        </button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    <?php elseif ($paymentMethod === 'ussd'): ?>
        <!-- USSD Payment Form -->
        <div class="bg-gray-800 rounded-lg p-6">
            <h2 class="text-lg font-semibold text-white mb-4">Fund with USSD</h2>
            
            <?php if (empty($ussdCode)): ?>
                <div class="bg-red-500 bg-opacity-20 text-red-400 p-4 rounded-md mb-4">
                    <p>USSD payment is not available at the moment. Please try another payment method or contact support.</p>
                </div>
            <?php else: ?>
                <form id="ussdForm" class="space-y-4">
                    <div>
                        <label for="amount_ussd" class="block text-sm font-medium text-gray-400 mb-2">Amount (<?php echo $currency; ?>)</label>
                        <div class="relative">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                            </div>
                            <input type="number" id="amount_ussd" name="amount" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="100" step="0.01" required>
                        </div>
                    </div>
                    
                    <input type="hidden" name="payment_method" value="ussd">
                    
                    <div class="pt-4">
                        <button type="submit" id="ussdBtn" class="accent-button w-full py-2 px-4 rounded-md text-white flex items-center justify-center">
                            <span id="ussdBtnText">Get USSD Code</span>
                            <span id="ussdBtnLoader" class="hidden">
                                <svg class="animate-spin ml-2 h-4 w-4 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                                    <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
                                    <path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                                </svg>
                            </span>
                        </button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <!-- Payment Method Selection -->
        <div class="bg-gray-800 rounded-lg p-6 text-center">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-wallet text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-white mb-2">Select a Payment Method</h3>
            <p class="text-gray-400 mb-4">Choose your preferred payment method above to fund your wallet</p>
        </div>
    <?php endif; ?>
</div>

<!-- Recent Funding History -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Recent Funding History</h2>
    
    <?php if (empty($recentFunding)): ?>
        <div class="text-center py-10">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-history text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-gray-400 mb-1">No Funding History</h3>
            <p class="text-gray-500 text-sm">Your recent wallet funding will appear here</p>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Reference</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Method</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($recentFunding as $funding): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, H:i', strtotime($funding['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-indigo-400">
                                <?php echo htmlspecialchars($funding['txn_ref']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($funding['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php
                                $method = 'Other';
                                if (strpos($funding['description'], 'Paystack') !== false) {
                                    $method = 'Card Payment';
                                } elseif (strpos($funding['description'], 'bank') !== false) {
                                    $method = 'Bank Transfer';
                                } elseif (strpos($funding['description'], 'USSD') !== false) {
                                    $method = 'USSD';
                                }
                                echo $method;
                                ?>
                            </td>
                            <td class="py-3 px-4">
                                <span class="status-badge status-<?php echo $funding['status']; ?>">
                                    <?php echo ucfirst($funding['status']); ?>
                                </span>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Bank Transfer Details Modal -->
<div id="bankDetailsModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-blue-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-university text-3xl text-blue-400"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Bank Transfer Details</h3>
            <p class="text-gray-400 mt-2">Make a transfer to the account below</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Bank Name:</span>
                <span id="bankNameDisplay" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Account Name:</span>
                <span id="accountNameDisplay" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Account Number:</span>
                <span id="accountNumberDisplay" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="amountDisplay" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Reference:</span>
                <span id="referenceDisplay" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="bg-yellow-800 bg-opacity-30 p-4 rounded-md mb-4 border border-yellow-700">
            <div class="flex">
                <i class="fas fa-info-circle text-yellow-400 mr-2 mt-1"></i>
                <div>
                    <p class="text-yellow-200 text-sm">Please use the reference number above when making your transfer. Your wallet will be credited once payment is confirmed.</p>
                </div>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeBankDetailsModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- USSD Code Modal -->
<div id="ussdCodeModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-yellow-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-mobile-alt text-3xl text-yellow-400"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">USSD Payment</h3>
            <p class="text-gray-400 mt-2">Dial the code below on your phone</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4 text-center">
            <div class="text-2xl font-bold text-white" id="ussdCodeDisplay"></div>
            <div class="text-sm text-gray-400 mt-2">Use reference: <span id="ussdReferenceDisplay" class="text-white"></span></div>
        </div>
        <div class="bg-yellow-800 bg-opacity-30 p-4 rounded-md mb-4 border border-yellow-700">
            <div class="flex">
                <i class="fas fa-info-circle text-yellow-400 mr-2 mt-1"></i>
                <div>
                    <p class="text-yellow-200 text-sm">Follow the prompts on your phone after dialing the code. Your wallet will be credited automatically once payment is confirmed.</p>
                </div>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeUssdCodeModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Error</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">An error occurred. Please try again.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<'EOT'
<script src="https://js.paystack.co/v1/inline.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Paystack Form
        const paystackForm = document.getElementById('paystackForm');
        const paystackPayBtn = document.getElementById('paystackPayBtn');
        const paystackBtnText = document.getElementById('paystackBtnText');
        const paystackBtnLoader = document.getElementById('paystackBtnLoader');
        
        // Bank Transfer Form
        const bankTransferForm = document.getElementById('bankTransferForm');
        const bankTransferBtn = document.getElementById('bankTransferBtn');
        const bankTransferBtnText = document.getElementById('bankTransferBtnText');
        const bankTransferBtnLoader = document.getElementById('bankTransferBtnLoader');
        
        // USSD Form
        const ussdForm = document.getElementById('ussdForm');
        const ussdBtn = document.getElementById('ussdBtn');
        const ussdBtnText = document.getElementById('ussdBtnText');
        const ussdBtnLoader = document.getElementById('ussdBtnLoader');
        
        // Bank Details Modal
        const bankDetailsModal = document.getElementById('bankDetailsModal');
        const closeBankDetailsModal = document.getElementById('closeBankDetailsModal');
        const bankNameDisplay = document.getElementById('bankNameDisplay');
        const accountNameDisplay = document.getElementById('accountNameDisplay');
        const accountNumberDisplay = document.getElementById('accountNumberDisplay');
        const amountDisplay = document.getElementById('amountDisplay');
        const referenceDisplay = document.getElementById('referenceDisplay');
        
        // USSD Code Modal
        const ussdCodeModal = document.getElementById('ussdCodeModal');
        const closeUssdCodeModal = document.getElementById('closeUssdCodeModal');
        const ussdCodeDisplay = document.getElementById('ussdCodeDisplay');
        const ussdReferenceDisplay = document.getElementById('ussdReferenceDisplay');
        
        // Error Modal
        const errorModal = document.getElementById('errorModal');
        const closeErrorModal = document.getElementById('closeErrorModal');
        const errorMessage = document.getElementById('errorMessage');
        
        // Helper functions
        function showLoader(button, text, loader) {
            text.classList.add('hidden');
            loader.classList.remove('hidden');
            button.disabled = true;
        }
        
        function hideLoader(button, text, loader) {
            text.classList.remove('hidden');
            loader.classList.add('hidden');
            button.disabled = false;
        }
        
        function showError(message) {
            errorMessage.textContent = message;
            errorModal.classList.remove('hidden');
        }
        
        // Paystack Payment
        if (paystackForm) {
            paystackForm.addEventListener('submit', function(e) {
                e.preventDefault();
                
                const amount = parseFloat(document.getElementById('amount').value);
                
                if (isNaN(amount) || amount <= 0) {
                    showError('Please enter a valid amount');
                    return;
                }
                
                // Show loader
                showLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                
                // Send request to get payment details
                fetch('${window.location.origin}/dashboard/process/fund_wallet.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        'amount': amount,
                        'payment_method': 'paystack'
                    })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Initialize Paystack payment
                        let paystack_key = data.data.paystack_key;
                        console.log("Received Paystack key:", paystack_key);
                        
                        let paystack_data = data.data.paystack_data;
                        
                        // Check if we have a valid key
                        if (!paystack_key || paystack_key.trim() === "") {
                            showError('Invalid Paystack configuration. Please contact support.');
                            hideLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                            return;
                        }
                        
                        try {
                            let handler = PaystackPop.setup({
                                key: paystack_key,
                                email: paystack_data.email,
                                amount: paystack_data.amount,
                                currency: paystack_data.currency,
                                ref: paystack_data.reference,
                                callback: function(response) {
                                    // Redirect to verify payment
                                    window.location.href = '${window.location.origin}/dashboard/verify_payment.php?reference=' + response.reference;
                                },
                                onClose: function() {
                                    // Hide loader if user closes payment modal
                                    hideLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                                }
                            });
                            handler.openIframe();
                        } catch (error) {
                            console.error("Paystack initialization error:", error);
                            showError('Failed to initialize payment gateway. Please try again later.');
                            hideLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                        }
                    } else {
                        showError(data.message || 'An error occurred. Please try again.');
                        hideLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    showError('An unexpected error occurred. Please try again later.');
                    hideLoader(paystackPayBtn, paystackBtnText, paystackBtnLoader);
                });
            });
        }
        
        // Bank Transfer
        if (bankTransferForm) {
            bankTransferForm.addEventListener('submit', function(e) {
                e.preventDefault();
                
                const amount = parseFloat(document.getElementById('amount_bank').value);
                
                if (isNaN(amount) || amount <= 0) {
                    showError('Please enter a valid amount');
                    return;
                }
                
                // Show loader
                showLoader(bankTransferBtn, bankTransferBtnText, bankTransferBtnLoader);
                
                // Send request to get bank details
                fetch('${window.location.origin}/dashboard/process/fund_wallet.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        'amount': amount,
                        'payment_method': 'bank_transfer'
                    })
                })
                .then(response => response.json())
                .then(data => {
                    // Hide loader
                    hideLoader(bankTransferBtn, bankTransferBtnText, bankTransferBtnLoader);
                    
                    if (data.success) {
                        // Show bank details modal
                        bankNameDisplay.textContent = data.data.bank_name;
                        accountNameDisplay.textContent = data.data.account_name;
                        accountNumberDisplay.textContent = data.data.account_number;
                        amountDisplay.textContent = '${currency}' + parseFloat(data.data.amount).toFixed(2);
                        referenceDisplay.textContent = data.data.reference;
                        
                        bankDetailsModal.classList.remove('hidden');
                    } else {
                        showError(data.message || 'An error occurred. Please try again.');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    showError('An unexpected error occurred. Please try again later.');
                    hideLoader(bankTransferBtn, bankTransferBtnText, bankTransferBtnLoader);
                });
            });
        }
        
        // USSD Payment
        if (ussdForm) {
            ussdForm.addEventListener('submit', function(e) {
                e.preventDefault();
                
                const amount = parseFloat(document.getElementById('amount_ussd').value);
                
                if (isNaN(amount) || amount <= 0) {
                    showError('Please enter a valid amount');
                    return;
                }
                
                // Show loader
                showLoader(ussdBtn, ussdBtnText, ussdBtnLoader);
                
                // Send request to get USSD code
                fetch('${window.location.origin}/dashboard/process/fund_wallet.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        'amount': amount,
                        'payment_method': 'ussd'
                    })
                })
                .then(response => response.json())
                .then(data => {
                    // Hide loader
                    hideLoader(ussdBtn, ussdBtnText, ussdBtnLoader);
                    
                    if (data.success) {
                        // Show USSD code modal
                        ussdCodeDisplay.textContent = data.data.ussd_code;
                        ussdReferenceDisplay.textContent = data.data.reference;
                        
                        ussdCodeModal.classList.remove('hidden');
                    } else {
                        showError(data.message || 'An error occurred. Please try again.');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    showError('An unexpected error occurred. Please try again later.');
                    hideLoader(ussdBtn, ussdBtnText, ussdBtnLoader);
                });
            });
        }
        
        // Close Bank Details Modal
        if (closeBankDetailsModal) {
            closeBankDetailsModal.addEventListener('click', function() {
                bankDetailsModal.classList.add('hidden');
            });
        }
        
        // Close USSD Code Modal
        if (closeUssdCodeModal) {
            closeUssdCodeModal.addEventListener('click', function() {
                ussdCodeModal.classList.add('hidden');
            });
        }
        
        // Close Error Modal
        if (closeErrorModal) {
            closeErrorModal.addEventListener('click', function() {
                errorModal.classList.add('hidden');
            });
        }
        
        // Close modals when clicking outside
        window.addEventListener('click', function(e) {
            if (e.target === bankDetailsModal) {
                bankDetailsModal.classList.add('hidden');
            }
            if (e.target === ussdCodeModal) {
                ussdCodeModal.classList.add('hidden');
            }
            if (e.target === errorModal) {
                errorModal.classList.add('hidden');
            }
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>