<?php
// File: /dashboard/get_plans_by_data_type.php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'Unauthorized']);
    exit;
}

// Get data type ID from query params
$data_type_id = isset($_GET['data_type_id']) ? (int)$_GET['data_type_id'] : 0;

if ($data_type_id <= 0) {
    echo json_encode(['success' => false, 'message' => 'Invalid data type ID']);
    exit;
}

// Get user data to determine price tier
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

$stmt = $conn->prepare("SELECT user_type FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode(['success' => false, 'message' => 'User not found']);
    exit;
}

// Determine price field based on user type
$priceField = 'price';
switch ($user['user_type']) {
    case 'smart':
        $priceField = 'amount_smart';
        break;
    case 'api':
        $priceField = 'amount_api';
        break;
    case 'vendor':
        $priceField = 'amount_vendor';
        break;
}

// Get all active plans for the selected data type
$plans = [];
$stmt = $conn->prepare("
    SELECT id, name, size as value, $priceField as price 
    FROM data_plans 
    WHERE data_type_id = ? AND status = 'active' 
    ORDER BY $priceField ASC
");
$stmt->bind_param("i", $data_type_id);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $plans[] = $row;
}

// Return plans as JSON
echo json_encode([
    'success' => true,
    'plans' => $plans
]);
?>