<?php
$pageTitle = 'Dashboard';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get services count
$stmt = $conn->prepare("SELECT COUNT(*) as count FROM networks WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$networksCount = $result->fetch_assoc()['count'];

$stmt = $conn->prepare("SELECT COUNT(*) as count FROM data_plans WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$dataPlansCount = $result->fetch_assoc()['count'];

$stmt = $conn->prepare("SELECT COUNT(*) as count FROM cable_providers WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$cableProvidersCount = $result->fetch_assoc()['count'];

$stmt = $conn->prepare("SELECT COUNT(*) as count FROM electricity_providers WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$electricityProvidersCount = $result->fetch_assoc()['count'];

// Get recent transactions
$stmt = $conn->prepare("
    SELECT * FROM transactions 
    WHERE user_id = ? 
    ORDER BY created_at DESC 
    LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$recentTransactions = [];

while ($row = $result->fetch_assoc()) {
    $recentTransactions[] = $row;
}

// Get unread notifications
$stmt = $conn->prepare("
    SELECT * FROM notifications 
    WHERE user_id = ? AND is_read = 0
    ORDER BY created_at DESC 
    LIMIT 3
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$notifications = [];

while ($row = $result->fetch_assoc()) {
    $notifications[] = $row;
}

// Load analytics widget
include_once './widgets/analytics.php';
?>

<!-- Quick Actions -->
<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h2 class="text-xl font-bold text-white mb-4">Quick Actions</h2>
    
    <div class="grid grid-cols-2 md:grid-cols-4 gap-4">
        <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 text-center transition-colors">
            <div class="h-12 w-12 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                <i class="fas fa-wifi text-2xl text-indigo-400"></i>
            </div>
            <div class="font-medium text-white mb-1">Buy Data</div>
            <div class="text-xs text-gray-400"><?php echo $networksCount; ?> networks available</div>
        </a>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 text-center transition-colors">
            <div class="h-12 w-12 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                <i class="fas fa-phone text-2xl text-green-400"></i>
            </div>
            <div class="font-medium text-white mb-1">Buy Airtime</div>
            <div class="text-xs text-gray-400">Instant delivery</div>
        </a>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 text-center transition-colors">
            <div class="h-12 w-12 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                <i class="fas fa-tv text-2xl text-purple-400"></i>
            </div>
            <div class="font-medium text-white mb-1">Cable TV</div>
            <div class="text-xs text-gray-400"><?php echo $cableProvidersCount; ?> providers available</div>
        </a>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-4 text-center transition-colors">
            <div class="h-12 w-12 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                <i class="fas fa-bolt text-2xl text-yellow-400"></i>
            </div>
            <div class="font-medium text-white mb-1">Electricity</div>
            <div class="text-xs text-gray-400"><?php echo $electricityProvidersCount; ?> providers available</div>
        </a>
    </div>
</div>

<div class="grid grid-cols-1 lg:grid-cols-3 gap-6 mb-6">
    <!-- Fund Wallet Card -->
    <div class="dashboard-card shadow rounded-lg p-6">
        <h2 class="text-xl font-bold text-white mb-4">Fund Your Wallet</h2>
        
        <div class="bg-gray-800 rounded-lg p-4 mb-4">
            <div class="flex justify-between items-center">
                <div>
                    <div class="text-sm text-gray-400 mb-1">Current Balance</div>
                    <div class="text-2xl font-bold text-white"><?php echo $currency . number_format($user['balance'], 2); ?></div>
                </div>
                <div class="h-12 w-12 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center">
                    <i class="fas fa-wallet text-xl text-green-400"></i>
                </div>
            </div>
        </div>
        
        <div class="space-y-3">
            <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php?method=card" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-3 flex items-center transition-colors">
                <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                    <i class="fas fa-credit-card text-indigo-400"></i>
                </div>
                <div>
                    <div class="font-medium text-white">Credit/Debit Card</div>
                    <div class="text-xs text-gray-400">Fund instantly with your card</div>
                </div>
                <i class="fas fa-chevron-right ml-auto text-gray-500"></i>
            </a>
            
            <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php?method=bank" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-3 flex items-center transition-colors">
                <div class="h-10 w-10 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mr-3">
                    <i class="fas fa-university text-blue-400"></i>
                </div>
                <div>
                    <div class="font-medium text-white">Bank Transfer</div>
                    <div class="text-xs text-gray-400">Transfer from your bank account</div>
                </div>
                <i class="fas fa-chevron-right ml-auto text-gray-500"></i>
            </a>
            
            <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php?method=ussd" class="bg-gray-800 hover:bg-gray-700 rounded-lg p-3 flex items-center transition-colors">
                <div class="h-10 w-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                    <i class="fas fa-mobile-alt text-yellow-400"></i>
                </div>
                <div>
                    <div class="font-medium text-white">USSD</div>
                    <div class="text-xs text-gray-400">Use your bank's USSD code</div>
                </div>
                <i class="fas fa-chevron-right ml-auto text-gray-500"></i>
            </a>
        </div>
    </div>
    
    <!-- Recent Transactions -->
    <div class="dashboard-card shadow rounded-lg p-6">
        <div class="flex justify-between items-center mb-4">
            <h2 class="text-xl font-bold text-white">Recent Transactions</h2>
            <a href="<?php echo SITE_URL; ?>/dashboard/transactions.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                View All
            </a>
        </div>
        
        <?php if (empty($recentTransactions)): ?>
            <div class="text-center py-10">
                <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                    <i class="fas fa-receipt text-2xl text-gray-500"></i>
                </div>
                <h3 class="text-gray-400 mb-1">No Transactions Yet</h3>
                <p class="text-gray-500 text-sm mb-3">Your recent transactions will appear here</p>
                <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                    Make Your First Purchase
                </a>
            </div>
        <?php else: ?>
            <div class="space-y-3">
                <?php foreach ($recentTransactions as $transaction): ?>
                    <div class="bg-gray-800 rounded-lg p-3">
                        <div class="flex justify-between items-center mb-2">
                            <div class="flex items-center">
                                <?php
                                $icon = 'exchange-alt';
                                $bgColor = 'bg-gray-600';
                                $textColor = 'text-gray-400';
                                
                                if ($transaction['type'] === 'data') {
                                    $icon = 'wifi';
                                    $bgColor = 'bg-indigo-500';
                                    $textColor = 'text-indigo-400';
                                } elseif ($transaction['type'] === 'airtime') {
                                    $icon = 'phone';
                                    $bgColor = 'bg-green-500';
                                    $textColor = 'text-green-400';
                                } elseif ($transaction['type'] === 'cable') {
                                    $icon = 'tv';
                                    $bgColor = 'bg-purple-500';
                                    $textColor = 'text-purple-400';
                                } elseif ($transaction['type'] === 'electricity') {
                                    $icon = 'bolt';
                                    $bgColor = 'bg-yellow-500';
                                    $textColor = 'text-yellow-400';
                                } elseif ($transaction['type'] === 'fund') {
                                    $icon = 'wallet';
                                    $bgColor = 'bg-blue-500';
                                    $textColor = 'text-blue-400';
                                }
                                ?>
                                <div class="h-8 w-8 rounded-full <?php echo $bgColor; ?> bg-opacity-20 flex items-center justify-center mr-3">
                                    <i class="fas fa-<?php echo $icon; ?> <?php echo $textColor; ?>"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white"><?php echo ucfirst($transaction['type']); ?></div>
                                    <div class="text-xs text-gray-400"><?php echo date('M d, g:i A', strtotime($transaction['created_at'])); ?></div>
                                </div>
                            </div>
                            <div class="text-right">
                                <div class="font-medium <?php echo $transaction['type'] === 'fund' ? 'text-green-400' : 'text-white'; ?>">
                                    <?php echo $transaction['type'] === 'fund' ? '+' : '-'; ?><?php echo $currency . number_format($transaction['amount'], 2); ?>
                                </div>
                                <div class="status-badge status-<?php echo $transaction['status']; ?> mt-1">
                                    <?php echo ucfirst($transaction['status']); ?>
                                </div>
                            </div>
                        </div>
                        <div class="text-xs text-gray-500 truncate">
                            <?php echo htmlspecialchars($transaction['description']); ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>
    
    <!-- Notifications -->
    <div class="dashboard-card shadow rounded-lg p-6">
        <div class="flex justify-between items-center mb-4">
            <h2 class="text-xl font-bold text-white">Notifications</h2>
            <a href="<?php echo SITE_URL; ?>/dashboard/notifications.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                View All
            </a>
        </div>
        
        <?php if (empty($notifications)): ?>
            <div class="text-center py-10">
                <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                    <i class="fas fa-bell text-2xl text-gray-500"></i>
                </div>
                <h3 class="text-gray-400 mb-1">All Caught Up!</h3>
                <p class="text-gray-500 text-sm">You have no unread notifications</p>
            </div>
        <?php else: ?>
            <div class="space-y-3">
                <?php foreach ($notifications as $notification): ?>
                    <a href="<?php echo SITE_URL; ?>/dashboard/notifications.php?id=<?php echo $notification['id']; ?>" class="block bg-gray-800 hover:bg-gray-700 rounded-lg p-3 transition-colors">
                        <div class="flex items-start mb-2">
                            <?php
                            $icon = 'info-circle';
                            $bgColor = 'bg-blue-500';
                            $textColor = 'text-blue-400';
                            
                            if ($notification['type'] === 'success') {
                                $icon = 'check-circle';
                                $bgColor = 'bg-green-500';
                                $textColor = 'text-green-400';
                            } elseif ($notification['type'] === 'warning') {
                                $icon = 'exclamation-triangle';
                                $bgColor = 'bg-yellow-500';
                                $textColor = 'text-yellow-400';
                            } elseif ($notification['type'] === 'error') {
                                $icon = 'times-circle';
                                $bgColor = 'bg-red-500';
                                $textColor = 'text-red-400';
                            }
                            ?>
                            <div class="h-8 w-8 rounded-full <?php echo $bgColor; ?> bg-opacity-20 flex-shrink-0 flex items-center justify-center mr-3">
                                <i class="fas fa-<?php echo $icon; ?> <?php echo $textColor; ?>"></i>
                            </div>
                            <div>
                                <div class="font-medium text-white"><?php echo htmlspecialchars($notification['title']); ?></div>
                                <div class="text-xs text-gray-400"><?php echo date('M d, g:i A', strtotime($notification['created_at'])); ?></div>
                            </div>
                        </div>
                        <div class="text-sm text-gray-400 line-clamp-2">
                            <?php echo htmlspecialchars($notification['message']); ?>
                        </div>
                    </a>
                <?php endforeach; ?>
            </div>
            
            <?php if (count($notifications) == 3 && $notificationsCount > 3): ?>
                <div class="text-center mt-3">
                    <a href="<?php echo SITE_URL; ?>/dashboard/notifications.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                        <?php echo $notificationsCount - 3; ?> more unread notification<?php echo $notificationsCount - 3 != 1 ? 's' : ''; ?>
                    </a>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    </div>
</div>

<?php require_once './includes/footer.php'; ?>