<?php
require_once '../includes/config.php';
require_once '../includes/functions.php'; 
require_once './includes/header.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get user's unread notifications
$db = getDB();
$conn = $db->getConnection();
$stmt = $conn->prepare("SELECT * FROM notifications WHERE user_id = ? AND is_read = 0 ORDER BY created_at DESC LIMIT 1");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$notification = $result->fetch_assoc();

// Check for low balance warning (for Vendor and API users)
$lowBalanceWarning = false;
$minBalance = 0;

if ($user['user_type'] === 'api' && $user['balance'] < 5000) {
    $lowBalanceWarning = true;
    $minBalance = 5000;
} elseif ($user['user_type'] === 'vendor' && $user['balance'] < 2000) {
    $lowBalanceWarning = true;
    $minBalance = 2000;
}

// Check if user has dismissed low balance warning
$hideWarning = false;
if (isset($_COOKIE['hide_low_balance_warning'])) {
    $hideWarning = true;
}

// Handle dismiss warning
if (isset($_POST['dismiss_warning']) && isset($_POST['dont_show_again'])) {
    setcookie('hide_low_balance_warning', '1', time() + (86400 * 30), "/"); // 30 days
    $hideWarning = true;
}

// Mark notification as read
if (isset($_POST['mark_notification_read']) && isset($_POST['notification_id'])) {
    $notificationId = (int)$_POST['notification_id'];
    $stmt = $conn->prepare("UPDATE notifications SET is_read = 1 WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $notificationId, $userId);
    $stmt->execute();
    
    // Refresh page to remove the notification
    redirect(SITE_URL . '/dashboard/index.php');
}

// Get flash message
$flashMessage = getFlashMessage();
?>

        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <?php if ($flashMessage): ?>
                <div class="mb-4 p-4 rounded-md <?php echo $flashMessage['type'] === 'success' ? 'bg-green-500 text-white' : 'bg-red-500 text-white'; ?>">
                    <?php echo $flashMessage['message']; ?>
                </div>
            <?php endif; ?>
            
            <!-- Balance Card -->
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 text-center">
                <h2 class="text-xl font-semibold text-gray-300 mb-2">Wallet Balance</h2>
                <p class="text-3xl font-bold text-white <?php echo $lowBalanceWarning && !$hideWarning ? 'balance-low-warning' : ''; ?>"><?php echo formatAmount($user['balance']); ?></p>
                <a href="fund_wallet.php" class="accent-button mt-4 inline-block px-6 py-2 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">Fund Wallet</a>
            </div>
            
            <!-- Services Grid -->
            <h2 class="text-xl font-semibold text-gray-300 mb-4">Our Services</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                <a href="buy_data.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-wifi text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Buy Data</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Purchase data bundles at affordable rates</p>
                </a>
                
                <a href="buy_airtime.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-phone text-green-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Buy Airtime</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Recharge any network at discounted rates</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-bolt text-yellow-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Electricity</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Pay electricity bills instantly</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-red-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-tv text-red-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Cable TV</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Subscribe to DSTV, GOTV & Startimes</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-exchange-alt text-blue-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Airtime to Cash</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Convert airtime to cash instantly</p>
                </a>
                
                <a href="transactions.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-history text-purple-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Transactions</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">View your transaction history</p>
                </a>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Low Balance Warning Modal -->
    <?php if ($lowBalanceWarning && !$hideWarning): ?>
    <div id="lowBalanceModal" class="fixed inset-0 z-50 flex items-center justify-center">
        <div class="modal-backdrop fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6 relative z-10">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white flex items-center">
                    <i class="fas fa-exclamation-triangle text-red-500 mr-2"></i>
                    Low Balance Warning
                </h3>
            </div>
            
            <div class="p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md mb-4">
                <p class="text-white mb-2">Your current balance is <span class="font-bold"><?php echo formatAmount($user['balance']); ?></span></p>
                <p class="text-white">
                    As a <span class="font-bold"><?php echo ucfirst($user['user_type']); ?> user</span>, your account balance is below the recommended minimum of <span class="font-bold"><?php echo formatAmount($minBalance); ?></span>.
                </p>
            </div>
            
            <p class="text-gray-300 mb-6">
                Please fund your wallet to ensure uninterrupted service. Low balance may affect your ability to perform transactions.
            </p>
            
            <form method="POST" action="">
                <div class="flex items-center mb-4">
                    <input type="checkbox" id="dont_show_again" name="dont_show_again" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800">
                    <label for="dont_show_again" class="ml-2 text-gray-300">Don't show this warning again</label>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <a href="fund_wallet.php" class="accent-button py-2 px-4 rounded-md text-white">
                        Fund Wallet
                    </a>
                    <button type="submit" name="dismiss_warning" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600">
                        Dismiss
                    </button>
                </div>
            </form>
        </div>
    </div>
    <?php endif; ?>
    
    <!-- Admin Notification Modal -->
    <?php if ($notification): ?>
    <div id="notificationModal" class="fixed inset-0 z-50 flex items-center justify-center">
        <div class="modal-backdrop fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6 relative z-10">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white flex items-center">
                    <?php 
                    $iconClass = 'info';
                    switch($notification['type']) {
                        case 'success':
                            $iconClass = 'check-circle text-green-500';
                            break;
                        case 'warning':
                            $iconClass = 'exclamation-circle text-yellow-500';
                            break;
                        case 'error':
                            $iconClass = 'times-circle text-red-500';
                            break;
                        default:
                            $iconClass = 'info-circle text-blue-500';
                    }
                    ?>
                    <i class="fas fa-<?php echo $iconClass; ?> mr-2"></i>
                    <?php echo htmlspecialchars($notification['title']); ?>
                </h3>
            </div>
            
            <div class="mb-6">
                <p class="text-gray-300"><?php echo nl2br(htmlspecialchars($notification['message'])); ?></p>
                <p class="text-gray-400 text-sm mt-4">
                    <i class="fas fa-clock mr-1"></i>
                    <?php echo date('M d, Y h:i A', strtotime($notification['created_at'])); ?>
                </p>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="notification_id" value="<?php echo $notification['id']; ?>">
                <div class="flex justify-end">
                    <button type="submit" name="mark_notification_read" class="accent-button py-2 px-4 rounded-md text-white">
                        Close
                    </button>
                </div>
            </form>
        </div>
    </div>
    <?php endif; ?>
    
    <!-- JavaScript -->
    <style>
        /* Low balance warning animation */
        @keyframes balanceWarning {
            0% { color: white; }
            50% { color: #EF4444; }
            100% { color: white; }
        }
        
        .balance-low-warning {
            animation: balanceWarning 1s infinite;
            font-weight: bold;
        }
        
        /* Modal styles */
        .modal-backdrop {
            backdrop-filter: blur(3px);
        }
    </style>
    <?php require_once './includes/footer.php'; ?>
</body>
</html>