<?php
require_once '../includes/config.php';
require_once '../includes/functions.php'; 
require_once './includes/header.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get flash message
$flashMessage = getFlashMessage();
?>


        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <?php if ($flashMessage): ?>
                <div class="mb-4 p-4 rounded-md <?php echo $flashMessage['type'] === 'success' ? 'bg-green-500 text-white' : 'bg-red-500 text-white'; ?>">
                    <?php echo $flashMessage['message']; ?>
                </div>
            <?php endif; ?>
            
            <!-- Balance Card -->
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 text-center">
                <h2 class="text-xl font-semibold text-gray-300 mb-2">Wallet Balance</h2>
                <p class="text-3xl font-bold text-white"><?php echo formatAmount($user['balance']); ?></p>
                <a href="fund_wallet.php" class="accent-button mt-4 inline-block px-6 py-2 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">Fund Wallet</a>
            </div>
            
            <!-- Services Grid -->
            <h2 class="text-xl font-semibold text-gray-300 mb-4">Our Services</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                <a href="buy_data.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-wifi text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Buy Data</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Purchase data bundles at affordable rates</p>
                </a>
                
                <a href="buy_airtime.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-phone text-green-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Buy Airtime</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Recharge any network at discounted rates</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-bolt text-yellow-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Electricity</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Pay electricity bills instantly</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-red-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-tv text-red-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Cable TV</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Subscribe to DSTV, GOTV & Startimes</p>
                </a>
                
                <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-exchange-alt text-blue-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Airtime to Cash</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">Convert airtime to cash instantly</p>
                </a>
                
                <a href="transactions.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                    <div class="h-16 w-16 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mb-4">
                        <i class="fas fa-history text-purple-400 text-2xl"></i>
                    </div>
                    <h3 class="text-lg font-medium text-white">Transactions</h3>
                    <p class="mt-2 text-gray-400 text-sm text-center">View your transaction history</p>
                </a>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <?php require_once './includes/footer.php'; ?>
</body>
</html>