<?php
$pageTitle = 'Price List';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get networks
$stmt = $conn->prepare("SELECT * FROM networks WHERE status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();
$networks = [];

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Get cable providers
$stmt = $conn->prepare("SELECT * FROM cable_providers WHERE status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();
$cableProviders = [];

while ($row = $result->fetch_assoc()) {
    $cableProviders[] = $row;
}

// Get electricity providers
$stmt = $conn->prepare("SELECT * FROM electricity_providers WHERE status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();
$electricityProviders = [];

while ($row = $result->fetch_assoc()) {
    $electricityProviders[] = $row;
}

// Get user's price type based on user_type
$priceType = 'price_smart'; // Default to regular user price
if ($user['user_type'] === 'vendor') {
    $priceType = 'price_vendor';
} elseif ($user['user_type'] === 'api') {
    $priceType = 'price_api';
}

// Get the network ID from URL for data plans tab
$selectedNetworkId = isset($_GET['network']) ? (int)$_GET['network'] : (isset($networks[0]) ? $networks[0]['id'] : 0);

// Get data plans for selected network
$dataPlans = [];
if ($selectedNetworkId > 0) {
    $stmt = $conn->prepare("
        SELECT dp.id, dp.name, dp.description, dp.{$priceType} as price, dp.validity
        FROM data_plans dp
        WHERE dp.network_id = ? AND dp.status = 'active' 
        ORDER BY dp.{$priceType} ASC
    ");
    $stmt->bind_param("i", $selectedNetworkId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $dataPlans[] = $row;
    }
}

// Get cable provider ID from URL for cable plans tab
$selectedCableProviderId = isset($_GET['cable']) ? (int)$_GET['cable'] : (isset($cableProviders[0]) ? $cableProviders[0]['id'] : 0);

// Get cable plans for selected provider
$cablePlans = [];
if ($selectedCableProviderId > 0) {
    $stmt = $conn->prepare("
        SELECT cp.id, cp.name, cp.description, cp.{$priceType} as price, cp.duration
        FROM cable_plans cp
        WHERE cp.provider_id = ? AND cp.status = 'active' 
        ORDER BY cp.{$priceType} ASC
    ");
    $stmt->bind_param("i", $selectedCableProviderId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $cablePlans[] = $row;
    }
}

// Get electricity token purchase fees
$electricityFees = [];
foreach ($electricityProviders as $provider) {
    // Assuming a fees table or specific fields in the electricity_providers table
    // This is a placeholder - adjust based on your actual database structure
    $electricityFees[$provider['id']] = [
        'provider_name' => $provider['name'],
        'fee' => 100,  // Default fee
        'min_amount' => 1000,
        'max_amount' => 50000
    ];
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-6">Price List</h1>
    
    <div class="bg-gray-800 rounded-lg overflow-hidden">
        <div class="border-b border-gray-700">
            <nav class="-mb-px flex overflow-x-auto" aria-label="Tabs">
                <button class="price-tab-button whitespace-nowrap text-white px-4 py-3 font-medium border-b-2 border-indigo-500" data-tab="data">
                    <i class="fas fa-wifi mr-2"></i> Data Plans
                </button>
                <button class="price-tab-button whitespace-nowrap text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="airtime">
                    <i class="fas fa-phone mr-2"></i> Airtime
                </button>
                <button class="price-tab-button whitespace-nowrap text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="cable">
                    <i class="fas fa-tv mr-2"></i> Cable TV
                </button>
                <button class="price-tab-button whitespace-nowrap text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="electricity">
                    <i class="fas fa-bolt mr-2"></i> Electricity
                </button>
            </nav>
        </div>
        
        <!-- Data Plans Tab -->
        <div id="data-tab" class="price-tab-content p-4">
            <div class="flex flex-col md:flex-row justify-between mb-4">
                <div class="mb-4 md:mb-0">
                    <label for="network-select" class="block text-sm font-medium text-gray-400 mb-1">Select Network</label>
                    <select id="network-select" class="bg-gray-700 border border-gray-600 text-white rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        <?php foreach ($networks as $network): ?>
                            <option value="<?php echo $network['id']; ?>" data-url="?network=<?php echo $network['id']; ?>" <?php echo $selectedNetworkId == $network['id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($network['name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="flex items-center">
                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm flex items-center">
                        <i class="fas fa-shopping-cart mr-2"></i> Buy Data
                    </a>
                </div>
            </div>
            
            <?php if (empty($dataPlans)): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-wifi text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Data Plans Available</h3>
                    <p class="text-gray-500 text-sm">There are no data plans available for this network</p>
                </div>
            <?php else: ?>
                <div class="overflow-x-auto">
                    <table class="min-w-full">
                        <thead class="bg-gray-700">
                            <tr>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Plan</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Description</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Validity</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Price</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                            </tr>
                        </thead>
                        <tbody class="divide-y divide-gray-800">
                            <?php foreach ($dataPlans as $plan): ?>
                                <tr class="hover:bg-gray-700">
                                    <td class="py-3 px-4 text-sm font-medium text-white">
                                        <?php echo htmlspecialchars($plan['name']); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo htmlspecialchars($plan['description'] ?: 'N/A'); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo htmlspecialchars($plan['validity'] ?: 'N/A'); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-white">
                                        <?php echo $currency . number_format($plan['price'], 2); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm">
                                        <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php?plan=<?php echo $plan['id']; ?>&network=<?php echo $selectedNetworkId; ?>" class="py-1 px-3 bg-indigo-600 hover:bg-indigo-700 text-white rounded text-xs">
                                            Buy
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Airtime Tab -->
        <div id="airtime-tab" class="price-tab-content p-4 hidden">
            <div class="flex justify-end mb-4">
                <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php" class="py-2 px-4 bg-green-600 hover:bg-green-700 text-white rounded-md text-sm flex items-center">
                    <i class="fas fa-shopping-cart mr-2"></i> Buy Airtime
                </a>
            </div>
            
            <div class="overflow-x-auto">
                <table class="min-w-full">
                    <thead class="bg-gray-700">
                        <tr>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Network</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Discount</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Minimum Amount</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Maximum Amount</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                        </tr>
                    </thead>
                    <tbody class="divide-y divide-gray-800">
                        <?php foreach ($networks as $network): ?>
                            <tr class="hover:bg-gray-700">
                                <td class="py-3 px-4 text-sm font-medium text-white">
                                    <?php echo htmlspecialchars($network['name']); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php 
                                    // This is a placeholder - adjust based on your actual discount structure
                                    $discount = $user['user_type'] === 'vendor' ? '2%' : ($user['user_type'] === 'api' ? '3%' : '0%');
                                    echo $discount; 
                                    ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php echo $currency . number_format(50, 2); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php echo $currency . number_format(50000, 2); ?>
                                </td>
                                <td class="py-3 px-4 text-sm">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php?network=<?php echo $network['id']; ?>" class="py-1 px-3 bg-green-600 hover:bg-green-700 text-white rounded text-xs">
                                        Buy
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        
        <!-- Cable TV Tab -->
        <div id="cable-tab" class="price-tab-content p-4 hidden">
            <div class="flex flex-col md:flex-row justify-between mb-4">
                <div class="mb-4 md:mb-0">
                    <label for="cable-provider-select" class="block text-sm font-medium text-gray-400 mb-1">Select Provider</label>
                    <select id="cable-provider-select" class="bg-gray-700 border border-gray-600 text-white rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        <?php foreach ($cableProviders as $provider): ?>
                            <option value="<?php echo $provider['id']; ?>" data-url="?cable=<?php echo $provider['id']; ?>" <?php echo $selectedCableProviderId == $provider['id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($provider['name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="flex items-center">
                    <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php" class="py-2 px-4 bg-purple-600 hover:bg-purple-700 text-white rounded-md text-sm flex items-center">
                        <i class="fas fa-shopping-cart mr-2"></i> Pay Cable TV
                    </a>
                </div>
            </div>
            
            <?php if (empty($cablePlans)): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-tv text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Cable TV Plans Available</h3>
                    <p class="text-gray-500 text-sm">There are no cable TV plans available for this provider</p>
                </div>
            <?php else: ?>
                <div class="overflow-x-auto">
                    <table class="min-w-full">
                        <thead class="bg-gray-700">
                            <tr>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Package</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Description</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Duration</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Price</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                            </tr>
                        </thead>
                        <tbody class="divide-y divide-gray-800">
                            <?php foreach ($cablePlans as $plan): ?>
                                <tr class="hover:bg-gray-700">
                                    <td class="py-3 px-4 text-sm font-medium text-white">
                                        <?php echo htmlspecialchars($plan['name']); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo htmlspecialchars($plan['description'] ?: 'N/A'); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo htmlspecialchars($plan['duration'] ?: 'N/A'); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-white">
                                        <?php echo $currency . number_format($plan['price'], 2); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm">
                                        <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php?provider=<?php echo $selectedCableProviderId; ?>" class="py-1 px-3 bg-purple-600 hover:bg-purple-700 text-white rounded text-xs">
                                            Subscribe
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Electricity Tab -->
        <div id="electricity-tab" class="price-tab-content p-4 hidden">
            <div class="flex justify-end mb-4">
                <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php" class="py-2 px-4 bg-yellow-600 hover:bg-yellow-700 text-white rounded-md text-sm flex items-center">
                    <i class="fas fa-shopping-cart mr-2"></i> Pay Electricity
                </a>
            </div>
            
            <div class="overflow-x-auto">
                <table class="min-w-full">
                    <thead class="bg-gray-700">
                        <tr>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Provider</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Service Fee</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Minimum Amount</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Maximum Amount</th>
                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                        </tr>
                    </thead>
                    <tbody class="divide-y divide-gray-800">
                        <?php foreach ($electricityProviders as $provider): ?>
                            <tr class="hover:bg-gray-700">
                                <td class="py-3 px-4 text-sm font-medium text-white">
                                    <?php echo htmlspecialchars($provider['name']); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php 
                                    // Placeholder - adjust based on your actual fee structure
                                    echo $currency . number_format($electricityFees[$provider['id']]['fee'] ?? 100, 2); 
                                    ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php echo $currency . number_format($electricityFees[$provider['id']]['min_amount'] ?? 1000, 2); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php echo $currency . number_format($electricityFees[$provider['id']]['max_amount'] ?? 50000, 2); ?>
                                </td>
                                <td class="py-3 px-4 text-sm">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php?provider=<?php echo $provider['id']; ?>" class="py-1 px-3 bg-yellow-600 hover:bg-yellow-700 text-white rounded text-xs">
                                        Buy
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<!-- Pricing Information Card -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">
        <i class="fas fa-info-circle mr-2 text-indigo-400"></i> Pricing Information
    </h2>
    <div class="bg-gray-800 rounded-lg p-6">
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">Your Pricing Tier</h3>
            <p class="text-gray-400">
                You are currently on the <span class="text-indigo-400 font-medium"><?php echo ucfirst($user['user_type']); ?></span> pricing tier. 
                <?php if ($user['user_type'] === 'smart'): ?>
                    Upgrade to Vendor or API account for better rates.
                <?php elseif ($user['user_type'] === 'vendor'): ?>
                    You're enjoying vendor discount rates.
                <?php elseif ($user['user_type'] === 'api'): ?>
                    You're enjoying our best API pricing.
                <?php endif; ?>
            </p>
        </div>
        
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">Price Updates</h3>
            <p class="text-gray-400">
                Prices are subject to change based on network providers' rates. We always ensure to offer competitive prices.
            </p>
        </div>
        
        <div>
            <h3 class="text-white font-semibold mb-2">Bulk Purchase</h3>
            <p class="text-gray-400">
                For bulk purchases or special pricing, please contact our support team.
            </p>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Tab switching functionality
        const tabButtons = document.querySelectorAll('.price-tab-button');
        const tabContents = document.querySelectorAll('.price-tab-content');
        
        tabButtons.forEach(button => {
            button.addEventListener('click', function() {
                const targetTab = this.getAttribute('data-tab');
                
                // Hide all tab contents
                tabContents.forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all tab buttons
                tabButtons.forEach(btn => {
                    btn.classList.remove('text-white', 'border-indigo-500');
                    btn.classList.add('text-gray-400', 'border-transparent');
                });
                
                // Show selected tab content
                document.getElementById(targetTab + '-tab').classList.remove('hidden');
                
                // Highlight selected tab button
                this.classList.remove('text-gray-400', 'border-transparent');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
        
        // Network select change handler
        const networkSelect = document.getElementById('network-select');
        if (networkSelect) {
            networkSelect.addEventListener('change', function() {
                const selectedOption = this.options[this.selectedIndex];
                const url = selectedOption.getAttribute('data-url');
                window.location.href = url;
            });
        }
        
        // Cable provider select change handler
        const cableProviderSelect = document.getElementById('cable-provider-select');
        if (cableProviderSelect) {
            cableProviderSelect.addEventListener('change', function() {
                const selectedOption = this.options[this.selectedIndex];
                const url = selectedOption.getAttribute('data-url');
                window.location.href = url;
            });
        }
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>