<?php
// This file should be placed at /dashboard/process/get_order_details.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

header('Content-Type: application/json');

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode([
        'success' => false,
        'message' => 'You must be logged in to view order details'
    ]);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];

// Check for order ID
if (!isset($_GET['id']) || empty($_GET['id'])) {
    echo json_encode([
        'success' => false,
        'message' => 'Order ID is required'
    ]);
    exit;
}

$orderId = (int)$_GET['id'];

$db = getDB();
$conn = $db->getConnection();

// Get order details with panel name
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro 
    JOIN reseller_panels rp ON ro.panel_id = rp.id 
    WHERE ro.id = ? AND ro.user_id = ?
");
$stmt->bind_param("ii", $orderId, $userId);
$stmt->execute();
$result = $stmt->get_result();
$order = $result->fetch_assoc();

if (!$order) {
    echo json_encode([
        'success' => false,
        'message' => 'Order not found or you do not have permission to view it'
    ]);
    exit;
}

// Get currency from settings
$currency = getSetting('currency', '₦');

// Return order details
echo json_encode([
    'success' => true,
    'order' => $order,
    'currency' => $currency
]);
?>