<?php
// This file should be placed at /dashboard/process/order_reseller.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Only set Content-Type to JSON if it's an AJAX request
$isAjax = !empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest';
if ($isAjax) {
    header('Content-Type: application/json');
}

// Function to display HTML response
function displayResponse($success, $message, $data = null, $error = null) {
    global $isAjax;
    
    // If AJAX request, return JSON
    if ($isAjax) {
        echo json_encode([
            'success' => $success,
            'message' => $message,
            'data' => $data,
            'error' => $error
        ]);
        exit;
    }
    
    // For normal requests, display HTML
    $siteName = getSetting('site_name', 'Reseller System');
    $siteUrl = getSetting('site_url', '../dashboard/');
    $currency = getSetting('currency', '₦');
    
    // Build HTML response
    ?>
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title><?php echo $success ? 'Order Successful' : 'Order Failed'; ?> | <?php echo $siteName; ?></title>
        <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
        <style>
            :root {
                --primary-color: #5D5CDE;
                --primary-hover: #4a49c0;
                --bg-light: #f8f9fa;
                --bg-dark: #1a1a2e;
                --card-light: #ffffff;
                --card-dark: #16213e;
                --text-light: #f1f1f1;
                --text-dark: #333333;
            }
            
            .dark-mode {
                background-color: var(--bg-dark);
                color: var(--text-light);
            }
            
            .light-mode {
                background-color: var(--bg-light);
                color: var(--text-dark);
            }
            
            .card-dark {
                background-color: var(--card-dark);
                box-shadow: 0 4px 20px rgba(0, 0, 0, 0.25);
            }
            
            .card-light {
                background-color: var(--card-light);
                box-shadow: 0 4px 15px rgba(0, 0, 0, 0.1);
            }
            
            .btn-primary {
                background-color: var(--primary-color);
                color: white;
                transition: all 0.3s ease;
            }
            
            .btn-primary:hover {
                background-color: var(--primary-hover);
                transform: translateY(-2px);
            }
            
            @keyframes fadeInUp {
                from {
                    opacity: 0;
                    transform: translateY(20px);
                }
                to {
                    opacity: 1;
                    transform: translateY(0);
                }
            }
            
            @keyframes pulse {
                0% {
                    box-shadow: 0 0 0 0 rgba(93, 92, 222, 0.4);
                }
                70% {
                    box-shadow: 0 0 0 15px rgba(93, 92, 222, 0);
                }
                100% {
                    box-shadow: 0 0 0 0 rgba(93, 92, 222, 0);
                }
            }
            
            .response-container {
                animation: fadeInUp 0.6s ease-out forwards;
            }
            
            .success-icon {
                animation: pulse 2s infinite;
            }
            
            .border-success {
                border-color: #10B981;
            }
            
            .border-error {
                border-color: #EF4444;
            }
            
            .checkmark-circle {
                width: 100px;
                height: 100px;
                position: relative;
                display: inline-block;
                vertical-align: top;
                margin-left: auto;
                margin-right: auto;
            }
            
            .checkmark-circle .background {
                width: 100px;
                height: 100px;
                border-radius: 50%;
                background: #10B981;
                position: absolute;
            }
            
            .checkmark-circle .checkmark {
                border-radius: 5px;
            }
            
            .checkmark-circle .checkmark.draw:after {
                animation-delay: 300ms;
                animation-duration: 1s;
                animation-timing-function: ease;
                animation-name: checkmark;
                transform: scaleX(-1) rotate(135deg);
                animation-fill-mode: forwards;
            }
            
            .checkmark-circle .checkmark:after {
                opacity: 0;
                height: 50px;
                width: 25px;
                transform-origin: left top;
                border-right: 8px solid white;
                border-top: 8px solid white;
                border-radius: 2px !important;
                content: '';
                left: 30px;
                top: 50px;
                position: absolute;
            }
            
            @keyframes checkmark {
                0% {
                    height: 0;
                    width: 0;
                    opacity: 1;
                }
                20% {
                    height: 0;
                    width: 25px;
                    opacity: 1;
                }
                40% {
                    height: 50px;
                    width: 25px;
                    opacity: 1;
                }
                100% {
                    height: 50px;
                    width: 25px;
                    opacity: 1;
                }
            }
            
            .error-circle {
                width: 100px;
                height: 100px;
                border-radius: 50%;
                background: #EF4444;
                position: relative;
                display: inline-block;
                vertical-align: top;
                margin-left: auto;
                margin-right: auto;
            }
            
            .error-circle .error-icon {
                position: absolute;
                color: white;
                font-size: 60px;
                top: 50%;
                left: 50%;
                transform: translate(-50%, -50%);
            }
            
            .shimmer {
                background-image: linear-gradient(
                    -45deg,
                    rgba(255, 255, 255, 0.1) 25%,
                    transparent 25%,
                    transparent 50%,
                    rgba(255, 255, 255, 0.1) 50%,
                    rgba(255, 255, 255, 0.1) 75%,
                    transparent 75%,
                    transparent
                );
                background-size: 200% 200%;
                animation: shimmer 2s linear infinite;
            }
            
            @keyframes shimmer {
                0% {
                    background-position: 200% 0;
                }
                100% {
                    background-position: -200% 0;
                }
            }
        </style>
    </head>
    <body class="min-h-screen flex items-center justify-center p-4">
        <script>
            // Dark mode detection
            function setColorMode() {
                if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
                    document.body.classList.add('dark-mode');
                    document.body.classList.remove('light-mode');
                } else {
                    document.body.classList.add('light-mode');
                    document.body.classList.remove('dark-mode');
                }
            }
            
            setColorMode();
            
            // Listen for changes
            window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', setColorMode);
        </script>
        
        <div class="response-container w-full max-w-md mx-auto">
            <?php if ($success): ?>
                <!-- Success Response -->
                <div class="card-dark dark:card-dark light:card-light rounded-xl overflow-hidden shadow-lg">
                    <div class="bg-gradient-to-r from-indigo-600 to-purple-600 px-6 py-8 text-center">
                        <div class="checkmark-circle">
                            <div class="background"></div>
                            <div class="checkmark draw"></div>
                        </div>
                        <h1 class="text-white text-3xl font-bold mt-4">Order Successful!</h1>
                        <p class="text-white text-opacity-90 mt-2">Your reseller panel order has been processed</p>
                    </div>
                    
                    <div class="p-6">
                        <div class="bg-black bg-opacity-5 dark:bg-white dark:bg-opacity-5 rounded-lg p-4 mb-6">
                            <div class="text-sm text-gray-500 dark:text-gray-400 mb-1">Order Reference</div>
                            <div class="font-mono text-lg font-semibold"><?php echo $data['reference']; ?></div>
                        </div>
                        
                        <div class="space-y-4 mb-6">
                            <div class="flex justify-between py-2 border-b border-gray-200 dark:border-gray-700">
                                <span class="text-gray-600 dark:text-gray-400">Panel</span>
                                <span class="font-medium"><?php echo $data['panel_name']; ?></span>
                            </div>
                            
                            <div class="flex justify-between py-2 border-b border-gray-200 dark:border-gray-700">
                                <span class="text-gray-600 dark:text-gray-400">Amount</span>
                                <span class="font-medium"><?php echo $currency . number_format($data['amount'], 2); ?></span>
                            </div>
                            
                            <div class="flex justify-between py-2">
                                <span class="text-gray-600 dark:text-gray-400">Status</span>
                                <span class="px-3 py-1 inline-flex text-xs leading-5 font-semibold rounded-full bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-200">Pending</span>
                            </div>
                        </div>
                        
                        <div class="p-4 bg-indigo-50 dark:bg-indigo-900 dark:bg-opacity-20 rounded-lg mb-6">
                            <div class="flex items-start">
                                <div class="flex-shrink-0">
                                    <i class="fas fa-info-circle text-indigo-500 dark:text-indigo-400"></i>
                                </div>
                                <div class="ml-3">
                                    <h3 class="text-sm font-medium text-indigo-800 dark:text-indigo-300">What happens next?</h3>
                                    <div class="mt-2 text-sm text-indigo-700 dark:text-indigo-200">
                                        <p>We will review your order and process it as soon as possible. You will receive a notification once your panel is ready.</p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <div class="flex flex-col sm:flex-row space-y-3 sm:space-y-0 sm:space-x-3">
                            <a href="<?php echo $siteUrl; ?>" class="btn-primary flex-1 py-3 rounded-lg font-medium text-center hover:shadow-lg">
                                <i class="fas fa-tachometer-alt mr-2"></i> Dashboard
                            </a>
                            <a href="<?php echo $siteUrl; ?>reseller.php" class="flex-1 py-3 rounded-lg font-medium text-center border border-gray-300 dark:border-gray-600 hover:bg-gray-100 dark:hover:bg-gray-800 transition duration-200">
                                <i class="fas fa-list-alt mr-2"></i> My Orders
                            </a>
                        </div>
                    </div>
                </div>
            <?php else: ?>
                <!-- Error Response -->
                <div class="card-dark dark:card-dark light:card-light rounded-xl overflow-hidden shadow-lg">
                    <div class="bg-gradient-to-r from-red-500 to-pink-600 px-6 py-8 text-center">
                        <div class="error-circle">
                            <i class="fas fa-exclamation-triangle error-icon"></i>
                        </div>
                        <h1 class="text-white text-3xl font-bold mt-4">Order Failed</h1>
                        <p class="text-white text-opacity-90 mt-2">We encountered an issue with your order</p>
                    </div>
                    
                    <div class="p-6">
                        <div class="p-4 mb-6 bg-red-50 dark:bg-red-900 dark:bg-opacity-20 rounded-lg">
                            <div class="flex">
                                <div class="flex-shrink-0">
                                    <i class="fas fa-exclamation-circle text-red-500 dark:text-red-400"></i>
                                </div>
                                <div class="ml-3">
                                    <h3 class="text-sm font-medium text-red-800 dark:text-red-300">Error Details</h3>
                                    <div class="mt-2 text-sm text-red-700 dark:text-red-200">
                                        <p><?php echo $message; ?></p>
                                        <?php if ($error): ?>
                                            <p class="mt-2 text-xs text-red-600 dark:text-red-300"><?php echo $error; ?></p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <div class="space-y-4 mb-6">
                            <div class="p-4 bg-gray-50 dark:bg-gray-800 rounded-lg">
                                <h4 class="font-medium mb-2">What can you do?</h4>
                                <ul class="list-disc list-inside text-sm text-gray-600 dark:text-gray-400 space-y-1">
                                    <li>Check if you have sufficient balance in your wallet</li>
                                    <li>Verify that all required information was provided</li>
                                    <li>Try again in a few minutes</li>
                                    <li>Contact support if the issue persists</li>
                                </ul>
                            </div>
                        </div>
                        
                        <div class="flex flex-col sm:flex-row space-y-3 sm:space-y-0 sm:space-x-3">
                            <a href="javascript:history.back()" class="btn-primary flex-1 py-3 rounded-lg font-medium text-center hover:shadow-lg">
                                <i class="fas fa-arrow-left mr-2"></i> Go Back
                            </a>
                            <a href="<?php echo $siteUrl; ?>support/ticket.php" class="flex-1 py-3 rounded-lg font-medium text-center border border-gray-300 dark:border-gray-600 hover:bg-gray-100 dark:hover:bg-gray-800 transition duration-200">
                                <i class="fas fa-headset mr-2"></i> Contact Support
                            </a>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            
            <div class="text-center mt-6">
                <p class="text-sm text-gray-500 dark:text-gray-400">&copy; <?php echo date('Y'); ?> <?php echo $siteName; ?>. All rights reserved.</p>
            </div>
        </div>
    </body>
    </html>
    <?php
    exit;
}

// Check if user is logged in
if (!isLoggedIn()) {
    displayResponse(false, 'You must be logged in to place an order');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user data
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    displayResponse(false, 'User not found');
}

// Check if POST request with required fields
if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['panel_id'])) {
    displayResponse(false, 'Invalid request: Missing panel_id');
}

// Get panel ID
$panelId = (int)$_POST['panel_id'];

// Get panel details
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE id = ? AND status = 'active'");
$stmt->bind_param("i", $panelId);
$stmt->execute();
$result = $stmt->get_result();
$panel = $result->fetch_assoc();

if (!$panel) {
    displayResponse(false, 'Panel not found or not active');
}

// Get setup fee
$setupFee = isset($panel['setup_fee']) ? floatval($panel['setup_fee']) : 0;

// Check if domain needs to be registered
$registerDomain = isset($_POST['register_domain']) && $_POST['register_domain'] == 'on' ? 1 : 0;
$domainExtension = isset($_POST['domain_extension']) ? sanitizeInput($_POST['domain_extension']) : '';
$domainPrice = isset($_POST['domain_price']) ? floatval($_POST['domain_price']) : 0;

// Check if WHOIS protection was selected
$whoisProtection = isset($_POST['whois_protection']) && $_POST['whois_protection'] == 'on' ? 1 : 0;
$whoisProtectionPrice = isset($_POST['whois_protection_price']) ? floatval($_POST['whois_protection_price']) : 0;

// Get add-ons
$addonsTotal = isset($_POST['total_addons_price']) ? floatval($_POST['total_addons_price']) : 0;
$selectedAddons = isset($_POST['selected_addons']) ? $_POST['selected_addons'] : '[]';

// Calculate total amount
$totalAmount = $panel['price'] + $setupFee;

// Add domain registration price if applicable
if ($registerDomain) {
    $totalAmount += $domainPrice;
    
    // Add WHOIS protection price if applicable
    if ($whoisProtection) {
        $totalAmount += $whoisProtectionPrice;
    }
}

// Add add-ons price
$totalAmount += $addonsTotal;

// Check if user has enough balance
if ($user['balance'] < $totalAmount) {
    displayResponse(false, 'Insufficient balance to order this panel. Please fund your wallet and try again.');
}

// Validate required fields
$domainName = isset($_POST['domain_name']) ? sanitizeInput($_POST['domain_name']) : '';
$companyName = isset($_POST['company_name']) ? sanitizeInput($_POST['company_name']) : '';
$companyEmail = isset($_POST['company_email']) ? sanitizeInput($_POST['company_email']) : '';
$companyPhone = isset($_POST['company_phone']) ? sanitizeInput($_POST['company_phone']) : '';
$companyAddress = isset($_POST['company_address']) ? sanitizeInput($_POST['company_address']) : '';
$additionalInfo = isset($_POST['additional_info']) ? sanitizeInput($_POST['additional_info']) : '';
$agreeTerms = isset($_POST['agree_terms']);

// Validate the required fields
$errors = [];
if (empty($domainName)) {
    $errors[] = 'Domain name is required';
}
if (empty($companyName)) {
    $errors[] = 'Company name is required';
}
if (empty($companyEmail)) {
    $errors[] = 'Company email is required';
} elseif (!filter_var($companyEmail, FILTER_VALIDATE_EMAIL)) {
    $errors[] = 'Invalid email format';
}
if (empty($companyPhone)) {
    $errors[] = 'Company phone is required';
}
if (!$agreeTerms) {
    $errors[] = 'You must agree to the terms and conditions';
}

// Return errors if any
if (!empty($errors)) {
    displayResponse(false, implode('. ', $errors));
}

// Generate unique order ID
$orderRef = 'RSL_' . strtoupper(substr(uniqid(), -6)) . date('mdY');

// Begin transaction
$conn->begin_transaction();

try {
    // Create order in reseller_orders table
    $stmt = $conn->prepare("
        INSERT INTO reseller_orders (
            user_id, panel_id, order_ref, amount, domain_name, domain_extension, domain_price,
            setup_fee, register_domain, whois_protection, addons, total_addons_price,
            company_name, company_email, company_phone, company_address, additional_info, status
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 'pending')
    ");
    
    $stmt->bind_param(
        "iisdssddiiissssss",
        $userId,
        $panelId,
        $orderRef,
        $totalAmount,
        $domainName,
        $domainExtension,
        $domainPrice,
        $setupFee,
        $registerDomain,
        $whoisProtection,
        $selectedAddons,
        $addonsTotal,
        $companyName,
        $companyEmail,
        $companyPhone,
        $companyAddress,
        $additionalInfo
    );
    
    $stmt->execute();
    $orderId = $conn->insert_id;
    
    // Deduct amount from user's wallet
    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
    $stmt->bind_param("di", $totalAmount, $userId);
    $stmt->execute();
    
    // Get the currency symbol from settings
    $currency = getSetting('currency', '₦');
    
    // Create transaction record
    $txnRef = 'TXN_' . time() . rand(1000, 9999);
    $description = "Payment for " . $panel['name'] . " reseller panel";
    
    $stmt = $conn->prepare("
        INSERT INTO transactions (
            user_id, txn_ref, type, amount, fee, description, status
        ) VALUES (?, ?, 'debit', ?, 0, ?, 'successful')
    ");
    
    $stmt->bind_param("isds", $userId, $txnRef, $totalAmount, $description);
    $stmt->execute();
    
    // Create user notification
    $title = 'Reseller Panel Order Placed';
    $message = 'Your order for ' . $panel['name'] . ' reseller panel has been placed successfully. We will process your order shortly.';
    
    $stmt = $conn->prepare("
        INSERT INTO notifications (
            user_id, title, message, type, is_read
        ) VALUES (?, ?, ?, 'success', 0)
    ");
    
    $stmt->bind_param("iss", $userId, $title, $message);
    $stmt->execute();
    
    // Create admin notification
    // First check if admin_notifications table exists
    $adminNotifTable = false;
    $stmt = $conn->prepare("SHOW TABLES LIKE 'admin_notifications'");
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $adminNotifTable = true;
    }
    
    if ($adminNotifTable) {
        $adminNotifTitle = 'New Reseller Panel Order';
        $adminNotifMessage = 'User ' . $user['username'] . ' has placed an order for ' . $panel['name'] . ' reseller panel.';
        
        // Get admin IDs
        $stmt = $conn->prepare("SELECT id FROM admins WHERE role = 'super_admin' OR role = 'admin'");
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($admin = $result->fetch_assoc()) {
            $stmt = $conn->prepare("
                INSERT INTO admin_notifications (
                    admin_id, title, message, type, is_read
                ) VALUES (?, ?, ?, 'info', 0)
            ");
            
            $stmt->bind_param("iss", $admin['id'], $adminNotifTitle, $adminNotifMessage);
            $stmt->execute();
        }
    }
    
    // Send email notification to admin
    $adminEmail = getSetting('admin_email');
    if ($adminEmail) {
        $subject = 'New Reseller Panel Order - ' . getSetting('site_name');
        
        // Build detailed order information including add-ons and domain options
        $orderDetails = "
            <p><strong>Order Details:</strong></p>
            <p>
                User: {$user['username']} (ID: {$user['id']})<br>
                Panel: {$panel['name']}<br>
                Panel Price: {$currency}{$panel['price']}<br>
                Setup Fee: {$currency}{$setupFee}<br>
        ";
        
        if ($registerDomain) {
            $orderDetails .= "
                Domain: {$domainName}{$domainExtension}<br>
                Domain Registration: {$currency}{$domainPrice}<br>
            ";
            
            if ($whoisProtection) {
                $orderDetails .= "WHOIS Protection: {$currency}{$whoisProtectionPrice}<br>";
            }
        } else {
            $orderDetails .= "Domain: {$domainName}<br>";
        }
        
        if ($addonsTotal > 0) {
            $orderDetails .= "Add-ons Total: {$currency}{$addonsTotal}<br>";
            
            // Add selected add-ons details if available
            $decodedAddons = json_decode($selectedAddons, true);
            if (!empty($decodedAddons)) {
                $orderDetails .= "<br><strong>Selected Add-ons:</strong><br>";
                
                foreach ($decodedAddons as $addon) {
                    // Get addon details
                    $stmt = $conn->prepare("SELECT name FROM reseller_addons WHERE id = ?");
                    $stmt->bind_param("i", $addon['id']);
                    $stmt->execute();
                    $addonResult = $stmt->get_result();
                    $addonInfo = $addonResult->fetch_assoc();
                    
                    if ($addonInfo) {
                        $orderDetails .= "- {$addonInfo['name']}: {$currency}{$addon['price']}<br>";
                    }
                }
            }
        }
        
        $orderDetails .= "
                <br>
                <strong>Total Amount: {$currency}{$totalAmount}</strong><br>
                <br>
                <strong>Customer Information:</strong><br>
                Company: {$companyName}<br>
                Email: {$companyEmail}<br>
                Phone: {$companyPhone}<br>
                Address: {$companyAddress}
            </p>
        ";
        
        if (!empty($additionalInfo)) {
            $orderDetails .= "
                <p><strong>Additional Information:</strong></p>
                <p>{$additionalInfo}</p>
            ";
        }
        
        $emailMsg = "
            <p>Hello Admin,</p>
            <p>A new reseller panel order has been placed.</p>
            {$orderDetails}
            <p>Please login to the admin dashboard to process this order.</p>
            <p>Regards,<br>" . getSetting('site_name') . " Team</p>
        ";
        
        sendEmail($adminEmail, $subject, $emailMsg);
    }
    
    // Send confirmation email to user
    if (!empty($user['email'])) {
        $subject = 'Reseller Panel Order Confirmation - ' . getSetting('site_name');
        $emailMsg = "
            <p>Hello {$user['username']},</p>
            <p>Your order for {$panel['name']} reseller panel has been placed successfully.</p>
            <p><strong>Order Details:</strong></p>
            <p>
                Order Reference: {$orderRef}<br>
                Panel: {$panel['name']}<br>
                Domain: {$domainName}{$domainExtension}<br>
                Total Amount: {$currency}{$totalAmount}<br>
                Status: Pending
            </p>
            <p>We will review your order and process it as soon as possible. You will receive a notification once your panel is ready.</p>
            <p>Thank you for choosing " . getSetting('site_name') . "!</p>
            <p>Regards,<br>" . getSetting('site_name') . " Team</p>
        ";
        
        sendEmail($user['email'], $subject, $emailMsg);
    }
    
    // Commit transaction
    $conn->commit();
    
    // Store success message in session
    $_SESSION['order_success'] = 'Your order has been placed successfully. We will process it shortly.';
    
    // Display success response
    displayResponse(true, 'Your order has been placed successfully. We will process it shortly.', [
        'order_id' => $orderId,
        'reference' => $orderRef,
        'panel_name' => $panel['name'],
        'amount' => $totalAmount
    ]);
    
} catch (Exception $e) {
    // Rollback transaction on error
    $conn->rollback();
    
    // Display error response
    displayResponse(false, 'An error occurred while processing your order. Please try again later.', null, $e->getMessage());
}
?>