<?php
$pageTitle = 'Reseller Panel';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get reseller panels
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$panels = [];

while ($row = $result->fetch_assoc()) {
    $row['features'] = !is_null($row['features']) ? json_decode($row['features'], true) : [];
    $row['screenshots'] = !is_null($row['screenshots']) ? json_decode($row['screenshots'], true) : [];
    $panels[] = $row;
}

// Get user's reseller panel orders
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro
    JOIN reseller_panels rp ON ro.panel_id = rp.id
    WHERE ro.user_id = ?
    ORDER BY ro.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$orders = [];

while ($row = $result->fetch_assoc()) {
    $orders[] = $row;
}

// Get domain extensions
$stmt = $conn->prepare("SELECT * FROM domain_extensions WHERE status = 'active' ORDER BY extension ASC");
$stmt->execute();
$result = $stmt->get_result();
$domainExtensions = [];

while ($row = $result->fetch_assoc()) {
    $domainExtensions[] = $row;
}

// Get add-ons
$stmt = $conn->prepare("SELECT * FROM reseller_addons WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$addons = [];

while ($row = $result->fetch_assoc()) {
    $addons[] = $row;
}

// Get form field settings
$stmt = $conn->prepare("
    SELECT * FROM form_field_settings 
    WHERE form_name = 'reseller_order' AND is_visible = 1
    ORDER BY id ASC
");
$stmt->execute();
$result = $stmt->get_result();
$formFields = [];

while ($row = $result->fetch_assoc()) {
    $formFields[$row['field_name']] = $row;
}

// If form_field_settings table doesn't exist or no settings found, use default fields
if (empty($formFields)) {
    $formFields = [
        'domain_name' => [
            'field_name' => 'domain_name',
            'field_label' => 'Domain Name',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_name' => [
            'field_name' => 'company_name',
            'field_label' => 'Company Name',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_email' => [
            'field_name' => 'company_email',
            'field_label' => 'Company Email',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_phone' => [
            'field_name' => 'company_phone',
            'field_label' => 'Company Phone',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_address' => [
            'field_name' => 'company_address',
            'field_label' => 'Company Address',
            'is_required' => 0,
            'is_visible' => 1
        ],
        'additional_info' => [
            'field_name' => 'additional_info',
            'field_label' => 'Additional Information',
            'is_required' => 0,
            'is_visible' => 1
        ]
    ];
}

// Default panel if only one is available
$defaultPanel = !empty($panels) ? $panels[0] : null;

// Get any "panel_id" from URL parameter
$selectedPanelId = isset($_GET['panel_id']) ? (int)$_GET['panel_id'] : null;

// Find the selected panel
$selectedPanel = null;
if ($selectedPanelId) {
    foreach ($panels as $panel) {
        if ($panel['id'] == $selectedPanelId) {
            $selectedPanel = $panel;
            break;
        }
    }
}

// If no panel is selected, use the default panel
if (!$selectedPanel && $defaultPanel) {
    $selectedPanel = $defaultPanel;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Reseller Panel</h1>
    
    <div class="text-sm text-gray-400 mb-6">
        Get your own VTU reseller panel with all features and services. Customize it with your brand and start earning.
    </div>
    
    <?php if (empty($panels)): ?>
        <div class="bg-gray-800 rounded-lg p-8 text-center">
            <div class="h-16 w-16 mx-auto mb-4 bg-gray-700 rounded-full flex items-center justify-center">
                <i class="fas fa-store-slash text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-white text-lg font-medium mb-2">No Reseller Panels Available</h3>
            <p class="text-gray-400 mb-4">Reseller panels are currently unavailable. Please check back later.</p>
        </div>
    <?php else: ?>
        <!-- Reseller Panel Selection -->
        <?php if (count($panels) > 1): ?>
            <div class="mb-6">
                <h2 class="text-lg font-semibold text-white mb-4">Select a Reseller Plan</h2>
                <div class="overflow-x-auto pb-2">
                    <div class="inline-flex space-x-4 min-w-full">
                        <?php foreach ($panels as $panel): ?>
                            <a href="?panel_id=<?php echo $panel['id']; ?>" class="flex-shrink-0 w-64">
                                <div class="bg-gray-800 border border-gray-700 rounded-lg p-4 h-full <?php echo ($selectedPanel && $selectedPanel['id'] == $panel['id']) ? 'border-indigo-500' : 'hover:border-gray-600'; ?>">
                                    <div class="font-bold text-white mb-2"><?php echo htmlspecialchars($panel['name']); ?></div>
                                    <div class="text-2xl font-bold text-white mb-3"><?php echo $currency . number_format($panel['price'], 2); ?></div>
                                    <div class="text-sm text-gray-400 mb-3"><?php echo htmlspecialchars($panel['description']); ?></div>
                                    
                                    <?php if (!empty($panel['sample_link'])): ?>
                                    <div class="mb-2">
                                        <a href="<?php echo htmlspecialchars($panel['sample_link']); ?>" target="_blank" class="text-indigo-400 hover:text-indigo-300 text-sm inline-flex items-center">
                                            <i class="fas fa-external-link-alt mr-1"></i> View Sample
                                        </a>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </a>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        
        <?php if ($selectedPanel): ?>
            <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
                <!-- Panel Details -->
                <div class="lg:col-span-1">
                    <div class="bg-gray-800 rounded-lg p-6 sticky top-24">
                        <h2 class="text-xl font-bold text-white mb-4"><?php echo htmlspecialchars($selectedPanel['name']); ?></h2>
                        <div class="text-3xl font-bold text-white mb-3"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></div>
                        <div class="text-sm text-gray-400 mb-4"><?php echo htmlspecialchars($selectedPanel['description']); ?></div>
                        
                        <?php if (!empty($selectedPanel['sample_link'])): ?>
                        <div class="mb-4">
                            <a href="<?php echo htmlspecialchars($selectedPanel['sample_link']); ?>" target="_blank" class="text-indigo-400 hover:text-indigo-300 inline-flex items-center">
                                <i class="fas fa-external-link-alt mr-2"></i> View Sample Panel
                            </a>
                        </div>
                        <?php endif; ?>
                        
                        <?php if (!empty($selectedPanel['screenshots'])): ?>
                        <div class="mb-4">
                            <h3 class="text-lg font-semibold text-white mb-3">Screenshot Preview</h3>
                            <div class="relative">
                                <div id="screenshots-carousel" class="overflow-hidden rounded-lg">
                                    <?php foreach ($selectedPanel['screenshots'] as $index => $screenshot): ?>
                                    <div class="screenshot-slide <?php echo $index === 0 ? 'block' : 'hidden'; ?>">
                                        <img src="<?php echo htmlspecialchars($screenshot); ?>" alt="Screenshot <?php echo $index + 1; ?>" class="w-full h-auto rounded">
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                                
                                <?php if (count($selectedPanel['screenshots']) > 1): ?>
                                <div class="absolute inset-y-0 left-0 flex items-center">
                                    <button type="button" class="carousel-prev bg-black bg-opacity-50 text-white p-2 rounded-r focus:outline-none">
                                        <i class="fas fa-chevron-left"></i>
                                    </button>
                                </div>
                                <div class="absolute inset-y-0 right-0 flex items-center">
                                    <button type="button" class="carousel-next bg-black bg-opacity-50 text-white p-2 rounded-l focus:outline-none">
                                        <i class="fas fa-chevron-right"></i>
                                    </button>
                                </div>
                                
                                <div class="absolute bottom-2 left-0 right-0 flex justify-center space-x-2">
                                    <?php foreach ($selectedPanel['screenshots'] as $index => $screenshot): ?>
                                    <button type="button" class="carousel-dot w-2 h-2 rounded-full <?php echo $index === 0 ? 'bg-white' : 'bg-gray-400'; ?>"></button>
                                    <?php endforeach; ?>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <?php endif; ?>
                        
                        <h3 class="text-lg font-semibold text-white mb-3">Features</h3>
                        <div class="space-y-3 mb-6">
                            <?php if (!empty($selectedPanel['features'])): ?>
                                <?php foreach ($selectedPanel['features'] as $feature): ?>
                                    <div class="flex items-start">
                                        <div class="h-5 w-5 rounded-full bg-indigo-500 bg-opacity-20 flex-shrink-0 flex items-center justify-center mt-0.5 mr-3">
                                            <i class="fas fa-check text-xs text-indigo-400"></i>
                                        </div>
                                        <div>
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($feature['title']); ?></div>
                                            <div class="text-xs text-gray-400"><?php echo htmlspecialchars($feature['description']); ?></div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p class="text-gray-400">No specific features listed.</p>
                            <?php endif; ?>
                        </div>
                        
                        <div class="text-sm text-gray-400">
                            <div class="flex items-center mb-2">
                                <i class="fas fa-calendar-alt text-indigo-400 mr-2"></i>
                                <span>Valid for 1 Year</span>
                            </div>
                            <div class="flex items-center">
                                <i class="fas fa-sync-alt text-indigo-400 mr-2"></i>
                                <span>Renewable Annually</span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Order Form -->
                <div class="lg:col-span-2">
                    <div class="bg-gray-800 rounded-lg p-6">
                        <h2 class="text-xl font-bold text-white mb-4">Order Reseller Panel</h2>
                        
                        <form method="POST" action="process/order_reseller.php" id="resellerOrderForm" class="space-y-4">
                            <input type="hidden" name="panel_id" value="<?php echo $selectedPanel['id']; ?>">
                            <input type="hidden" name="setup_fee" id="setup_fee" value="<?php echo floatval($selectedPanel['setup_fee']); ?>">
                            
                            <!-- Dynamic form fields based on settings -->
                            <?php foreach ($formFields as $fieldName => $field): ?>
                                <div class="form-group">
                                    <label for="<?php echo $fieldName; ?>" class="block text-sm font-medium text-gray-400 mb-2">
                                        <?php echo htmlspecialchars($field['field_label']); ?>
                                        <?php if ($field['is_required']): ?>
                                            <span class="text-red-500">*</span>
                                        <?php endif; ?>
                                    </label>
                                    
                                    <?php if ($fieldName === 'domain_name'): ?>
                                        <div class="grid grid-cols-12 gap-2">
                                            <div class="col-span-7 sm:col-span-8">
                                                <input type="text" id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 text-base" <?php echo $field['is_required'] ? 'required' : ''; ?>>
                                            </div>
                                            <div class="col-span-5 sm:col-span-4">
                                                <select id="domain_extension" name="domain_extension" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 text-base">
                                                    <?php foreach ($domainExtensions as $extension): ?>
                                                        <option value="<?php echo $extension['extension']; ?>" data-price="<?php echo $extension['price']; ?>" data-whois-price="<?php echo $extension['whois_protection_price']; ?>">
                                                            <?php echo $extension['extension']; ?> (<?php echo $currency . number_format($extension['price'], 2); ?>)
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </div>
                                        <div class="mt-3 space-y-2">
                                            <div class="flex items-center">
                                                <input type="checkbox" id="register_domain" name="register_domain" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                                                <label for="register_domain" class="ml-2 text-sm text-gray-400">Register domain for me (additional fees apply)</label>
                                            </div>
                                            <div id="whois_protection_container" class="flex items-center ml-6 hidden">
                                                <input type="checkbox" id="whois_protection" name="whois_protection" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                                                <label for="whois_protection" class="ml-2 text-sm text-gray-400">Add WHOIS Protection (<span id="whois_price">0.00</span>)</label>
                                                <i class="fas fa-question-circle text-gray-500 ml-1 tooltip" data-tooltip="WHOIS protection hides your personal information from public domain records"></i>
                                            </div>
                                        </div>
                                        <p class="mt-1 text-xs text-gray-500">Enter domain name if you have one, or we'll provide a subdomain for you.</p>
                                    <?php elseif ($fieldName === 'additional_info'): ?>
                                        <textarea id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" rows="3" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 text-base" <?php echo $field['is_required'] ? 'required' : ''; ?>></textarea>
                                    <?php elseif ($fieldName === 'company_address'): ?>
                                        <textarea id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" rows="2" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 text-base" <?php echo $field['is_required'] ? 'required' : ''; ?>></textarea>
                                    <?php else: ?>
                                        <input type="<?php echo $fieldName === 'company_email' ? 'email' : 'text'; ?>" id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 text-base" <?php echo $field['is_required'] ? 'required' : ''; ?>>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                            
                            <!-- Add-ons Section -->
                            <?php if (!empty($addons)): ?>
                            <div class="mt-6">
                                <h3 class="text-lg font-semibold text-white mb-3">Additional Services</h3>
                                <div class="bg-gray-900 rounded-lg p-4 space-y-3">
                                    <?php foreach ($addons as $addon): ?>
                                    <div class="flex items-center justify-between py-2 border-b border-gray-700 last:border-0">
                                        <div class="flex items-start">
                                            <input type="checkbox" id="addon_<?php echo $addon['id']; ?>" name="addons[]" value="<?php echo $addon['id']; ?>" data-price="<?php echo $addon['price']; ?>" class="addon-checkbox rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4 mt-1" <?php echo $addon['is_default'] ? 'checked' : ''; ?>>
                                            <div class="ml-2">
                                                <label for="addon_<?php echo $addon['id']; ?>" class="text-white cursor-pointer"><?php echo htmlspecialchars($addon['name']); ?></label>
                                                <p class="text-xs text-gray-400"><?php echo htmlspecialchars($addon['description']); ?></p>
                                            </div>
                                        </div>
                                        <div class="text-white font-medium">
                                            <?php echo $currency . number_format($addon['price'], 2); ?>
                                        </div>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                            <?php endif; ?>
                            
                            <!-- Terms and Conditions -->
                            <div class="form-group">
                                <label class="inline-flex items-center cursor-pointer">
                                    <input type="checkbox" id="agree_terms" name="agree_terms" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4" required>
                                    <span class="ml-2 text-gray-400">I agree to the <a href="<?php echo SITE_URL; ?>/terms.php" target="_blank" class="text-indigo-400 hover:text-indigo-300">Terms and Conditions</a></span>
                                </label>
                            </div>
                            
                            <!-- Payment Summary -->
                            <div class="p-4 bg-gray-900 rounded-md mb-4">
                                <div class="space-y-2 mb-3">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Reseller Panel:</span>
                                        <span class="text-white font-medium"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></span>
                                    </div>
                                    
                                    <?php if ($selectedPanel['setup_fee'] > 0): ?>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Setup Fee:</span>
                                        <span class="text-white font-medium"><?php echo $currency . number_format($selectedPanel['setup_fee'], 2); ?></span>
                                    </div>
                                    <?php endif; ?>
                                    
                                    <div id="domain_price_row" class="flex justify-between hidden">
                                        <span class="text-gray-400">Domain Registration:</span>
                                        <span class="text-white font-medium" id="domain_price_display"><?php echo $currency; ?>0.00</span>
                                    </div>
                                    
                                    <div id="whois_price_row" class="flex justify-between hidden">
                                        <span class="text-gray-400">WHOIS Protection:</span>
                                        <span class="text-white font-medium" id="whois_price_display"><?php echo $currency; ?>0.00</span>
                                    </div>
                                    
                                    <div id="addons_price_row" class="flex justify-between hidden">
                                        <span class="text-gray-400">Add-ons:</span>
                                        <span class="text-white font-medium" id="addons_price_display"><?php echo $currency; ?>0.00</span>
                                    </div>
                                </div>
                                
                                <div class="flex justify-between pt-2 border-t border-gray-700">
                                    <span class="text-gray-300 font-medium">Total Amount:</span>
                                    <span class="text-white font-bold" id="total_price"><?php echo $currency . number_format($selectedPanel['price'] + $selectedPanel['setup_fee'], 2); ?></span>
                                </div>
                            </div>
                            
                            <!-- Submit Button -->
                            <div class="flex justify-end">
                                <button type="submit" id="orderBtn" class="accent-button py-2 px-6 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                    Order Now
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- My Reseller Panels -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">My Reseller Panels</h2>
    
    <?php if (empty($orders)): ?>
        <div class="text-center py-10 text-gray-400">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-store text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-lg font-medium mb-1">No Reseller Panels Yet</h3>
            <p class="text-sm mb-4">You haven't ordered any reseller panels yet.</p>
            <?php if (!empty($panels)): ?>
                <a href="#resellerOrderForm" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                    Order Reseller Panel
                </a>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Order Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Panel</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Domain</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Expiry Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, Y', strtotime($order['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($order['panel_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($order['domain_name'] ? $order['domain_name'] . ($order['domain_extension'] ? $order['domain_extension'] : '') : 'Not specified'); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($order['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php
                                $statusColors = [
                                    'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-400',
                                    'processing' => 'bg-blue-500 bg-opacity-20 text-blue-400',
                                    'completed' => 'bg-green-500 bg-opacity-20 text-green-400',
                                    'cancelled' => 'bg-red-500 bg-opacity-20 text-red-400'
                                ];
                                $statusColor = $statusColors[$order['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-400';
                                ?>
                                <span class="px-2 py-1 text-xs rounded-full <?php echo $statusColor; ?>">
                                    <?php echo ucfirst($order['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php 
                                if ($order['status'] === 'completed' && $order['expiry_date']) {
                                    echo date('M d, Y', strtotime($order['expiry_date']));
                                    
                                    // Check if expiry date is within 30 days
                                    $expiryDays = (strtotime($order['expiry_date']) - time()) / (60 * 60 * 24);
                                    if ($expiryDays <= 30 && $expiryDays > 0) {
                                        echo ' <span class="text-xs text-red-400">(' . round($expiryDays) . ' days left)</span>';
                                    }
                                } else {
                                    echo 'N/A';
                                }
                                ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php if ($order['status'] === 'completed'): ?>
                                    <a href="<?php echo isset($order['domain_name']) && $order['domain_name'] ? 'https://' . $order['domain_name'] . ($order['domain_extension'] ?: '') : '#'; ?>" class="text-indigo-400 hover:text-indigo-300" <?php echo isset($order['domain_name']) && $order['domain_name'] ? 'target="_blank"' : ''; ?>>
                                        <i class="fas fa-external-link-alt mr-1"></i> Access Panel
                                    </a>
                                <?php elseif ($order['status'] === 'pending'): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/view_order.php?id=<?php echo $order['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                        <i class="fas fa-eye mr-1"></i> View Details
                                    </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2">Processing Your Order</p>
        <p class="text-gray-400">Please wait while we process your reseller panel order...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Submitted Successfully!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your reseller panel order has been submitted successfully. Our team will review your order and contact you shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Order Reference:</span>
                <span id="orderReference" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Panel:</span>
                <span id="panelName" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="orderAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="orderDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeSuccessModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your reseller panel order at this time.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Tooltip -->
<div id="tooltip" class="absolute z-50 bg-gray-900 text-white text-xs rounded py-1 px-2 hidden">
    Tooltip text
</div>

<?php
$extraScripts = <<<'EOT'
<script>
document.addEventListener('DOMContentLoaded', function() {
    // Carousel functionality
    const slides = document.querySelectorAll('.screenshot-slide');
    const dots = document.querySelectorAll('.carousel-dot');
    const prevBtn = document.querySelector('.carousel-prev');
    const nextBtn = document.querySelector('.carousel-next');
    
    if (slides.length > 0) {
        let currentSlide = 0;
        
        function showSlide(index) {
            slides.forEach((slide, i) => {
                slide.classList.toggle('hidden', i !== index);
            });
            
            if (dots.length > 0) {
                dots.forEach((dot, i) => {
                    dot.classList.toggle('bg-white', i === index);
                    dot.classList.toggle('bg-gray-400', i !== index);
                });
            }
            
            currentSlide = index;
        }
        
        if (prevBtn) {
            prevBtn.addEventListener('click', () => {
                let newIndex = currentSlide - 1;
                if (newIndex < 0) newIndex = slides.length - 1;
                showSlide(newIndex);
            });
        }
        
        if (nextBtn) {
            nextBtn.addEventListener('click', () => {
                let newIndex = currentSlide + 1;
                if (newIndex >= slides.length) newIndex = 0;
                showSlide(newIndex);
            });
        }
        
        dots.forEach((dot, i) => {
            dot.addEventListener('click', () => {
                showSlide(i);
            });
        });
    }

    // Form price calculation functionality
    const panelPrice = parseFloat(document.querySelector('#resellerOrderForm input[name="panel_id"]').value);
    const setupFee = parseFloat(document.querySelector('#setup_fee').value) || 0;
    const domainExtensionSelect = document.querySelector('#domain_extension');
    const registerDomainCheckbox = document.querySelector('#register_domain');
    const whoisProtectionCheckbox = document.querySelector('#whois_protection');
    const whoisProtectionContainer = document.querySelector('#whois_protection_container');
    const totalPriceElement = document.querySelector('#total_price');
    const domainPriceRow = document.querySelector('#domain_price_row');
    const domainPriceDisplay = document.querySelector('#domain_price_display');
    const whoisPriceRow = document.querySelector('#whois_price_row');
    const whoisPriceDisplay = document.querySelector('#whois_price_display');
    const addonsRow = document.querySelector('#addons_price_row');
    const addonsPriceDisplay = document.querySelector('#addons_price_display');
    const currency = totalPriceElement.textContent.charAt(0);
    const addonCheckboxes = document.querySelectorAll('.addon-checkbox');
    
    // Update WHOIS price display
    function updateWhoisPrice() {
        if (domainExtensionSelect) {
            const selectedOption = domainExtensionSelect.options[domainExtensionSelect.selectedIndex];
            const whoisPrice = parseFloat(selectedOption.dataset.whoisPrice) || 0;
            const whoisPriceFormatted = whoisPrice.toFixed(2);
            
            if (document.querySelector('#whois_price')) {
                document.querySelector('#whois_price').textContent = currency + whoisPriceFormatted;
            }
            
            if (whoisPriceDisplay) {
                whoisPriceDisplay.textContent = currency + whoisPriceFormatted;
            }
        }
    }
    
    // Calculate total price
    function calculateTotalPrice() {
        let total = parseFloat('<?php echo $selectedPanel['price']; ?>') || 0;
        
        // Add setup fee
        total += setupFee;
        
        // Domain registration
        let domainPrice = 0;
        let whoisPrice = 0;
        
        if (registerDomainCheckbox && registerDomainCheckbox.checked && domainExtensionSelect) {
            const selectedOption = domainExtensionSelect.options[domainExtensionSelect.selectedIndex];
            domainPrice = parseFloat(selectedOption.dataset.price) || 0;
            total += domainPrice;
            
            // Show domain price row
            if (domainPriceRow) {
                domainPriceRow.classList.remove('hidden');
                domainPriceDisplay.textContent = currency + domainPrice.toFixed(2);
            }
            
            // WHOIS protection
            if (whoisProtectionCheckbox && whoisProtectionCheckbox.checked) {
                whoisPrice = parseFloat(selectedOption.dataset.whoisPrice) || 0;
                total += whoisPrice;
                
                // Show WHOIS price row
                if (whoisPriceRow) {
                    whoisPriceRow.classList.remove('hidden');
                    whoisPriceDisplay.textContent = currency + whoisPrice.toFixed(2);
                }
            } else {
                // Hide WHOIS price row
                if (whoisPriceRow) {
                    whoisPriceRow.classList.add('hidden');
                }
            }
        } else {
            // Hide domain and WHOIS price rows
            if (domainPriceRow) domainPriceRow.classList.add('hidden');
            if (whoisPriceRow) whoisPriceRow.classList.add('hidden');
        }
        
        // Add-ons
        let addonTotal = 0;
        
        if (addonCheckboxes.length > 0) {
            addonCheckboxes.forEach(checkbox => {
                if (checkbox.checked) {
                    addonTotal += parseFloat(checkbox.dataset.price) || 0;
                }
            });
            
            if (addonTotal > 0) {
                total += addonTotal;
                
                if (addonsRow) {
                    addonsRow.classList.remove('hidden');
                    addonsPriceDisplay.textContent = currency + addonTotal.toFixed(2);
                }
            } else {
                if (addonsRow) {
                    addonsRow.classList.add('hidden');
                }
            }
        }
        
        // Update total price display
        if (totalPriceElement) {
            totalPriceElement.textContent = currency + total.toFixed(2);
        }
    }
    
    // Update WHOIS visibility based on domain registration checkbox
    if (registerDomainCheckbox) {
        registerDomainCheckbox.addEventListener('change', function() {
            if (this.checked) {
                if (whoisProtectionContainer) {
                    whoisProtectionContainer.classList.remove('hidden');
                }
            } else {
                if (whoisProtectionContainer) {
                    whoisProtectionContainer.classList.add('hidden');
                }
                if (whoisProtectionCheckbox) {
                    whoisProtectionCheckbox.checked = false;
                }
            }
            calculateTotalPrice();
        });
    }
    
    // Event listeners for price calculation
    if (domainExtensionSelect) {
        domainExtensionSelect.addEventListener('change', function() {
            updateWhoisPrice();
            calculateTotalPrice();
        });
    }
    
    if (whoisProtectionCheckbox) {
        whoisProtectionCheckbox.addEventListener('change', function() {
            calculateTotalPrice();
        });
    }
    
    // Add-on checkboxes
    addonCheckboxes.forEach(checkbox => {
        checkbox.addEventListener('change', calculateTotalPrice);
    });
    
    // Initial price calculation and WHOIS price update
    updateWhoisPrice();
    calculateTotalPrice();
    
    // Order form submission
    const orderForm = document.getElementById('resellerOrderForm');
    const loadingModal = document.getElementById('loadingModal');
    const successModal = document.getElementById('successModal');
    const errorModal = document.getElementById('errorModal');
    
    if (orderForm) {
        orderForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Show loading modal
            if (loadingModal) {
                loadingModal.classList.remove('hidden');
            }
            
            // Prepare form data with selected add-ons
            const formData = new FormData(orderForm);
            
            // Add domain registration data
            if (registerDomainCheckbox && domainExtensionSelect) {
                const selectedOption = domainExtensionSelect.options[domainExtensionSelect.selectedIndex];
                const domainPrice = registerDomainCheckbox.checked ? parseFloat(selectedOption.dataset.price) || 0 : 0;
                const whoisPrice = (registerDomainCheckbox.checked && whoisProtectionCheckbox && whoisProtectionCheckbox.checked) ? parseFloat(selectedOption.dataset.whoisPrice) || 0 : 0;
                
                formData.append('domain_price', domainPrice);
                formData.append('whois_protection_price', whoisPrice);
            }
            
            // Calculate total add-ons price
            let addonTotal = 0;
            const selectedAddons = [];
            
            addonCheckboxes.forEach(checkbox => {
                if (checkbox.checked) {
                    const addonId = checkbox.value;
                    const addonPrice = parseFloat(checkbox.dataset.price) || 0;
                    addonTotal += addonPrice;
                    selectedAddons.push({id: addonId, price: addonPrice});
                }
            });
            
            formData.append('total_addons_price', addonTotal);
            formData.append('selected_addons', JSON.stringify(selectedAddons));
            
            // Submit form using fetch API
            fetch(orderForm.action, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                // Hide loading modal
                if (loadingModal) {
                    loadingModal.classList.add('hidden');
                }
                
                if (data.success) {
                    // Show success modal
                    if (successModal) {
                        document.getElementById('successMessage').textContent = data.message;
                        document.getElementById('orderReference').textContent = data.data.reference;
                        document.getElementById('panelName').textContent = data.data.panel_name;
                        document.getElementById('orderAmount').textContent = currency + parseFloat(data.data.amount).toFixed(2);
                        document.getElementById('orderDate').textContent = new Date().toLocaleDateString();
                        
                        successModal.classList.remove('hidden');
                    }
                    
                    // Reset the form
                    orderForm.reset();
                    
                    // Update price calculation
                    calculateTotalPrice();
                } else {
                    // Show error modal
                    if (errorModal) {
                        document.getElementById('errorMessage').textContent = data.message;
                        errorModal.classList.remove('hidden');
                    }
                }
            })
            .catch(error => {
                console.error('Error:', error);
                
                // Hide loading modal
                if (loadingModal) {
                    loadingModal.classList.add('hidden');
                }
                
                // Show error modal
                if (errorModal) {
                    document.getElementById('errorMessage').textContent = 'An error occurred. Please try again later.';
                    errorModal.classList.remove('hidden');
                }
            });
        });
    }
    
    // Modal close buttons
    const closeSuccessModal = document.getElementById('closeSuccessModal');
    const closeErrorModal = document.getElementById('closeErrorModal');
    
    if (closeSuccessModal) {
        closeSuccessModal.addEventListener('click', function() {
            successModal.classList.add('hidden');
            // Redirect to orders page
            window.location.href = '<?php echo SITE_URL; ?>/dashboard/reseller.php';
        });
    }
    
    if (closeErrorModal) {
        closeErrorModal.addEventListener('click', function() {
            errorModal.classList.add('hidden');
        });
    }
    
    // Tooltip functionality
    const tooltips = document.querySelectorAll('.tooltip');
    const tooltipElement = document.getElementById('tooltip');
    
    tooltips.forEach(tooltip => {
        tooltip.addEventListener('mouseenter', function() {
            const tooltipText = this.getAttribute('data-tooltip');
            tooltipElement.textContent = tooltipText;
            tooltipElement.classList.remove('hidden');
            
            // Position the tooltip
            const rect = this.getBoundingClientRect();
            tooltipElement.style.top = (rect.top - tooltipElement.offsetHeight - 10) + 'px';
            tooltipElement.style.left = (rect.left + rect.width / 2 - tooltipElement.offsetWidth / 2) + 'px';
        });
        
        tooltip.addEventListener('mouseleave', function() {
            tooltipElement.classList.add('hidden');
        });
    });
});
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>