<?php
$pageTitle = 'Reseller Panel';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get reseller panels
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$panels = [];

while ($row = $result->fetch_assoc()) {
    $row['features'] = json_decode($row['features'], true);
    $panels[] = $row;
}

// Get user's reseller panel orders
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro
    JOIN reseller_panels rp ON ro.panel_id = rp.id
    WHERE ro.user_id = ?
    ORDER BY ro.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$orders = [];

while ($row = $result->fetch_assoc()) {
    $orders[] = $row;
}

// Get form field settings
$stmt = $conn->prepare("
    SELECT * FROM form_field_settings 
    WHERE form_name = 'reseller_order' AND is_visible = 1
    ORDER BY id ASC
");
$stmt->execute();
$result = $stmt->get_result();
$formFields = [];

while ($row = $result->fetch_assoc()) {
    $formFields[$row['field_name']] = $row;
}

// If form_field_settings table doesn't exist or no settings found, use default fields
if (empty($formFields)) {
    $formFields = [
        'domain_name' => [
            'field_name' => 'domain_name',
            'field_label' => 'Domain Name',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_name' => [
            'field_name' => 'company_name',
            'field_label' => 'Company Name',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_email' => [
            'field_name' => 'company_email',
            'field_label' => 'Company Email',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_phone' => [
            'field_name' => 'company_phone',
            'field_label' => 'Company Phone',
            'is_required' => 1,
            'is_visible' => 1
        ],
        'company_address' => [
            'field_name' => 'company_address',
            'field_label' => 'Company Address',
            'is_required' => 0,
            'is_visible' => 1
        ],
        'additional_info' => [
            'field_name' => 'additional_info',
            'field_label' => 'Additional Information',
            'is_required' => 0,
            'is_visible' => 1
        ]
    ];
}

// Default panel if only one is available
$defaultPanel = !empty($panels) ? $panels[0] : null;

// Get any "panel_id" from URL parameter
$selectedPanelId = isset($_GET['panel_id']) ? (int)$_GET['panel_id'] : null;

// Find the selected panel
$selectedPanel = null;
if ($selectedPanelId) {
    foreach ($panels as $panel) {
        if ($panel['id'] == $selectedPanelId) {
            $selectedPanel = $panel;
            break;
        }
    }
}

// If no panel is selected, use the default panel
if (!$selectedPanel && $defaultPanel) {
    $selectedPanel = $defaultPanel;
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Reseller Panel</h1>
    
    <div class="text-sm text-gray-400 mb-6">
        Get your own VTU reseller panel with all features and services. Customize it with your brand and start earning.
    </div>
    
    <?php if (empty($panels)): ?>
        <div class="bg-gray-800 rounded-lg p-8 text-center">
            <div class="h-16 w-16 mx-auto mb-4 bg-gray-700 rounded-full flex items-center justify-center">
                <i class="fas fa-store-slash text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-white text-lg font-medium mb-2">No Reseller Panels Available</h3>
            <p class="text-gray-400 mb-4">Reseller panels are currently unavailable. Please check back later.</p>
        </div>
    <?php else: ?>
        <!-- Reseller Panel Selection -->
        <?php if (count($panels) > 1): ?>
            <div class="mb-6">
                <h2 class="text-lg font-semibold text-white mb-4">Select a Reseller Plan</h2>
                <div class="grid grid-cols-1 md:grid-cols-<?php echo min(count($panels), 3); ?> gap-4">
                    <?php foreach ($panels as $panel): ?>
                        <a href="?panel_id=<?php echo $panel['id']; ?>" class="block">
                            <div class="bg-gray-800 border border-gray-700 rounded-lg p-4 h-full <?php echo ($selectedPanel && $selectedPanel['id'] == $panel['id']) ? 'border-indigo-500' : 'hover:border-gray-600'; ?>">
                                <div class="font-bold text-white mb-2"><?php echo htmlspecialchars($panel['name']); ?></div>
                                <div class="text-2xl font-bold text-white mb-3"><?php echo $currency . number_format($panel['price'], 2); ?></div>
                                <div class="text-sm text-gray-400 mb-3"><?php echo htmlspecialchars($panel['description']); ?></div>
                            </div>
                        </a>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <?php if ($selectedPanel): ?>
            <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
                <!-- Panel Details -->
                <div class="lg:col-span-1">
                    <div class="bg-gray-800 rounded-lg p-6 sticky top-24">
                        <h2 class="text-xl font-bold text-white mb-4"><?php echo htmlspecialchars($selectedPanel['name']); ?></h2>
                        <div class="text-3xl font-bold text-white mb-3"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></div>
                        <div class="text-sm text-gray-400 mb-4"><?php echo htmlspecialchars($selectedPanel['description']); ?></div>
                        
                        <h3 class="text-lg font-semibold text-white mb-3">Features</h3>
                        <div class="space-y-3 mb-6">
                            <?php if (!empty($selectedPanel['features'])): ?>
                                <?php foreach ($selectedPanel['features'] as $feature): ?>
                                    <div class="flex items-start">
                                        <div class="h-5 w-5 rounded-full bg-indigo-500 bg-opacity-20 flex-shrink-0 flex items-center justify-center mt-0.5 mr-3">
                                            <i class="fas fa-check text-xs text-indigo-400"></i>
                                        </div>
                                        <div>
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($feature['title']); ?></div>
                                            <div class="text-xs text-gray-400"><?php echo htmlspecialchars($feature['description']); ?></div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p class="text-gray-400">No specific features listed.</p>
                            <?php endif; ?>
                        </div>
                        
                        <div class="text-sm text-gray-400">
                            <div class="flex items-center mb-2">
                                <i class="fas fa-calendar-alt text-indigo-400 mr-2"></i>
                                <span>Valid for 1 Year</span>
                            </div>
                            <div class="flex items-center">
                                <i class="fas fa-sync-alt text-indigo-400 mr-2"></i>
                                <span>Renewable Annually</span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Order Form -->
                <div class="lg:col-span-2">
                    <div class="bg-gray-800 rounded-lg p-6">
                        <h2 class="text-xl font-bold text-white mb-4">Order Reseller Panel</h2>
                        
                        <form method="POST" action="process/order_reseller.php" id="resellerOrderForm" class="space-y-4">
                            <input type="hidden" name="panel_id" value="<?php echo $selectedPanel['id']; ?>">
                            
                            <!-- Dynamic form fields based on settings -->
                            <?php foreach ($formFields as $fieldName => $field): ?>
                                <div class="form-group">
                                    <label for="<?php echo $fieldName; ?>" class="block text-sm font-medium text-gray-400 mb-2">
                                        <?php echo htmlspecialchars($field['field_label']); ?>
                                        <?php if ($field['is_required']): ?>
                                            <span class="text-red-500">*</span>
                                        <?php endif; ?>
                                    </label>
                                    
                                    <?php if ($fieldName === 'additional_info'): ?>
                                        <textarea id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" rows="3" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" <?php echo $field['is_required'] ? 'required' : ''; ?>></textarea>
                                    <?php elseif ($fieldName === 'company_address'): ?>
                                        <textarea id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" rows="2" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" <?php echo $field['is_required'] ? 'required' : ''; ?>></textarea>
                                    <?php else: ?>
                                        <input type="<?php echo $fieldName === 'company_email' ? 'email' : 'text'; ?>" id="<?php echo $fieldName; ?>" name="<?php echo $fieldName; ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" <?php echo $field['is_required'] ? 'required' : ''; ?>>
                                    <?php endif; ?>
                                    
                                    <?php if ($fieldName === 'domain_name'): ?>
                                        <p class="mt-1 text-xs text-gray-500">Enter domain name if you have one, or we'll provide a subdomain for you.</p>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                            
                            <!-- Terms and Conditions -->
                            <div class="form-group">
                                <label class="inline-flex items-center cursor-pointer">
                                    <input type="checkbox" id="agree_terms" name="agree_terms" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4" required>
                                    <span class="ml-2 text-gray-400">I agree to the <a href="<?php echo SITE_URL; ?>/terms.php" target="_blank" class="text-indigo-400 hover:text-indigo-300">Terms and Conditions</a></span>
                                </label>
                            </div>
                            
                            <!-- Payment Summary -->
                            <div class="p-4 bg-gray-900 rounded-md mb-4">
                                <div class="flex justify-between mb-2">
                                    <span class="text-gray-400">Reseller Panel:</span>
                                    <span class="text-white font-medium"><?php echo htmlspecialchars($selectedPanel['name']); ?></span>
                                </div>
                                <div class="flex justify-between mb-2">
                                    <span class="text-gray-400">Validity:</span>
                                    <span class="text-white font-medium">1 Year</span>
                                </div>
                                <div class="flex justify-between pt-2 border-t border-gray-700">
                                    <span class="text-gray-300 font-medium">Total Amount:</span>
                                    <span class="text-white font-bold"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></span>
                                </div>
                            </div>
                            
                            <!-- Submit Button -->
                            <div class="flex justify-end">
                                <button type="submit" id="orderBtn" class="accent-button py-2 px-6 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                    Order Now
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- My Reseller Panels -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">My Reseller Panels</h2>
    
    <?php if (empty($orders)): ?>
        <div class="text-center py-10 text-gray-400">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-store text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-lg font-medium mb-1">No Reseller Panels Yet</h3>
            <p class="text-sm mb-4">You haven't ordered any reseller panels yet.</p>
            <?php if (!empty($panels)): ?>
                <a href="#resellerOrderForm" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                    Order Reseller Panel
                </a>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Order Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Panel</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Domain</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Expiry Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, Y', strtotime($order['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($order['panel_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($order['domain_name'] ?: 'Not specified'); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($order['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php
                                $statusColors = [
                                    'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-400',
                                    'processing' => 'bg-blue-500 bg-opacity-20 text-blue-400',
                                    'completed' => 'bg-green-500 bg-opacity-20 text-green-400',
                                    'cancelled' => 'bg-red-500 bg-opacity-20 text-red-400'
                                ];
                                $statusColor = $statusColors[$order['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-400';
                                ?>
                                <span class="px-2 py-1 text-xs rounded-full <?php echo $statusColor; ?>">
                                    <?php echo ucfirst($order['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php 
                                if ($order['status'] === 'completed' && $order['expiry_date']) {
                                    echo date('M d, Y', strtotime($order['expiry_date']));
                                    
                                    // Check if expiry date is within 30 days
                                    $expiryDays = (strtotime($order['expiry_date']) - time()) / (60 * 60 * 24);
                                    if ($expiryDays <= 30 && $expiryDays > 0) {
                                        echo ' <span class="text-xs text-red-400">(' . round($expiryDays) . ' days left)</span>';
                                    }
                                } else {
                                    echo 'N/A';
                                }
                                ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php if ($order['status'] === 'completed'): ?>
                                    <a href="<?php echo isset($order['domain_name']) && $order['domain_name'] ? 'https://' . $order['domain_name'] : '#'; ?>" class="text-indigo-400 hover:text-indigo-300" <?php echo isset($order['domain_name']) && $order['domain_name'] ? 'target="_blank"' : ''; ?>>
                                        <i class="fas fa-external-link-alt mr-1"></i> Access Panel
                                    </a>
                                <?php elseif ($order['status'] === 'pending'): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/view_order.php?id=<?php echo $order['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                        <i class="fas fa-eye mr-1"></i> View Details
                                    </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2">Processing Your Order</p>
        <p class="text-gray-400">Please wait while we process your reseller panel order...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Submitted Successfully!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your reseller panel order has been submitted successfully. Our team will review your order and contact you shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Order Reference:</span>
                <span id="orderReference" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Panel:</span>
                <span id="panelName" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="orderAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="orderDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeSuccessModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your reseller panel order at this time.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<'EOT'
<script>
document.addEventListener('DOMContentLoaded', function() {
    const orderForm = document.getElementById('orderForm');
    const orderResponse = document.getElementById('orderResponse');
    
    if (orderForm) {
        orderForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Remove any previous response
            orderResponse.innerHTML = '';
            orderResponse.className = 'hidden mb-4 p-4 rounded-md';
            
            // Show loading state
            const submitButton = orderForm.querySelector('button[type="submit"]');
            const originalButtonText = submitButton.innerHTML;
            submitButton.disabled = true;
            submitButton.innerHTML = '<i class="fas fa-spinner fa-spin mr-2"></i> Processing...';
            
            // Submit form using fetch API
            const formData = new FormData(orderForm);
            
            fetch(orderForm.action, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    // Show success message
                    orderResponse.innerHTML = `
                        <div class="flex items-start">
                            <i class="fas fa-check-circle text-green-500 mr-2 mt-1"></i>
                            <div>
                                <p class="text-white">${data.message}</p>
                                <p class="text-gray-400 mt-1">Order Reference: ${data.data.reference}</p>
                            </div>
                        </div>
                    `;
                    orderResponse.className = 'mb-4 p-4 bg-green-500 bg-opacity-10 border border-green-500 rounded-md';
                    
                    // Reset the form
                    orderForm.reset();
                    
                    // Redirect to orders page after a delay
                    setTimeout(() => {
                        window.location.href = 'orders.php';
                    }, 3000);
                } else {
                    // Show error message
                    orderResponse.innerHTML = `
                        <div class="flex items-start">
                            <i class="fas fa-exclamation-circle text-red-500 mr-2 mt-1"></i>
                            <p class="text-white">${data.message}</p>
                        </div>
                    `;
                    orderResponse.className = 'mb-4 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md';
                    
                    // Reset button
                    submitButton.disabled = false;
                    submitButton.innerHTML = originalButtonText;
                }
            })
            .catch(error => {
                console.error('Error:', error);
                // Show error message
                orderResponse.innerHTML = `
                    <div class="flex items-start">
                        <i class="fas fa-exclamation-circle text-red-500 mr-2 mt-1"></i>
                        <p class="text-white">An error occurred. Please try again later.</p>
                    </div>
                `;
                orderResponse.className = 'mb-4 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md';
                
                // Reset button
                submitButton.disabled = false;
                submitButton.innerHTML = originalButtonText;
            });
        });
    }
});
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>