<?php
// File: dashboard/reward/index.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

// Page title
$pageTitle = 'Rewards';
require_once '../includes/header.php';
?>

<div class="container px-4 py-6 mx-auto">
    <div class="dashboard-card shadow rounded-lg p-6 mb-6">
        <h1 class="text-2xl font-bold text-white mb-6">Rewards & Referrals</h1>
        
        <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
            <!-- Referrals Card -->
            <a href="<?php echo SITE_URL; ?>/dashboard/reward/referral.php" class="bg-indigo-900 bg-opacity-20 border border-indigo-500 rounded-lg p-6 transition-transform hover:transform hover:scale-105">
                <div class="w-16 h-16 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-user-plus text-3xl text-indigo-400"></i>
                </div>
                <h2 class="text-xl font-semibold text-white mb-2">My Referrals</h2>
                <p class="text-gray-400 mb-4">Track your referrals, share your referral link, and claim rewards.</p>
                <div class="text-indigo-400 flex items-center">
                    <span>View Referrals</span>
                    <i class="fas fa-arrow-right ml-2"></i>
                </div>
            </a>
            
            <!-- Contests Card -->
            <a href="<?php echo SITE_URL; ?>/dashboard/reward/contest.php" class="bg-purple-900 bg-opacity-20 border border-purple-500 rounded-lg p-6 transition-transform hover:transform hover:scale-105">
                <div class="w-16 h-16 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-trophy text-3xl text-purple-400"></i>
                </div>
                <h2 class="text-xl font-semibold text-white mb-2">Referral Contests</h2>
                <p class="text-gray-400 mb-4">Join referral contests to compete for prizes and exclusive rewards.</p>
                <div class="text-purple-400 flex items-center">
                    <span>Browse Contests</span>
                    <i class="fas fa-arrow-right ml-2"></i>
                </div>
            </a>
            
            <!-- Achievements Card -->
            <a href="<?php echo SITE_URL; ?>/dashboard/reward/achievement.php" class="bg-green-900 bg-opacity-20 border border-green-500 rounded-lg p-6 transition-transform hover:transform hover:scale-105">
                <div class="w-16 h-16 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-medal text-3xl text-green-400"></i>
                </div>
                <h2 class="text-xl font-semibold text-white mb-2">Achievements</h2>
                <p class="text-gray-400 mb-4">Unlock achievements and earn rewards for completing tasks.</p>
                <div class="text-green-400 flex items-center">
                    <span>View Achievements</span>
                    <i class="fas fa-arrow-right ml-2"></i>
                </div>
            </a>
        </div>
        
        <!-- Quick Stats -->
        <div class="mt-8 bg-gray-800 rounded-lg p-6">
            <h2 class="text-xl font-semibold text-white mb-4">Your Reward Stats</h2>
            
            <div class="grid grid-cols-1 md:grid-cols-4 gap-6">
                <div>
                    <p class="text-gray-400 text-sm mb-1">Total Referrals</p>
                    <p class="text-2xl font-bold text-white"><?php echo $user['referrals_count']; ?></p>
                </div>
                
                <div>
                    <p class="text-gray-400 text-sm mb-1">Referral Earnings</p>
                    <p class="text-2xl font-bold text-white"><?php echo formatAmount($user['referral_earnings']); ?></p>
                </div>
                
                <?php 
                // Get contest stats
                $stmt = $conn->prepare("
                    SELECT COUNT(*) as total_contests,
                           SUM(CASE WHEN ce.is_disqualified = 0 THEN 1 ELSE 0 END) as active_contests
                    FROM contest_entries ce
                    WHERE ce.user_id = ?
                ");
                $stmt->bind_param("i", $userId);
                $stmt->execute();
                $result = $stmt->get_result();
                $contestStats = $result->fetch_assoc();
                $totalContests = $contestStats['total_contests'] ?? 0;
                $activeContests = $contestStats['active_contests'] ?? 0;
                ?>
                
                <div>
                    <p class="text-gray-400 text-sm mb-1">Contests Joined</p>
                    <p class="text-2xl font-bold text-white"><?php echo $totalContests; ?></p>
                </div>
                
                <div>
                    <p class="text-gray-400 text-sm mb-1">Active Contests</p>
                    <p class="text-2xl font-bold text-white"><?php echo $activeContests; ?></p>
                </div>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>