<?php
$pageTitle = 'Support';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Handle form submission
$successMessage = '';
$errorMessage = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['submit_ticket'])) {
    $subject = sanitizeInput($_POST['subject']);
    $category = sanitizeInput($_POST['category']);
    $message = sanitizeInput($_POST['message']);
    $reference = isset($_POST['reference']) ? sanitizeInput($_POST['reference']) : '';
    
    // Validate inputs
    if (empty($subject)) {
        $errorMessage = 'Please enter a subject for your ticket';
    } elseif (empty($category)) {
        $errorMessage = 'Please select a category for your ticket';
    } elseif (empty($message)) {
        $errorMessage = 'Please enter a message for your ticket';
    } else {
        // Create a ticket
        // This is a placeholder - replace with your actual ticket creation logic
        
        // Assume we have a support_tickets table
        $stmt = $conn->prepare("
            INSERT INTO support_tickets 
            (user_id, subject, category, message, reference, status)
            VALUES (?, ?, ?, ?, ?, 'open')
        ");
        
        $stmt->bind_param("issss", $userId, $subject, $category, $message, $reference);
        
        if ($stmt->execute()) {
            $ticketId = $conn->insert_id;
            
            // Send email notification
            $adminEmail = getSetting('admin_email');
            $userEmail = $user['email'];
            
            // Email to admin
            if ($adminEmail) {
                $subject = "New Support Ticket #{$ticketId}";
                $emailMessage = "
                    <p>A new support ticket has been submitted.</p>
                    <p><strong>Ticket ID:</strong> #{$ticketId}</p>
                    <p><strong>User:</strong> {$user['username']} ({$user['email']})</p>
                    <p><strong>Subject:</strong> {$_POST['subject']}</p>
                    <p><strong>Category:</strong> {$_POST['category']}</p>
                    <p><strong>Message:</strong></p>
                    <p>{$_POST['message']}</p>
                ";
                
                if (!empty($reference)) {
                    $emailMessage .= "<p><strong>Reference:</strong> {$reference}</p>";
                }
                
                sendEmail($adminEmail, $subject, $emailMessage);
            }
            
            // Email to user
            if ($userEmail) {
                $subject = "Your Support Ticket #{$ticketId} Has Been Received";
                $emailMessage = "
                    <p>Dear {$user['username']},</p>
                    <p>We have received your support ticket. Our team will review it and get back to you as soon as possible.</p>
                    <p><strong>Ticket ID:</strong> #{$ticketId}</p>
                    <p><strong>Subject:</strong> {$_POST['subject']}</p>
                    <p><strong>Category:</strong> {$_POST['category']}</p>
                    <p>Thank you for your patience.</p>
                ";
                
                sendEmail($userEmail, $subject, $emailMessage);
            }
            
            $successMessage = 'Your support ticket has been submitted successfully. We will get back to you soon.';
            
            // Clear form inputs after successful submission
            $_POST = [];
        } else {
            $errorMessage = 'Failed to submit your ticket. Please try again later.';
        }
    }
}

// Get user's recent tickets
$tickets = [];

// Attempt to get tickets if the table exists
try {
    $stmt = $conn->prepare("
        SELECT * FROM support_tickets 
        WHERE user_id = ? 
        ORDER BY created_at DESC
        LIMIT 5
    ");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $tickets[] = $row;
    }
} catch (Exception $e) {
    // Table might not exist, silently ignore
    error_log("Support tickets table error: " . $e->getMessage());
}

// Get FAQ categories and items
$faqs = [
    'general' => [
        ['question' => 'How do I fund my wallet?', 
         'answer' => 'To fund your wallet, navigate to the "Fund Wallet" page. You can choose from various payment methods including bank transfer, card payment, and USSD. Follow the instructions for your chosen method to complete the funding process.'],
        ['question' => 'What happens if my transaction fails?', 
         'answer' => 'If your transaction fails, the amount will not be deducted from your wallet. If it was a wallet funding transaction and your account was debited by your bank but not credited on our platform, please contact our support team with your payment reference.']
    ],
    'data' => [
        ['question' => 'How long does it take for data to be delivered?', 
         'answer' => 'Data purchases are usually processed and delivered instantly. In rare cases, it might take up to 5 minutes. If you haven\'t received your data after 5 minutes, please contact our support team.'],
        ['question' => 'Why is my data not delivering to my phone?', 
         'answer' => 'This could be due to several reasons: incorrect phone number, network issues, or temporary service disruption. Please verify the phone number and ensure it\'s active and properly formatted.']
    ],
    'airtime' => [
        ['question' => 'Can I buy airtime for any network?', 
         'answer' => 'Yes, you can purchase airtime for all major networks including MTN, Airtel, Glo, and 9mobile.'],
        ['question' => 'Is there a limit to how much airtime I can buy?', 
         'answer' => 'Yes, there is a minimum amount of ₦50 and a maximum of ₦50,000 per transaction. For larger amounts, you can make multiple transactions.']
    ],
    'account' => [
        ['question' => 'How do I change my password?', 
         'answer' => 'To change your password, go to your account settings page. Click on "Change Password", enter your current password, and then your new password.'],
        ['question' => 'What are the benefits of upgrading to a vendor account?', 
         'answer' => 'Vendor accounts enjoy lower rates on all services, higher transaction limits, and the ability to create sub-accounts. This is ideal for resellers and businesses.']
    ]
];
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Support Center</h1>
    
    <div class="text-sm text-gray-400 mb-6">
        Need help with something? Get assistance from our support team or browse through our frequently asked questions.
    </div>
    
    <div class="bg-gray-800 rounded-lg overflow-hidden">
        <div class="border-b border-gray-700">
            <nav class="-mb-px flex" aria-label="Tabs">
                <button class="support-tab-button text-white px-4 py-3 font-medium border-b-2 border-indigo-500" data-tab="contact">
                    <i class="fas fa-headset mr-2"></i> Contact Support
                </button>
                <button class="support-tab-button text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="tickets">
                    <i class="fas fa-ticket-alt mr-2"></i> My Tickets
                </button>
                <button class="support-tab-button text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="faq">
                    <i class="fas fa-question-circle mr-2"></i> FAQs
                </button>
            </nav>
        </div>
        
        <!-- Contact Support Tab -->
        <div id="contact-tab" class="support-tab-content p-4">
            <?php if ($successMessage): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4">
                    <p><?php echo $successMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($errorMessage): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4">
                    <p><?php echo $errorMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <form method="POST" action="" class="space-y-4">
                <div>
                    <label for="subject" class="block text-sm font-medium text-gray-400 mb-1">Subject</label>
                    <input type="text" id="subject" name="subject" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo isset($_POST['subject']) ? htmlspecialchars($_POST['subject']) : ''; ?>" required>
                </div>
                
                <div>
                    <label for="category" class="block text-sm font-medium text-gray-400 mb-1">Category</label>
                    <select id="category" name="category" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="" <?php echo !isset($_POST['category']) ? 'selected' : ''; ?> disabled>Select a category</option>
                        <option value="account" <?php echo (isset($_POST['category']) && $_POST['category'] === 'account') ? 'selected' : ''; ?>>Account Issues</option>
                        <option value="payment" <?php echo (isset($_POST['category']) && $_POST['category'] === 'payment') ? 'selected' : ''; ?>>Payment & Wallet</option>
                        <option value="data" <?php echo (isset($_POST['category']) && $_POST['category'] === 'data') ? 'selected' : ''; ?>>Data Purchase</option>
                        <option value="airtime" <?php echo (isset($_POST['category']) && $_POST['category'] === 'airtime') ? 'selected' : ''; ?>>Airtime Purchase</option>
                        <option value="cable" <?php echo (isset($_POST['category']) && $_POST['category'] === 'cable') ? 'selected' : ''; ?>>Cable TV</option>
                        <option value="electricity" <?php echo (isset($_POST['category']) && $_POST['category'] === 'electricity') ? 'selected' : ''; ?>>Electricity</option>
                        <option value="other" <?php echo (isset($_POST['category']) && $_POST['category'] === 'other') ? 'selected' : ''; ?>>Other</option>
                    </select>
                </div>
                
                <div>
                    <label for="reference" class="block text-sm font-medium text-gray-400 mb-1">Transaction Reference (optional)</label>
                    <input type="text" id="reference" name="reference" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo isset($_POST['reference']) ? htmlspecialchars($_POST['reference']) : ''; ?>">
                    <p class="mt-1 text-xs text-gray-500">If your query is about a specific transaction, please provide the reference number</p>
                </div>
                
                <div>
                    <label for="message" class="block text-sm font-medium text-gray-400 mb-1">Message</label>
                    <textarea id="message" name="message" rows="5" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo isset($_POST['message']) ? htmlspecialchars($_POST['message']) : ''; ?></textarea>
                    <p class="mt-1 text-xs text-gray-500">Please provide as much detail as possible to help us assist you better</p>
                </div>
                
                <div class="pt-2">
                    <button type="submit" name="submit_ticket" class="accent-button py-2 px-6 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Submit Ticket
                    </button>
                </div>
            </form>
        </div>
        
        <!-- My Tickets Tab -->
        <div id="tickets-tab" class="support-tab-content p-4 hidden">
            <?php if (empty($tickets)): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-ticket-alt text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Support Tickets</h3>
                    <p class="text-gray-500 text-sm mb-4">You haven't created any support tickets yet</p>
                    <button class="support-tab-button py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm inline-block" data-tab="contact">
                        Create a Ticket
                    </button>
                </div>
            <?php else: ?>
                <div class="overflow-x-auto">
                    <table class="min-w-full">
                        <thead class="bg-gray-700">
                            <tr>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Ticket ID</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Subject</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Category</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Date</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                            </tr>
                        </thead>
                        <tbody class="divide-y divide-gray-800">
                            <?php foreach ($tickets as $ticket): ?>
                                <tr>
                                    <td class="py-3 px-4 text-sm text-white">
                                        #<?php echo $ticket['id']; ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-white">
                                        <?php echo htmlspecialchars($ticket['subject']); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo ucfirst(htmlspecialchars($ticket['category'])); ?>
                                    </td>
                                    <td class="py-3 px-4">
                                        <?php
                                        $statusColors = [
                                            'open' => 'bg-green-500 bg-opacity-20 text-green-400',
                                            'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-400',
                                            'replied' => 'bg-blue-500 bg-opacity-20 text-blue-400',
                                            'closed' => 'bg-gray-500 bg-opacity-20 text-gray-400'
                                        ];
                                        $statusColor = $statusColors[$ticket['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-400';
                                        ?>
                                        <span class="px-2 py-1 text-xs rounded-full <?php echo $statusColor; ?>">
                                            <?php echo ucfirst($ticket['status']); ?>
                                        </span>
                                    </td>
                                    <td class="py-3 px-4 text-sm text-gray-300">
                                        <?php echo date('M d, Y', strtotime($ticket['created_at'])); ?>
                                    </td>
                                    <td class="py-3 px-4 text-sm">
                                        <a href="<?php echo SITE_URL; ?>/dashboard/view_ticket.php?id=<?php echo $ticket['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                            View
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- FAQs Tab -->
        <div id="faq-tab" class="support-tab-content p-4 hidden">
            <div class="flex flex-col md:flex-row">
                <!-- FAQ Categories -->
                <div class="md:w-1/4 mb-4 md:mb-0 md:mr-4">
                    <div class="bg-gray-700 rounded-lg p-4">
                        <h3 class="text-white font-medium mb-3">Categories</h3>
                        <ul class="space-y-2">
                            <li>
                                <button class="faq-category-btn w-full text-left py-2 px-3 rounded text-white bg-indigo-600" data-category="general">
                                    General Questions
                                </button>
                            </li>
                            <li>
                                <button class="faq-category-btn w-full text-left py-2 px-3 rounded text-gray-300 hover:bg-gray-600" data-category="data">
                                    Data Services
                                </button>
                            </li>
                            <li>
                                <button class="faq-category-btn w-full text-left py-2 px-3 rounded text-gray-300 hover:bg-gray-600" data-category="airtime">
                                    Airtime Services
                                </button>
                            </li>
                            <li>
                                <button class="faq-category-btn w-full text-left py-2 px-3 rounded text-gray-300 hover:bg-gray-600" data-category="account">
                                    Account & Billing
                                </button>
                            </li>
                        </ul>
                    </div>
                </div>
                
                <!-- FAQ Content -->
                <div class="md:w-3/4">
                    <?php foreach ($faqs as $category => $categoryFaqs): ?>
                        <div id="faq-<?php echo $category; ?>" class="faq-category <?php echo $category !== 'general' ? 'hidden' : ''; ?>">
                            <h3 class="text-white font-medium mb-4"><?php echo ucfirst($category); ?> FAQs</h3>
                            
                            <div class="space-y-4">
                                <?php foreach ($categoryFaqs as $index => $faq): ?>
                                    <div class="faq-item bg-gray-700 rounded-lg overflow-hidden">
                                        <button class="faq-question w-full text-left py-3 px-4 focus:outline-none flex justify-between items-center">
                                            <span class="text-white font-medium"><?php echo htmlspecialchars($faq['question']); ?></span>
                                            <i class="fas fa-chevron-down text-gray-400 transition-transform"></i>
                                        </button>
                                        <div class="faq-answer px-4 pb-3 hidden">
                                            <p class="text-gray-300"><?php echo htmlspecialchars($faq['answer']); ?></p>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                    
                    <div class="mt-6 bg-gray-700 rounded-lg p-4">
                        <h3 class="text-white font-medium mb-2">Still have questions?</h3>
                        <p class="text-gray-400 mb-3">If you couldn't find the answer to your question, feel free to contact our support team.</p>
                        <button class="support-tab-button py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm" data-tab="contact">
                            Contact Support
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Contact Information Card -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">
        <i class="fas fa-address-card mr-2 text-indigo-400"></i> Contact Information
    </h2>
    <div class="bg-gray-800 rounded-lg p-6">
        <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div class="text-center">
                <div class="h-12 w-12 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fas fa-envelope text-indigo-400"></i>
                </div>
                <h3 class="text-white font-semibold mb-1">Email</h3>
                <a href="mailto:<?php echo getSetting('support_email') ?: 'support@teleco.com.ng'; ?>" class="text-indigo-400 hover:text-indigo-300">
                    <?php echo getSetting('support_email') ?: 'support@teleco.com.ng'; ?>
                </a>
            </div>
            
            <div class="text-center">
                <div class="h-12 w-12 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fas fa-phone text-green-400"></i>
                </div>
                <h3 class="text-white font-semibold mb-1">Phone</h3>
                <a href="tel:<?php echo getSetting('support_phone') ?: '+234 800 123 4567'; ?>" class="text-green-400 hover:text-green-300">
                    <?php echo getSetting('support_phone') ?: '+234 800 123 4567'; ?>
                </a>
            </div>
            
            <div class="text-center">
                <div class="h-12 w-12 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mx-auto mb-3">
                    <i class="fab fa-whatsapp text-blue-400"></i>
                </div>
                <h3 class="text-white font-semibold mb-1">WhatsApp</h3>
                <a href="https://wa.me/<?php echo str_replace(['+', ' ', '-'], '', getSetting('whatsapp_number') ?: '+234 800 123 4567'); ?>" class="text-blue-400 hover:text-blue-300" target="_blank">
                    <?php echo getSetting('whatsapp_number') ?: '+234 800 123 4567'; ?>
                </a>
            </div>
        </div>
        
        <div class="mt-6 text-center text-gray-400">
            <p>Our support team is available Monday to Friday, 8:00 AM - 6:00 PM WAT.</p>
            <p>We typically respond to tickets within 24 hours.</p>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Tab switching functionality
        const tabButtons = document.querySelectorAll('.support-tab-button');
        const tabContents = document.querySelectorAll('.support-tab-content');
        
        tabButtons.forEach(button => {
            button.addEventListener('click', function() {
                const targetTab = this.getAttribute('data-tab');
                
                // Hide all tab contents
                tabContents.forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all tab buttons
                tabButtons.forEach(btn => {
                    btn.classList.remove('text-white', 'border-indigo-500');
                    btn.classList.add('text-gray-400', 'border-transparent', 'hover:border-gray-500');
                });
                
                // Show selected tab content
                document.getElementById(targetTab + '-tab').classList.remove('hidden');
                
                // Highlight selected tab button
                this.classList.remove('text-gray-400', 'border-transparent', 'hover:border-gray-500');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
        
        // FAQ category switching
        const categoryButtons = document.querySelectorAll('.faq-category-btn');
        const categoryContents = document.querySelectorAll('.faq-category');
        
        categoryButtons.forEach(button => {
            button.addEventListener('click', function() {
                const targetCategory = this.getAttribute('data-category');
                
                // Hide all category contents
                categoryContents.forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all category buttons
                categoryButtons.forEach(btn => {
                    btn.classList.remove('bg-indigo-600', 'text-white');
                    btn.classList.add('text-gray-300', 'hover:bg-gray-600');
                });
                
                // Show selected category content
                document.getElementById('faq-' + targetCategory).classList.remove('hidden');
                
                // Highlight selected category button
                this.classList.remove('text-gray-300', 'hover:bg-gray-600');
                this.classList.add('bg-indigo-600', 'text-white');
            });
        });
        
        // FAQ accordion functionality
        const faqQuestions = document.querySelectorAll('.faq-question');
        
        faqQuestions.forEach(question => {
            question.addEventListener('click', function() {
                const answer = this.nextElementSibling;
                const icon = this.querySelector('i');
                
                answer.classList.toggle('hidden');
                icon.classList.toggle('transform');
                icon.classList.toggle('rotate-180');
            });
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>