<?php
require_once 'config.php';

class Database {
    private $host = DB_HOST;
    private $user = DB_USER;
    private $pass = DB_PASS;
    private $dbname = DB_NAME;
    
    private $connection;
    private $error;
    private static $instance;
    
    // Singleton pattern - ensures only one database connection is created
    public static function getInstance() {
        if (!self::$instance) {
            self::$instance = new Database();
        }
        return self::$instance;
    }
    
    private function __construct() {
        $this->connectDB();
    }
    
    // Connect to the database
    private function connectDB() {
        try {
            $this->connection = new mysqli($this->host, $this->user, $this->pass, $this->dbname);
            
            if ($this->connection->connect_error) {
                throw new Exception('Database connection error: ' . $this->connection->connect_error);
            }
            
            // Set charset to UTF-8
            $this->connection->set_charset('utf8mb4');
        } catch (Exception $e) {
            $this->error = $e->getMessage();
            echo $this->error;
        }
    }
    
    // Get database connection
    public function getConnection() {
        return $this->connection;
    }
    
    // Execute query
    public function query($sql) {
        return $this->connection->query($sql);
    }
    
    // Get error
    public function getError() {
        return $this->error;
    }
    
    // Prepare statement
    public function prepare($sql) {
        return $this->connection->prepare($sql);
    }
    
    // Sanitize input data
    public function escapeString($string) {
        return $this->connection->real_escape_string($string);
    }
    
    // Get last insert ID
    public function getLastId() {
        return $this->connection->insert_id;
    }
    
    // Count affected rows
    public function countAffected() {
        return $this->connection->affected_rows;
    }
    
    // Begin transaction
    public function beginTransaction() {
        $this->connection->begin_transaction();
    }
    
    // Commit transaction
    public function commit() {
        $this->connection->commit();
    }
    
    // Rollback transaction
    public function rollback() {
        $this->connection->rollback();
    }
    
    // Close connection when object is destroyed
    public function __destruct() {
        if ($this->connection) {
            $this->connection->close();
        }
    }
}
?>