<?php
// File: /includes/redirects.php
// Purpose: Handle URL redirects for similar URLs

// Define redirects - map from (incorrect URL) to (correct URL)
$redirects = [
    // Auth redirects
    '/signup' => '/register',
    '/signup.php' => '/register.php',
    '/signin' => '/login',
    '/signin.php' => '/login.php',
    '/log-in' => '/login',
    '/log-in.php' => '/login.php',
    '/sign-in' => '/login',
    '/sign-in.php' => '/login.php',
    '/register-account' => '/register',
    '/register-account.php' => '/register.php',
    '/create-account' => '/register',
    '/create-account.php' => '/register.php',
    
    // Dashboard redirects
    '/dashboard/home' => '/dashboard',
    '/dashboard/home.php' => '/dashboard/index.php',
    '/dashboard/main' => '/dashboard',
    '/dashboard/main.php' => '/dashboard/index.php',
    
    // Common misspellings or alternative paths
    '/dashbaord' => '/dashboard', // misspelling
    '/services' => '/dashboard/services.php',
    '/wallet' => '/dashboard/wallet.php',
    '/profile' => '/dashboard/profile.php',
    '/service-ids' => '/dashboard/service_ids.php',
    '/service_id' => '/dashboard/service_ids.php',
    '/ids' => '/dashboard/service_ids.php',
    
    // API related
    '/api' => '/api/documentation',
    '/api-docs' => '/api/documentation',
    '/api/docs' => '/api/documentation',
    '/api-documentation' => '/api/documentation',
    
    // Admin redirects
    '/admin/home' => '/admin',
    '/admin/home.php' => '/admin/index.php',
    
    // Payments
    '/payment' => '/dashboard/wallet.php',
    '/deposit' => '/dashboard/wallet.php',
    '/fund' => '/dashboard/wallet.php',
    '/topup' => '/dashboard/wallet.php',
    
    // Services
    '/airtime' => '/dashboard/buy_airtime.php',
    '/buy-airtime' => '/dashboard/buy_airtime.php',
    '/data' => '/dashboard/buy_data.php',
    '/buy-data' => '/dashboard/buy_data.php',
    
    // Add more redirects as needed
];

// Get the current request path (without query string)
$requestUri = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);

// Check if the current URL needs redirection
if (isset($redirects[$requestUri])) {
    // Get the target URL
    $targetUrl = $redirects[$requestUri];
    
    // If there's a query string, preserve it
    if (!empty($_SERVER['QUERY_STRING'])) {
        $targetUrl .= '?' . $_SERVER['QUERY_STRING'];
    }
    
    // Perform the redirect with 301 Moved Permanently status code
    header("HTTP/1.1 301 Moved Permanently");
    header("Location: $targetUrl");
    exit;
}

// If you want to handle plural/singular variations automatically, you can add this logic
$singularToPlural = [
    '/service' => '/services',
    '/network' => '/networks',
    '/transaction' => '/transactions',
    // Add more patterns as needed
];

foreach ($singularToPlural as $singular => $plural) {
    // Check if URL starts with the singular form but is not exactly the singular form
    if (strpos($requestUri, $singular . '/') === 0 && $requestUri != $singular) {
        $pluralUrl = str_replace($singular . '/', $plural . '/', $requestUri);
        
        // If there's a query string, preserve it
        if (!empty($_SERVER['QUERY_STRING'])) {
            $pluralUrl .= '?' . $_SERVER['QUERY_STRING'];
        }
        
        header("HTTP/1.1 301 Moved Permanently");
        header("Location: $pluralUrl");
        exit;
    }
}

// No redirect needed, continue with normal script execution
?>