<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

// Get site settings
$siteName = getSetting('site_name') ?: 'VTU Platform';
$siteDescription = getSetting('site_description') ?: 'Buy data, airtime, and pay bills at the best prices';
$contactEmail = getSetting('contact_email') ?: 'support@example.com';
$contactPhone = getSetting('contact_phone') ?: '09167408768';

// Check if user is logged in
$loggedIn = isLoggedIn();

// Get flash message
$flashMessage = getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $siteName; ?> - Data, Airtime & Bills Payment</title>
    <meta name="description" content="<?php echo $siteDescription; ?>">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
            scroll-behavior: smooth;
        }
        
        .site-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .site-card {
            transition: transform 0.3s ease, box-shadow 0.3s ease;
        }
        
        .site-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 25px -5px rgba(0, 0, 0, 0.3);
        }
        
        .mobile-app-mockup {
            position: relative;
            z-index: 10;
        }
        
        .glow-circle {
            position: absolute;
            width: 300px;
            height: 300px;
            border-radius: 50%;
            background: radial-gradient(circle, rgba(93, 92, 222, 0.3) 0%, rgba(0, 0, 0, 0) 70%);
            z-index: 0;
        }
        
        .feature-icon {
            background: linear-gradient(135deg, rgba(93, 92, 222, 0.2) 0%, rgba(93, 92, 222, 0.1) 100%);
        }
        
        .testimonial-card {
            position: relative;
            overflow: hidden;
        }
        
        .testimonial-card::before {
            content: '';
            position: absolute;
            top: -100px;
            left: -100px;
            width: 200px;
            height: 200px;
            background: radial-gradient(circle, rgba(93, 92, 222, 0.1) 0%, rgba(0, 0, 0, 0) 70%);
            border-radius: 50%;
            z-index: 0;
        }
        
        .testimonial-card::after {
            content: '';
            position: absolute;
            bottom: -100px;
            right: -100px;
            width: 200px;
            height: 200px;
            background: radial-gradient(circle, rgba(93, 92, 222, 0.1) 0%, rgba(0, 0, 0, 0) 70%);
            border-radius: 50%;
            z-index: 0;
        }
        
        .testimonial-content {
            position: relative;
            z-index: 10;
        }
        
        .hero-gradient {
            background: linear-gradient(135deg, rgba(93, 92, 222, 0.1) 0%, rgba(0, 0, 0, 0) 100%);
        }
        
        .section-divider {
            height: 6px;
            background: linear-gradient(90deg, transparent, var(--accent-color), transparent);
            opacity: 0.3;
            width: 100px;
            margin: 0 auto;
            border-radius: 3px;
        }

        /* Mobile menu animation */
        .mobile-menu-enter {
            opacity: 0;
            transform: translateY(-10px);
        }
        
        .mobile-menu-enter-active {
            opacity: 1;
            transform: translateY(0);
            transition: opacity 200ms, transform 200ms;
        }
        
        .mobile-menu-exit {
            opacity: 1;
            transform: translateY(0);
        }
        
        .mobile-menu-exit-active {
            opacity: 0;
            transform: translateY(-10px);
            transition: opacity 150ms, transform 150ms;
        }
        
        /* Animation for counting numbers */
        @keyframes countUp {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }
        
        .count-up {
            animation: countUp 1s forwards;
        }
        
        /* Custom scrollbar for webkit browsers */
        ::-webkit-scrollbar {
            width: 10px;
            height: 10px;
        }
        
        ::-webkit-scrollbar-track {
            background: var(--bg-secondary);
        }
        
        ::-webkit-scrollbar-thumb {
            background: #444;
            border-radius: 5px;
        }
        
        ::-webkit-scrollbar-thumb:hover {
            background: #555;
        }
    </style>
</head>
<body>
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow-lg">
        <div class="container mx-auto px-4 py-3">
            <div class="flex justify-between items-center">
                <div class="flex items-center">
                    <a href="index.php" class="font-bold text-xl flex items-center">
                        <span class="text-indigo-400 mr-1"><i class="fas fa-bolt"></i></span>
                        <?php echo $siteName; ?>
                    </a>
                </div>
                
                <!-- Desktop Navigation -->
                <nav class="hidden md:flex items-center space-x-8">
                    <a href="#features" class="text-gray-300 hover:text-white transition-colors">Features</a>
                    <a href="#services" class="text-gray-300 hover:text-white transition-colors">Services</a>
                    <a href="#pricing" class="text-gray-300 hover:text-white transition-colors">Pricing</a>
                    <a href="#faq" class="text-gray-300 hover:text-white transition-colors">FAQ</a>
                    <a href="#contact" class="text-gray-300 hover:text-white transition-colors">Contact</a>
                    
                    <div class="ml-4">
                        <?php if ($loggedIn): ?>
                            <a href="dashboard/" class="accent-button py-2 px-4 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">
                                Dashboard
                            </a>
                        <?php else: ?>
                            <a href="login/" class="text-gray-300 hover:text-white transition-colors mr-4">Login</a>
                            <a href="login/register.php" class="accent-button py-2 px-4 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">
                                Register
                            </a>
                        <?php endif; ?>
                    </div>
                </nav>
                
                <!-- Mobile Menu Button -->
                <button id="mobileMenuButton" class="md:hidden text-gray-300 hover:text-white focus:outline-none">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 6h16M4 12h16m-7 6h7"></path>
                    </svg>
                </button>
            </div>
            
            <!-- Mobile Navigation -->
            <div id="mobileMenu" class="hidden md:hidden mt-4 pb-4">
                <nav class="flex flex-col space-y-3">
                    <a href="#features" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md">Features</a>
                    <a href="#services" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md">Services</a>
                    <a href="#pricing" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md">Pricing</a>
                    <a href="#faq" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md">FAQ</a>
                    <a href="#contact" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md">Contact</a>
                    
                    <div class="border-t border-gray-700 pt-3 mt-2 flex">
                        <?php if ($loggedIn): ?>
                            <a href="dashboard/" class="accent-button py-2 px-4 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">
                                Dashboard
                            </a>
                        <?php else: ?>
                            <a href="login/" class="text-gray-300 hover:text-white transition-colors py-2 px-3 hover:bg-gray-700 rounded-md mr-2">Login</a>
                            <a href="login/register.php" class="accent-button py-2 px-4 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">
                                Register
                            </a>
                        <?php endif; ?>
                    </div>
                </nav>
            </div>
        </div>
    </header>
    
    <?php if ($flashMessage): ?>
        <div class="container mx-auto px-4 mt-4">
            <div class="<?php echo $flashMessage['type'] === 'success' ? 'bg-green-500' : 'bg-red-500'; ?> text-white p-4 rounded-md">
                <?php echo $flashMessage['message']; ?>
            </div>
        </div>
    <?php endif; ?>
    
    <!-- Hero Section -->
    <section class="py-16 md:py-24 hero-gradient">
        <div class="container mx-auto px-4">
            <div class="flex flex-col md:flex-row items-center">
                <div class="md:w-1/2 mb-8 md:mb-0">
                    <h1 class="text-4xl md:text-5xl font-bold text-white leading-tight mb-4">
                        Buy Data, Airtime & Pay Bills at 
                        <span class="text-indigo-400">The Best Prices</span>
                    </h1>
                    <p class="text-xl text-gray-300 mb-8">
                        Quick, reliable, and affordable VTU services for all networks. Save more with our discounted rates and instant delivery.
                    </p>
                    <div class="flex flex-col sm:flex-row space-y-4 sm:space-y-0 sm:space-x-4">
                        <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="accent-button py-3 px-8 rounded-md text-white font-medium text-center hover:bg-indigo-600 transition-colors">
                            <?php echo $loggedIn ? 'Go to Dashboard' : 'Get Started'; ?>
                        </a>
                        <a href="#services" class="bg-gray-700 py-3 px-8 rounded-md text-white font-medium text-center hover:bg-gray-600 transition-colors">
                            Explore Services
                        </a>
                    </div>
                </div>
                <div class="md:w-1/2 relative">
                    <div class="glow-circle" style="top: 10%; left: 20%;"></div>
                    <div class="mobile-app-mockup">
                        <!-- Mobile mockup for the service -->
                        <div class="relative mx-auto border-gray-800 dark:border-gray-800 bg-gray-800 border-[14px] rounded-[2.5rem] h-[600px] w-[300px] shadow-xl">
                            <div class="w-[148px] h-[18px] bg-gray-800 top-0 rounded-b-[1rem] left-1/2 -translate-x-1/2 absolute"></div>
                            <div class="h-[46px] w-[3px] bg-gray-800 absolute -left-[17px] top-[124px] rounded-l-lg"></div>
                            <div class="h-[46px] w-[3px] bg-gray-800 absolute -left-[17px] top-[178px] rounded-l-lg"></div>
                            <div class="h-[64px] w-[3px] bg-gray-800 absolute -right-[17px] top-[142px] rounded-r-lg"></div>
                            <div class="rounded-[2rem] overflow-hidden w-[272px] h-[572px] bg-white dark:bg-gray-800">
                                <!-- App Screen Content -->
                                <div class="bg-indigo-500 w-full h-24 flex items-center justify-center text-white font-bold text-xl">
                                    <?php echo $siteName; ?> App
                                </div>
                                <div class="p-4 space-y-4">
                                    <div class="bg-gray-700 p-3 rounded-lg flex items-center justify-between">
                                        <div>
                                            <div class="text-xs text-gray-400">Wallet Balance</div>
                                            <div class="text-white font-bold text-xl">₦25,430.00</div>
                                        </div>
                                        <button class="bg-indigo-500 text-white px-3 py-1 rounded-md text-sm">Fund</button>
                                    </div>
                                    
                                    <!-- Services Grid -->
                                    <div class="grid grid-cols-3 gap-3">
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-indigo-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-wifi text-indigo-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">Data</span>
                                        </div>
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-green-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-phone text-green-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">Airtime</span>
                                        </div>
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-yellow-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-bolt text-yellow-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">Electric</span>
                                        </div>
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-red-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-tv text-red-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">Cable</span>
                                        </div>
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-blue-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-exchange-alt text-blue-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">Convert</span>
                                        </div>
                                        <div class="bg-gray-700 p-2 rounded-lg flex flex-col items-center">
                                            <div class="h-8 w-8 rounded-full bg-purple-500 bg-opacity-30 flex items-center justify-center mb-1">
                                                <i class="fas fa-ellipsis-h text-purple-400 text-sm"></i>
                                            </div>
                                            <span class="text-white text-xs">More</span>
                                        </div>
                                    </div>
                                    
                                    <!-- Data Purchase Form -->
                                    <div class="bg-gray-700 p-3 rounded-lg space-y-3">
                                        <div class="text-white font-medium">Buy Data Bundle</div>
                                        <div class="bg-gray-600 rounded-md px-3 py-2 text-sm text-white flex justify-between">
                                            <span>Network</span>
                                            <span>MTN <i class="fas fa-chevron-down ml-1 text-xs"></i></span>
                                        </div>
                                        <div class="bg-gray-600 rounded-md px-3 py-2 text-sm text-white flex justify-between">
                                            <span>Data Plan</span>
                                            <span>1GB / 30 Days <i class="fas fa-chevron-down ml-1 text-xs"></i></span>
                                        </div>
                                        <div class="bg-gray-600 rounded-md px-3 py-2 text-sm text-white">
                                            <div class="text-xs text-gray-400 mb-1">Phone Number</div>
                                            <div>09167408768</div>
                                        </div>
                                        <button class="w-full bg-indigo-500 text-white p-2 rounded-md font-medium">
                                            Purchase (₦240)
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Stats -->
            <div class="mt-16 py-6 bg-gray-800 bg-opacity-50 rounded-xl">
                <div class="grid grid-cols-2 md:grid-cols-4 gap-4">
                    <div class="text-center">
                        <div class="text-3xl md:text-4xl font-bold text-white count-up">25K+</div>
                        <div class="text-gray-400 mt-1">Happy Customers</div>
                    </div>
                    <div class="text-center">
                        <div class="text-3xl md:text-4xl font-bold text-white count-up">99.9%</div>
                        <div class="text-gray-400 mt-1">Uptime</div>
                    </div>
                    <div class="text-center">
                        <div class="text-3xl md:text-4xl font-bold text-white count-up">500K+</div>
                        <div class="text-gray-400 mt-1">Transactions</div>
                    </div>
                    <div class="text-center">
                        <div class="text-3xl md:text-4xl font-bold text-white count-up">24/7</div>
                        <div class="text-gray-400 mt-1">Customer Support</div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
    <!-- Features Section -->
    <section id="features" class="py-16">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Why Choose Us?</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    We're committed to providing the best VTU experience with features that make your life easier.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-8">
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-bolt text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">Instant Delivery</h3>
                    <p class="text-gray-400">
                        All our services are automated and delivered instantly to your devices without any delay.
                    </p>
                </div>
                
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-shield-alt text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">Secure Transactions</h3>
                    <p class="text-gray-400">
                        Your data and transactions are encrypted and protected with the highest security standards.
                    </p>
                </div>
                
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-tags text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">Best Pricing</h3>
                    <p class="text-gray-400">
                        We offer the most competitive rates in the market with discounts for bulk purchases.
                    </p>
                </div>
                
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-wallet text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">Wallet System</h3>
                    <p class="text-gray-400">
                        Fund your wallet once and use it for multiple transactions with ease and convenience.
                    </p>
                </div>
                
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-code text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">API Access</h3>
                    <p class="text-gray-400">
                        Developers can integrate our services directly into their applications with our robust API.
                    </p>
                </div>
                
                <div class="site-card rounded-xl p-6 text-center">
                    <div class="h-16 w-16 mx-auto bg-indigo-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4 feature-icon">
                        <i class="fas fa-headset text-indigo-400 text-2xl"></i>
                    </div>
                    <h3 class="text-xl font-bold text-white mb-3">24/7 Support</h3>
                    <p class="text-gray-400">
                        Our customer support team is available round the clock to assist you with any issues.
                    </p>
                </div>
            </div>
        </div>
    </section>
    
    <!-- Services Section -->
    <section id="services" class="py-16 bg-gray-900">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Our Services</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    We offer a comprehensive range of services to meet all your digital needs at the best possible prices.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-blue-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-blue-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-wifi text-blue-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">Data Bundles</h3>
                        <p class="text-gray-400 mb-4">
                            Get affordable data plans for all networks - MTN, Airtel, Glo, and 9mobile with instant delivery.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                SME Data Plans
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Gifting Data Plans
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Corporate Data Plans
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/buy_data.php' : 'login/register.php'; ?>" class="text-blue-400 hover:text-blue-300 font-medium flex items-center">
                            Buy Data <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
                
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-green-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-phone text-green-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">Airtime Recharge</h3>
                        <p class="text-gray-400 mb-4">
                            Recharge airtime for yourself, family, and friends at discounted rates with instant delivery.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                VTU Airtime (All Networks)
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Bulk Airtime Purchase
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Schedule Recharge
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/buy_airtime.php' : 'login/register.php'; ?>" class="text-green-400 hover:text-green-300 font-medium flex items-center">
                            Buy Airtime <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
                
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-yellow-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-yellow-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-bolt text-yellow-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">Electricity Bills</h3>
                        <p class="text-gray-400 mb-4">
                            Pay electricity bills for all distribution companies in Nigeria with instant token delivery.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Prepaid Meters
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Postpaid Meters
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                All Discos Available
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-yellow-400 hover:text-yellow-300 font-medium flex items-center">
                            Pay Electricity <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
                
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-red-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-tv text-red-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">Cable TV Subscription</h3>
                        <p class="text-gray-400 mb-4">
                            Renew your cable TV subscriptions for DSTV, GOTV, and Startimes at discounted rates.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                DSTV Packages
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                GOTV Packages
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Startimes Packages
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-red-400 hover:text-red-300 font-medium flex items-center">
                            Pay TV Bills <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
                
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-purple-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-purple-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-exchange-alt text-purple-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">Airtime to Cash</h3>
                        <p class="text-gray-400 mb-4">
                            Convert your excess airtime to cash with the best rates in the market.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                All Networks Supported
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Competitive Rates
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Fast Processing
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-purple-400 hover:text-purple-300 font-medium flex items-center">
                            Convert Airtime <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
                
                <div class="site-card rounded-xl overflow-hidden">
                    <div class="h-3 bg-pink-500"></div>
                    <div class="p-6">
                        <div class="h-14 w-14 bg-pink-500 bg-opacity-20 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-code text-pink-400 text-2xl"></i>
                        </div>
                        <h3 class="text-xl font-bold text-white mb-3">API Access</h3>
                        <p class="text-gray-400 mb-4">
                            Integrate our services into your applications with our robust API for developers.
                        </p>
                        <ul class="space-y-2 mb-6">
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                RESTful API
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Detailed Documentation
                            </li>
                            <li class="flex items-center text-gray-400 text-sm">
                                <i class="fas fa-check text-green-400 mr-2"></i>
                                Developer Support
                            </li>
                        </ul>
                        <a href="<?php echo $loggedIn ? 'dashboard/api_documentation.php' : 'login/register.php'; ?>" class="text-pink-400 hover:text-pink-300 font-medium flex items-center">
                            API Documentation <i class="fas fa-arrow-right ml-2"></i>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
    <!-- Pricing Section -->
    <section id="pricing" class="py-16">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Simple, Transparent Pricing</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    Choose the plan that works best for you with no hidden fees or charges.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-8 max-w-5xl mx-auto">
                <!-- Smart User Plan -->
                <div class="site-card rounded-xl overflow-hidden border-2 border-gray-700 relative">
                    <div class="bg-gray-800 text-center py-8 px-6">
                        <h3 class="text-2xl font-bold text-white mb-2">Smart User</h3>
                        <div class="text-3xl font-bold text-white">Free</div>
                        <p class="text-gray-400 mt-2">Standard Benefits</p>
                    </div>
                    <div class="p-6">
                        <ul class="space-y-4">
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Access to all services</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Standard data and airtime rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Wallet system</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Email support</span>
                            </li>
                            <li class="flex items-start opacity-50">
                                <i class="fas fa-times text-red-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Discounted rates</span>
                            </li>
                            <li class="flex items-start opacity-50">
                                <i class="fas fa-times text-red-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">API access</span>
                            </li>
                        </ul>
                        
                        <div class="mt-8">
                            <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="block w-full py-2 px-4 bg-gray-700 hover:bg-gray-600 text-white font-medium text-center rounded-md transition-colors">
                                Get Started
                            </a>
                        </div>
                    </div>
                </div>
                
                <!-- Vendor Plan -->
                <div class="site-card rounded-xl overflow-hidden border-2 border-indigo-500 relative transform scale-105 z-10">
                    <div class="absolute top-0 right-0 bg-indigo-500 text-white text-xs font-bold px-3 py-1 rounded-bl-lg">POPULAR</div>
                    <div class="bg-indigo-600 text-center py-8 px-6">
                        <h3 class="text-2xl font-bold text-white mb-2">Vendor</h3>
                        <div class="text-3xl font-bold text-white">₦1,000</div>
                        <p class="text-indigo-200 mt-2">One-time payment</p>
                    </div>
                    <div class="p-6">
                        <ul class="space-y-4">
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">All Smart User benefits</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Discounted data rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Discounted airtime rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Priority customer support</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Access to exclusive offers</span>
                            </li>
                            <li class="flex items-start opacity-50">
                                <i class="fas fa-times text-red-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">API access</span>
                            </li>
                        </ul>
                        
                        <div class="mt-8">
                            <a href="<?php echo $loggedIn ? 'dashboard/upgrade.php' : 'login/register.php'; ?>" class="block w-full py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white font-medium text-center rounded-md transition-colors">
                                Upgrade Now
                            </a>
                        </div>
                    </div>
                </div>
                
                <!-- API User Plan -->
                <div class="site-card rounded-xl overflow-hidden border-2 border-gray-700 relative">
                    <div class="bg-gray-800 text-center py-8 px-6">
                        <h3 class="text-2xl font-bold text-white mb-2">API User</h3>
                        <div class="text-3xl font-bold text-white">Contact Us</div>
                        <p class="text-gray-400 mt-2">For developers & businesses</p>
                    </div>
                    <div class="p-6">
                        <ul class="space-y-4">
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">All Vendor benefits</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">API integration access</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Lowest rates available</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Detailed documentation</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Developer support</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check text-green-400 mt-1 mr-3"></i>
                                <span class="text-gray-300">Custom integrations</span>
                            </li>
                        </ul>
                        
                        <div class="mt-8">
                            <a href="#contact" class="block w-full py-2 px-4 bg-gray-700 hover:bg-gray-600 text-white font-medium text-center rounded-md transition-colors">
                                Contact Us
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
    <!-- Testimonials -->
    <section class="py-16 bg-gray-900">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">What Our Customers Say</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    Don't just take our word for it. Here's what our customers have to say about our services.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-8">
                <div class="testimonial-card site-card rounded-xl p-6">
                    <div class="testimonial-content">
                        <div class="flex items-center mb-4">
                            <div class="h-12 w-12 rounded-full bg-gray-700 flex items-center justify-center mr-3 text-lg font-bold text-white">JD</div>
                            <div>
                                <h4 class="text-lg font-semibold text-white">John Doe</h4>
                                <div class="flex text-yellow-400 text-sm">
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                </div>
                            </div>
                        </div>
                        <p class="text-gray-300">
                            "I've been using this platform for over a year now, and it has been a great experience. The services are fast, reliable, and the rates are unbeatable."
                        </p>
                    </div>
                </div>
                
                <div class="testimonial-card site-card rounded-xl p-6">
                    <div class="testimonial-content">
                        <div class="flex items-center mb-4">
                            <div class="h-12 w-12 rounded-full bg-gray-700 flex items-center justify-center mr-3 text-lg font-bold text-white">SD</div>
                            <div>
                                <h4 class="text-lg font-semibold text-white">Sarah Davis</h4>
                                <div class="flex text-yellow-400 text-sm">
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star-half-alt"></i>
                                </div>
                            </div>
                        </div>
                        <p class="text-gray-300">
                            "The best VTU service I've used. Their customer support is excellent, and the transactions are always instant. I recommend them to all my friends."
                        </p>
                    </div>
                </div>
                
                <div class="testimonial-card site-card rounded-xl p-6">
                    <div class="testimonial-content">
                        <div class="flex items-center mb-4">
                            <div class="h-12 w-12 rounded-full bg-gray-700 flex items-center justify-center mr-3 text-lg font-bold text-white">MJ</div>
                            <div>
                                <h4 class="text-lg font-semibold text-white">Michael Johnson</h4>
                                <div class="flex text-yellow-400 text-sm">
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                    <i class="fas fa-star"></i>
                                </div>
                            </div>
                        </div>
                        <p class="text-gray-300">
                            "As a business owner, I needed a reliable API for my app. Their API is well-documented, stable, and their rates are the best in the market. Highly recommended!"
                        </p>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
    <!-- FAQ Section -->
    <section id="faq" class="py-16">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Frequently Asked Questions</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    Find answers to the most common questions about our services.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="max-w-4xl mx-auto">
                <div class="space-y-6">
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">How do I fund my wallet?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                You can fund your wallet using your dedicated Paystack account or through bank transfer. Once your wallet is funded, you can use it to purchase any service on our platform. The transaction is processed instantly, and your wallet is updated in real-time.
                            </p>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">How long does it take for services to be delivered?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                All our services are delivered instantly. Once your payment is confirmed, the service is automatically processed and delivered to the recipient. In rare cases, it might take up to 5 minutes due to network issues.
                            </p>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">What is the difference between Smart, Vendor, and API users?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                <strong>Smart User:</strong> This is the default account type with standard rates and access to all services.<br><br>
                                <strong>Vendor User:</strong> This account type comes with discounted rates for all services and priority support. It requires a one-time upgrade fee.<br><br>
                                <strong>API User:</strong> This account type includes all vendor benefits plus API access for developers to integrate our services into their applications. Contact us for API user upgrade.
                            </p>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">What happens if a transaction fails?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                If a transaction fails, the amount is automatically refunded to your wallet. You will also receive a notification about the failed transaction. If you don't see the refund or have any issues, our customer support team is available 24/7 to assist you.
                            </p>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">Is there a minimum amount for wallet funding?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                For Paystack checkout, the minimum amount is ₦200. For bank transfer funding, there is no minimum amount, but a service charge of about 5% applies to all wallet funding. The exact rates are displayed during the funding process.
                            </p>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl overflow-hidden">
                        <button class="faq-question w-full px-6 py-4 flex justify-between items-center focus:outline-none text-left">
                            <h3 class="text-lg font-semibold text-white">How do I contact customer support?</h3>
                            <i class="fas fa-chevron-down text-gray-400 transition-transform transform"></i>
                        </button>
                        <div class="faq-answer px-6 py-4 border-t border-gray-700 hidden">
                            <p class="text-gray-300">
                                You can contact our customer support team via email at <?php echo $contactEmail; ?> or by phone at <?php echo $contactPhone; ?>. We are available 24/7 to assist you with any issues or questions you may have.
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    
    <!-- CTA Section -->
    <section class="py-16 bg-indigo-600">
        <div class="container mx-auto px-4 text-center">
            <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Ready to Get Started?</h2>
            <p class="text-xl text-indigo-100 max-w-3xl mx-auto mb-8">
                Join thousands of satisfied customers who are saving money on their digital needs.
            </p>
            <div class="flex flex-col sm:flex-row justify-center space-y-4 sm:space-y-0 sm:space-x-4">
                <a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="bg-white text-indigo-600 py-3 px-8 rounded-md font-medium hover:bg-gray-100 transition-colors">
                    <?php echo $loggedIn ? 'Go to Dashboard' : 'Create an Account'; ?>
                </a>
                <a href="#contact" class="border-2 border-white text-white py-3 px-8 rounded-md font-medium hover:bg-indigo-700 transition-colors">
                    Contact Us
                </a>
            </div>
        </div>
    </section>
    
    <!-- Contact Section -->
    <section id="contact" class="py-16">
        <div class="container mx-auto px-4">
            <div class="text-center mb-12">
                <h2 class="text-3xl md:text-4xl font-bold text-white mb-4">Get in Touch</h2>
                <p class="text-xl text-gray-400 max-w-3xl mx-auto">
                    Have questions or feedback? We'd love to hear from you.
                </p>
                <div class="section-divider mt-6"></div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-12 max-w-6xl mx-auto">
                <div>
                    <div class="site-card rounded-xl p-6 mb-6">
                        <h3 class="text-xl font-semibold text-white mb-4">Contact Information</h3>
                        <div class="space-y-4">
                            <div class="flex items-start">
                                <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-4">
                                    <i class="fas fa-envelope text-indigo-400"></i>
                                </div>
                                <div>
                                    <h4 class="font-medium text-white">Email</h4>
                                    <p class="text-gray-400"><?php echo $contactEmail; ?></p>
                                </div>
                            </div>
                            <div class="flex items-start">
                                <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-4">
                                    <i class="fas fa-phone-alt text-indigo-400"></i>
                                </div>
                                <div>
                                    <h4 class="font-medium text-white">Phone</h4>
                                    <p class="text-gray-400"><?php echo $contactPhone; ?></p>
                                </div>
                            </div>
                            <div class="flex items-start">
                                <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-4">
                                    <i class="fas fa-map-marker-alt text-indigo-400"></i>
                                </div>
                                <div>
                                    <h4 class="font-medium text-white">Address</h4>
                                    <p class="text-gray-400">123 Business Avenue, Lagos, Nigeria</p>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="site-card rounded-xl p-6">
                        <h3 class="text-xl font-semibold text-white mb-4">Business Hours</h3>
                        <div class="space-y-2">
                            <div class="flex justify-between">
                                <span class="text-gray-400">Monday - Friday:</span>
                                <span class="text-white">9:00 AM - 6:00 PM</span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Saturday:</span>
                                <span class="text-white">10:00 AM - 4:00 PM</span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Sunday:</span>
                                <span class="text-white">Closed</span>
                            </div>
                        </div>
                        <div class="mt-4 pt-4 border-t border-gray-700">
                            <p class="text-gray-400">
                                <i class="fas fa-info-circle text-indigo-400 mr-2"></i>
                                Our online services are available 24/7, and our customer support team is always ready to assist you.
                            </p>
                        </div>
                    </div>
                </div>
                
                <div class="site-card rounded-xl p-6">
                    <h3 class="text-xl font-semibold text-white mb-4">Send us a Message</h3>
                    <form action="#" method="POST" id="contactForm">
                        <div class="mb-4">
                            <label for="name" class="block text-sm font-medium text-gray-400 mb-1">Your Name</label>
                            <input type="text" id="name" name="name" class="w-full bg-gray-700 border border-gray-600 rounded-md py-2 px-3 text-white focus:outline-none focus:border-indigo-500" required>
                        </div>
                        <div class="mb-4">
                            <label for="email" class="block text-sm font-medium text-gray-400 mb-1">Email Address</label>
                            <input type="email" id="email" name="email" class="w-full bg-gray-700 border border-gray-600 rounded-md py-2 px-3 text-white focus:outline-none focus:border-indigo-500" required>
                        </div>
                        <div class="mb-4">
                            <label for="subject" class="block text-sm font-medium text-gray-400 mb-1">Subject</label>
                            <input type="text" id="subject" name="subject" class="w-full bg-gray-700 border border-gray-600 rounded-md py-2 px-3 text-white focus:outline-none focus:border-indigo-500" required>
                        </div>
                        <div class="mb-6">
                            <label for="message" class="block text-sm font-medium text-gray-400 mb-1">Message</label>
                            <textarea id="message" name="message" rows="4" class="w-full bg-gray-700 border border-gray-600 rounded-md py-2 px-3 text-white focus:outline-none focus:border-indigo-500" required></textarea>
                        </div>
                        <div>
                            <button type="submit" class="w-full accent-button py-2 px-4 border border-transparent rounded-md font-medium text-white hover:bg-indigo-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Send Message
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </section>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 pt-12 pb-6">
        <div class="container mx-auto px-4">
            <div class="grid grid-cols-1 md:grid-cols-4 gap-8 mb-8">
                <div>
                    <h3 class="text-xl font-bold text-white mb-4">
                        <span class="text-indigo-400 mr-1"><i class="fas fa-bolt"></i></span>
                        <?php echo $siteName; ?>
                    </h3>
                    <p class="mb-4">
                        <?php echo $siteDescription; ?>
                    </p>
                    <div class="flex space-x-4">
                        <a href="#" class="text-gray-400 hover:text-white">
                            <i class="fab fa-facebook-f"></i>
                        </a>
                        <a href="#" class="text-gray-400 hover:text-white">
                            <i class="fab fa-twitter"></i>
                        </a>
                        <a href="#" class="text-gray-400 hover:text-white">
                            <i class="fab fa-instagram"></i>
                        </a>
                        <a href="#" class="text-gray-400 hover:text-white">
                            <i class="fab fa-whatsapp"></i>
                        </a>
                    </div>
                </div>
                
                <div>
                    <h3 class="text-lg font-semibold text-white mb-4">Quick Links</h3>
                    <ul class="space-y-2">
                        <li><a href="#features" class="text-gray-400 hover:text-white">Features</a></li>
                        <li><a href="#services" class="text-gray-400 hover:text-white">Services</a></li>
                        <li><a href="#pricing" class="text-gray-400 hover:text-white">Pricing</a></li>
                        <li><a href="#faq" class="text-gray-400 hover:text-white">FAQ</a></li>
                        <li><a href="#contact" class="text-gray-400 hover:text-white">Contact</a></li>
                    </ul>
                </div>
                
                <div>
                    <h3 class="text-lg font-semibold text-white mb-4">Services</h3>
                    <ul class="space-y-2">
                        <li><a href="<?php echo $loggedIn ? 'dashboard/buy_data.php' : 'login/register.php'; ?>" class="text-gray-400 hover:text-white">Data Bundles</a></li>
                        <li><a href="<?php echo $loggedIn ? 'dashboard/buy_airtime.php' : 'login/register.php'; ?>" class="text-gray-400 hover:text-white">Airtime Recharge</a></li>
                        <li><a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-gray-400 hover:text-white">Electricity Bills</a></li>
                        <li><a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-gray-400 hover:text-white">Cable TV Subscription</a></li>
                        <li><a href="<?php echo $loggedIn ? 'dashboard/' : 'login/register.php'; ?>" class="text-gray-400 hover:text-white">Airtime to Cash</a></li>
                    </ul>
                </div>
                
                <div>
                    <h3 class="text-lg font-semibold text-white mb-4">Contact</h3>
                    <ul class="space-y-2">
                        <li class="flex items-start">
                            <i class="fas fa-envelope text-indigo-400 mt-1 mr-2"></i>
                            <span><?php echo $contactEmail; ?></span>
                        </li>
                        <li class="flex items-start">
                            <i class="fas fa-phone-alt text-indigo-400 mt-1 mr-2"></i>
                            <span><?php echo $contactPhone; ?></span>
                        </li>
                        <li class="flex items-start">
                            <i class="fas fa-map-marker-alt text-indigo-400 mt-1 mr-2"></i>
                            <span>123 Business Avenue, Lagos, Nigeria</span>
                        </li>
                    </ul>
                </div>
            </div>
            
            <div class="border-t border-gray-700 pt-6 text-center">
                <p>&copy; <?php echo date('Y'); ?> <?php echo $siteName; ?>. All rights reserved.</p>
            </div>
        </div>
    </footer>
    
    <!-- Back to top button -->
    <button id="backToTop" class="fixed bottom-8 right-8 bg-indigo-600 text-white w-10 h-10 rounded-full flex items-center justify-center shadow-lg transform transition-transform hover:scale-110 opacity-0">
        <i class="fas fa-arrow-up"></i>
    </button>
    
    <!-- JavaScript -->
    <script>
        // Mobile menu toggle
        const mobileMenuButton = document.getElementById('mobileMenuButton');
        const mobileMenu = document.getElementById('mobileMenu');
        
        mobileMenuButton.addEventListener('click', () => {
            mobileMenu.classList.toggle('hidden');
            if (!mobileMenu.classList.contains('hidden')) {
                mobileMenu.classList.add('mobile-menu-enter');
                setTimeout(() => {
                    mobileMenu.classList.add('mobile-menu-enter-active');
                }, 10);
                setTimeout(() => {
                    mobileMenu.classList.remove('mobile-menu-enter', 'mobile-menu-enter-active');
                }, 200);
            } else {
                mobileMenu.classList.add('mobile-menu-exit');
                setTimeout(() => {
                    mobileMenu.classList.add('mobile-menu-exit-active');
                }, 10);
                setTimeout(() => {
                    mobileMenu.classList.remove('mobile-menu-exit', 'mobile-menu-exit-active');
                }, 150);
            }
        });
        
        // FAQ accordion
        const faqQuestions = document.querySelectorAll('.faq-question');
        
        faqQuestions.forEach(question => {
            question.addEventListener('click', () => {
                const answer = question.nextElementSibling;
                const icon = question.querySelector('i');
                
                // Toggle display
                answer.classList.toggle('hidden');
                
                // Toggle icon rotation
                if (answer.classList.contains('hidden')) {
                    icon.classList.remove('rotate-180');
                } else {
                    icon.classList.add('rotate-180');
                }
            });
        });
        
        // Back to top button
        const backToTopButton = document.getElementById('backToTop');
        
        window.addEventListener('scroll', () => {
            if (window.scrollY > 300) {
                backToTopButton.classList.remove('opacity-0');
                backToTopButton.classList.add('opacity-100');
            } else {
                backToTopButton.classList.remove('opacity-100');
                backToTopButton.classList.add('opacity-0');
            }
        });
        
        backToTopButton.addEventListener('click', () => {
            window.scrollTo({
                top: 0,
                behavior: 'smooth'
            });
        });
        
        // Contact form submission (placeholder)
        const contactForm = document.getElementById('contactForm');
        
        contactForm.addEventListener('submit', (e) => {
            e.preventDefault();
            
            // This is a placeholder. In a real implementation, you would send an AJAX request to process the form.
            alert('Thank you for your message. We will get back to you shortly.');
            contactForm.reset();
        });
        
        // Smooth scrolling for anchor links
        document.querySelectorAll('a[href^="#"]').forEach(anchor => {
            anchor.addEventListener('click', function (e) {
                e.preventDefault();
                
                const targetId = this.getAttribute('href').substring(1);
                if (!targetId) return;
                
                const targetElement = document.getElementById(targetId);
                
                if (targetElement) {
                    targetElement.scrollIntoView({
                        behavior: 'smooth',
                        block: 'start'
                    });
                    
                    // Close mobile menu if open
                    if (!mobileMenu.classList.contains('hidden')) {
                        mobileMenu.classList.add('hidden');
                    }
                }
            });
        });
    </script>
</body>
</html>