<?php
// File: /webhook/monnify.php

// Disable direct access
if (php_sapi_name() !== 'cli' && (!isset($_SERVER['HTTP_X_MONNIFY_SIGNATURE']) || empty($_SERVER['HTTP_X_MONNIFY_SIGNATURE']))) {
    http_response_code(403);
    exit('Direct access not allowed');
}

// Load required files
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once '../includes/monnify.php';

// Get the raw POST data
$payload = file_get_contents('php://input');

// Log the webhook payload for debugging
error_log('Monnify Webhook Payload: ' . $payload);

// Get the signature from the header
$signature = $_SERVER['HTTP_X_MONNIFY_SIGNATURE'] ?? '';

// Create Monnify instance
$monnify = new Monnify();

// Handle the webhook
$result = $monnify->handleWebhook($payload, $signature);

if ($result['success']) {
    // Log success
    error_log('Monnify webhook processed successfully: ' . json_encode($result));
    
    // Return 200 OK
    http_response_code(200);
    echo json_encode([
        'status' => 'success',
        'message' => $result['message']
    ]);
} else {
    // Log error
    error_log('Monnify webhook error: ' . $result['message']);
    
    // Return 500 Internal Server Error
    http_response_code(500);
    echo json_encode([
        'status' => 'error',
        'message' => $result['message']
    ]);
}
?>